/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.css.engine.CSSNavigableNode;
/*     */ import org.apache.batik.dom.AbstractAttr;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.AbstractElement;
/*     */ import org.apache.batik.dom.events.NodeEventTarget;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.NamedNodeMap;
/*     */ import org.w3c.dom.Node;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractElement
/*     */   extends AbstractElement
/*     */   implements NodeEventTarget, CSSNavigableNode, SVGConstants
/*     */ {
/*  48 */   protected DoublyIndexedTable liveAttributeValues = new DoublyIndexedTable();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected AbstractElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected AbstractElement(String prefix, AbstractDocument owner) {
/*  63 */     this.ownerDocument = owner;
/*  64 */     setPrefix(prefix);
/*  65 */     initializeAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  74 */   public Node getCSSParentNode() { return getXblParentNode(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  81 */   public Node getCSSPreviousSibling() { return getXblPreviousSibling(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  88 */   public Node getCSSNextSibling() { return getXblNextSibling(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  95 */   public Node getCSSFirstChild() { return getXblFirstChild(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 102 */   public Node getCSSLastChild() { return getXblLastChild(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 110 */   public boolean isHiddenFromSelectors() { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void fireDOMAttrModifiedEvent(String name, Attr node, String oldv, String newv, short change) {
/* 117 */     super.fireDOMAttrModifiedEvent(name, node, oldv, newv, change);
/*     */ 
/*     */     
/* 120 */     if (((SVGOMDocument)this.ownerDocument).isSVG12 && (change == 2 || change == 1))
/*     */     {
/*     */       
/* 123 */       if (node.getNamespaceURI() == null && node.getNodeName().equals("id")) {
/*     */         
/* 125 */         Attr a = getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "id");
/*     */         
/* 127 */         if (a == null) {
/* 128 */           setAttributeNS("http://www.w3.org/XML/1998/namespace", "id", newv);
/* 129 */         } else if (!a.getNodeValue().equals(newv)) {
/* 130 */           a.setNodeValue(newv);
/*     */         } 
/* 132 */       } else if (node.getNodeName().equals("xml:id")) {
/* 133 */         Attr a = getAttributeNodeNS(null, "id");
/* 134 */         if (a == null) {
/* 135 */           setAttributeNS(null, "id", newv);
/* 136 */         } else if (!a.getNodeValue().equals(newv)) {
/* 137 */           a.setNodeValue(newv);
/*     */         } 
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 153 */   public LiveAttributeValue getLiveAttributeValue(String ns, String ln) { return (LiveAttributeValue)this.liveAttributeValues.get(ns, ln); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 167 */   public void putLiveAttributeValue(String ns, String ln, LiveAttributeValue val) { this.liveAttributeValues.put(ns, ln, val); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 175 */   protected AttributeInitializer getAttributeInitializer() { return null; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAttributes() {
/* 182 */     AttributeInitializer ai = getAttributeInitializer();
/* 183 */     if (ai != null) {
/* 184 */       ai.initializeAttributes(this);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean resetAttribute(String ns, String prefix, String ln) {
/* 193 */     AttributeInitializer ai = getAttributeInitializer();
/* 194 */     if (ai == null) {
/* 195 */       return false;
/*     */     }
/* 197 */     return ai.resetAttribute(this, ns, prefix, ln);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 204 */   protected NamedNodeMap createAttributes() { return new ExtendedNamedNodeHashMap(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setUnspecifiedAttribute(String nsURI, String name, String value) {
/* 215 */     if (this.attributes == null) {
/* 216 */       this.attributes = createAttributes();
/*     */     }
/* 218 */     ((ExtendedNamedNodeHashMap)this.attributes).setUnspecifiedAttribute(nsURI, name, value);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void attrAdded(Attr node, String newv) {
/* 226 */     LiveAttributeValue lav = getLiveAttributeValue(node);
/* 227 */     if (lav != null) {
/* 228 */       lav.attrAdded(node, newv);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void attrModified(Attr node, String oldv, String newv) {
/* 236 */     LiveAttributeValue lav = getLiveAttributeValue(node);
/* 237 */     if (lav != null) {
/* 238 */       lav.attrModified(node, oldv, newv);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void attrRemoved(Attr node, String oldv) {
/* 246 */     LiveAttributeValue lav = getLiveAttributeValue(node);
/* 247 */     if (lav != null) {
/* 248 */       lav.attrRemoved(node, oldv);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private LiveAttributeValue getLiveAttributeValue(Attr node) {
/* 257 */     String ns = node.getNamespaceURI();
/* 258 */     return getLiveAttributeValue(ns, (ns == null) ? node.getNodeName() : node.getLocalName());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node export(Node n, AbstractDocument d) {
/* 269 */     super.export(n, d);
/* 270 */     ((AbstractElement)n).initializeAttributes();
/*     */     
/* 272 */     super.export(n, d);
/* 273 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepExport(Node n, AbstractDocument d) {
/* 280 */     super.export(n, d);
/* 281 */     ((AbstractElement)n).initializeAttributes();
/*     */     
/* 283 */     super.deepExport(n, d);
/* 284 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class ExtendedNamedNodeHashMap
/*     */     extends AbstractElement.NamedNodeHashMap
/*     */   {
/*     */     private final AbstractElement this$0;
/*     */ 
/*     */     
/* 295 */     public ExtendedNamedNodeHashMap(AbstractElement this$0) { super(this$0); this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setUnspecifiedAttribute(String nsURI, String name, String value) {
/* 307 */       Attr attr = this.this$0.getOwnerDocument().createAttributeNS(nsURI, name);
/* 308 */       attr.setValue(value);
/* 309 */       ((AbstractAttr)attr).setSpecified(false);
/* 310 */       setNamedItemNS(attr);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Node removeNamedItemNS(String namespaceURI, String localName) throws DOMException {
/* 318 */       if (this.this$0.isReadonly()) {
/* 319 */         throw this.this$0.createDOMException((short)7, "readonly.node.map", new Object[0]);
/*     */       }
/*     */ 
/*     */ 
/*     */       
/* 324 */       if (localName == null) {
/* 325 */         throw this.this$0.createDOMException((short)8, "attribute.missing", new Object[] { "" });
/*     */       }
/*     */ 
/*     */       
/* 329 */       AbstractAttr n = (AbstractAttr)remove(namespaceURI, localName);
/* 330 */       if (n == null) {
/* 331 */         throw this.this$0.createDOMException((short)8, "attribute.missing", new Object[] { localName });
/*     */       }
/*     */ 
/*     */       
/* 335 */       n.setOwnerElement(null);
/* 336 */       String prefix = n.getPrefix();
/*     */ 
/*     */       
/* 339 */       if (!this.this$0.resetAttribute(namespaceURI, prefix, localName))
/*     */       {
/* 341 */         this.this$0.fireDOMAttrModifiedEvent(n.getNodeName(), n, n.getNodeValue(), "", (short)3);
/*     */       }
/*     */ 
/*     */       
/* 345 */       return n;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */