/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatableLengthValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGAnimatedLength
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedLength, LiveAttributeValue
/*     */ {
/*     */   public static final short HORIZONTAL_LENGTH = 2;
/*     */   public static final short VERTICAL_LENGTH = 1;
/*     */   public static final short OTHER_LENGTH = 0;
/*     */   protected short direction;
/*     */   protected BaseSVGLength baseVal;
/*     */   protected AnimSVGLength animVal;
/*     */   protected boolean changing;
/*     */   protected boolean nonNegative;
/*     */   
/*     */   public AbstractSVGAnimatedLength(AbstractElement elt, String ns, String ln, short dir, boolean nonneg) {
/*  99 */     super(elt, ns, ln);
/* 100 */     this.direction = dir;
/* 101 */     this.nonNegative = nonneg;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract String getDefaultValue();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGLength getBaseVal() {
/* 114 */     if (this.baseVal == null) {
/* 115 */       this.baseVal = new BaseSVGLength(this, this.direction);
/*     */     }
/* 117 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGLength getAnimVal() {
/* 124 */     if (this.animVal == null) {
/* 125 */       this.animVal = new AnimSVGLength(this, this.direction);
/*     */     }
/* 127 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getCheckedValue() {
/* 135 */     if (this.hasAnimVal) {
/* 136 */       if (this.animVal == null) {
/* 137 */         this.animVal = new AnimSVGLength(this, this.direction);
/*     */       }
/* 139 */       if (this.nonNegative && this.animVal.value < 0.0F) {
/* 140 */         throw new LiveAttributeException(this.element, this.localName, (short)2, this.animVal.getValueAsString());
/*     */       }
/*     */ 
/*     */ 
/*     */       
/* 145 */       return this.animVal.getValue();
/*     */     } 
/* 147 */     if (this.baseVal == null) {
/* 148 */       this.baseVal = new BaseSVGLength(this, this.direction);
/*     */     }
/* 150 */     this.baseVal.revalidate();
/* 151 */     if (this.baseVal.missing) {
/* 152 */       throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */     }
/*     */     
/* 155 */     if (this.baseVal.unitType == 0)
/*     */     {
/* 157 */       throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 162 */     if (this.nonNegative && this.baseVal.value < 0.0F) {
/* 163 */       throw new LiveAttributeException(this.element, this.localName, (short)2, this.baseVal.getValueAsString());
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 168 */     return this.baseVal.getValue();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 176 */     if (val == null) {
/* 177 */       this.hasAnimVal = false;
/*     */     } else {
/* 179 */       this.hasAnimVal = true;
/* 180 */       AnimatableLengthValue animLength = (AnimatableLengthValue)val;
/* 181 */       if (this.animVal == null) {
/* 182 */         this.animVal = new AnimSVGLength(this, this.direction);
/*     */       }
/* 184 */       this.animVal.setAnimatedValue(animLength.getLengthType(), animLength.getLengthValue());
/*     */     } 
/*     */     
/* 187 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 194 */     SVGLength base = getBaseVal();
/* 195 */     return new AnimatableLengthValue(target, base.getUnitType(), base.getValueInSpecifiedUnits(), target.getPercentageInterpretation(getNamespaceURI(), getLocalName(), false));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 205 */   public void attrAdded(Attr node, String newv) { attrChanged(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 212 */   public void attrModified(Attr node, String oldv, String newv) { attrChanged(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 219 */   public void attrRemoved(Attr node, String oldv) { attrChanged(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void attrChanged() {
/* 226 */     if (!this.changing && this.baseVal != null) {
/* 227 */       this.baseVal.invalidate();
/*     */     }
/* 229 */     fireBaseAttributeListeners();
/* 230 */     if (!this.hasAnimVal) {
/* 231 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class BaseSVGLength
/*     */     extends AbstractSVGLength
/*     */   {
/*     */     protected boolean valid;
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean missing;
/*     */ 
/*     */ 
/*     */     
/*     */     private final AbstractSVGAnimatedLength this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public BaseSVGLength(AbstractSVGAnimatedLength this$0, short direction) {
/* 255 */       super(direction);
/*     */       this.this$0 = this$0;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 262 */     public void invalidate() { this.valid = false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void reset() {
/*     */       try {
/* 270 */         this.this$0.changing = true;
/* 271 */         this.valid = true;
/* 272 */         String value = getValueAsString();
/* 273 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 275 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/*     */       String str;
/* 283 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 287 */       this.missing = false;
/* 288 */       this.valid = true;
/*     */       
/* 290 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/*     */       
/* 292 */       if (attr == null) {
/* 293 */         str = this.this$0.getDefaultValue();
/* 294 */         if (str == null) {
/* 295 */           this.missing = true;
/*     */           return;
/*     */         } 
/*     */       } else {
/* 299 */         str = attr.getValue();
/*     */       } 
/*     */       
/* 302 */       parse(str);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 309 */     protected SVGOMElement getAssociatedElement() { return (SVGOMElement)this.this$0.element; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class AnimSVGLength
/*     */     extends AbstractSVGLength
/*     */   {
/*     */     private final AbstractSVGAnimatedLength this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public AnimSVGLength(AbstractSVGAnimatedLength this$0, short direction) {
/* 323 */       super(direction);
/*     */       this.this$0 = this$0;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/*     */     public short getUnitType() {
/* 330 */       if (this.this$0.hasAnimVal) {
/* 331 */         return super.getUnitType();
/*     */       }
/* 333 */       return this.this$0.getBaseVal().getUnitType();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getValue() {
/* 340 */       if (this.this$0.hasAnimVal) {
/* 341 */         return super.getValue();
/*     */       }
/* 343 */       return this.this$0.getBaseVal().getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getValueInSpecifiedUnits() {
/* 350 */       if (this.this$0.hasAnimVal) {
/* 351 */         return super.getValueInSpecifiedUnits();
/*     */       }
/* 353 */       return this.this$0.getBaseVal().getValueInSpecifiedUnits();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public String getValueAsString() {
/* 360 */       if (this.this$0.hasAnimVal) {
/* 361 */         return super.getValueAsString();
/*     */       }
/* 363 */       return this.this$0.getBaseVal().getValueAsString();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 370 */     public void setValue(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 380 */     public void setValueInSpecifiedUnits(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 389 */     public void setValueAsString(String value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 399 */     public void newValueSpecifiedUnits(short unit, float value) { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 409 */     public void convertToSpecifiedUnits(short unit) { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 418 */     protected SVGOMElement getAssociatedElement() { return (SVGOMElement)this.this$0.element; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 427 */     protected void setAnimatedValue(int type, float val) { super.newValueSpecifiedUnits((short)type, val); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGAnimatedLength.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */