/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.parser.LengthParser;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.apache.batik.parser.UnitProcessor;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGLength
/*     */   implements SVGLength
/*     */ {
/*     */   public static final short HORIZONTAL_LENGTH = 2;
/*     */   public static final short VERTICAL_LENGTH = 1;
/*     */   public static final short OTHER_LENGTH = 0;
/*     */   protected short unitType;
/*     */   protected float value;
/*     */   protected short direction;
/*     */   protected UnitProcessor.Context context;
/*     */   protected static final String[] UNITS = { 
/*  92 */       "", "", "%", "em", "ex", "px", "cm", "mm", "in", "pt", "pc" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract SVGOMElement getAssociatedElement();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AbstractSVGLength(short direction) {
/* 105 */     this.context = new DefaultContext(this);
/* 106 */     this.direction = direction;
/* 107 */     this.value = 0.0F;
/* 108 */     this.unitType = 1;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public short getUnitType() {
/* 115 */     revalidate();
/* 116 */     return this.unitType;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getValue() {
/* 123 */     revalidate();
/*     */     try {
/* 125 */       return UnitProcessor.svgToUserSpace(this.value, this.unitType, this.direction, this.context);
/*     */     
/*     */     }
/*     */     catch (IllegalArgumentException ex) {
/*     */       
/* 130 */       return 0.0F;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValue(float value) throws DOMException {
/* 138 */     this.value = UnitProcessor.userSpaceToSVG(value, this.unitType, this.direction, this.context);
/*     */     
/* 140 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getValueInSpecifiedUnits() {
/* 147 */     revalidate();
/* 148 */     return this.value;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValueInSpecifiedUnits(float value) throws DOMException {
/* 156 */     revalidate();
/* 157 */     this.value = value;
/* 158 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getValueAsString() {
/* 165 */     revalidate();
/* 166 */     if (this.unitType == 0) {
/* 167 */       return "";
/*     */     }
/* 169 */     return Float.toString(this.value) + UNITS[this.unitType];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValueAsString(String value) throws DOMException {
/* 176 */     parse(value);
/* 177 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void newValueSpecifiedUnits(short unit, float value) {
/* 185 */     this.unitType = unit;
/* 186 */     this.value = value;
/* 187 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void convertToSpecifiedUnits(short unit) {
/* 195 */     float v = getValue();
/* 196 */     this.unitType = unit;
/* 197 */     setValue(v);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void reset() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void revalidate() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void parse(String s) throws DOMException {
/*     */     try {
/* 227 */       LengthParser lengthParser = new LengthParser();
/* 228 */       UnitProcessor.UnitResolver ur = new UnitProcessor.UnitResolver();
/*     */       
/* 230 */       lengthParser.setLengthHandler(ur);
/* 231 */       lengthParser.parse(s);
/* 232 */       this.unitType = ur.unit;
/* 233 */       this.value = ur.value;
/*     */     } catch (ParseException e) {
/* 235 */       this.unitType = 0;
/* 236 */       this.value = 0.0F;
/*     */     } 
/*     */   }
/*     */   
/*     */   protected class DefaultContext implements UnitProcessor.Context {
/*     */     private final AbstractSVGLength this$0;
/*     */     
/* 243 */     protected DefaultContext(AbstractSVGLength this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 249 */     public Element getElement() { return this.this$0.getAssociatedElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 256 */     public float getPixelUnitToMillimeter() { return this.this$0.getAssociatedElement().getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 266 */     public float getPixelToMM() { return getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 273 */     public float getFontSize() { return this.this$0.getAssociatedElement().getSVGContext().getFontSize(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 280 */     public float getXHeight() { return 0.5F; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 287 */     public float getViewportWidth() { return this.this$0.getAssociatedElement().getSVGContext().getViewportWidth(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 294 */     public float getViewportHeight() { return this.this$0.getAssociatedElement().getSVGContext().getViewportHeight(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGLength.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */