/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.Reader;
/*     */ import java.io.StringReader;
/*     */ import java.net.MalformedURLException;
/*     */ import java.util.MissingResourceException;
/*     */ import java.util.Properties;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.svg12.SVG12DOMImplementation;
/*     */ import org.apache.batik.dom.util.SAXDocumentFactory;
/*     */ import org.apache.batik.util.MimeTypeConstants;
/*     */ import org.apache.batik.util.ParsedURL;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.svg.SVGDocument;
/*     */ import org.xml.sax.InputSource;
/*     */ import org.xml.sax.SAXException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SAXSVGDocumentFactory
/*     */   extends SAXDocumentFactory
/*     */   implements SVGDocumentFactory
/*     */ {
/*  53 */   public static final Object LOCK = new Object();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String KEY_PUBLIC_IDS = "publicIds";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String KEY_SKIPPABLE_PUBLIC_IDS = "skippablePublicIds";
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String KEY_SKIP_DTD = "skipDTD";
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String KEY_SYSTEM_ID = "systemId.";
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static final String DTDIDS = "org.apache.batik.dom.svg.resources.dtdids";
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static final String HTTP_CHARSET = "charset";
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String dtdids;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String skippable_dtdids;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String skip_dtd;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static Properties dtdProps;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 111 */   public SAXSVGDocumentFactory(String parser) { super(SVGDOMImplementation.getDOMImplementation(), parser); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 120 */   public SAXSVGDocumentFactory(String parser, boolean dd) { super(SVGDOMImplementation.getDOMImplementation(), parser, dd); }
/*     */ 
/*     */ 
/*     */   
/* 124 */   public SVGDocument createSVGDocument(String uri) throws IOException { return (SVGDocument)createDocument(uri); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 135 */   public SVGDocument createSVGDocument(String uri, InputStream inp) throws IOException { return (SVGDocument)createDocument(uri, inp); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 146 */   public SVGDocument createSVGDocument(String uri, Reader r) throws IOException { return (SVGDocument)createDocument(uri, r); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String uri) throws IOException {
/* 156 */     ParsedURL purl = new ParsedURL(uri);
/*     */     
/* 158 */     InputStream is = purl.openStream(MimeTypeConstants.MIME_TYPES_SVG);
/*     */     
/* 160 */     InputSource isrc = new InputSource(is);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 166 */     String contentType = purl.getContentType();
/* 167 */     int cindex = -1;
/* 168 */     if (contentType != null) {
/* 169 */       contentType = contentType.toLowerCase();
/* 170 */       cindex = contentType.indexOf("charset");
/*     */     } 
/*     */     
/* 173 */     String charset = null;
/* 174 */     if (cindex != -1) {
/* 175 */       int i = cindex + "charset".length();
/* 176 */       int eqIdx = contentType.indexOf('=', i);
/* 177 */       if (eqIdx != -1) {
/* 178 */         eqIdx++;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 185 */         int idx = contentType.indexOf(',', eqIdx);
/* 186 */         int semiIdx = contentType.indexOf(';', eqIdx);
/* 187 */         if (semiIdx != -1 && (semiIdx < idx || idx == -1))
/* 188 */           idx = semiIdx; 
/* 189 */         if (idx != -1) {
/* 190 */           charset = contentType.substring(eqIdx, idx);
/*     */         } else {
/* 192 */           charset = contentType.substring(eqIdx);
/* 193 */         }  charset = charset.trim();
/* 194 */         isrc.setEncoding(charset);
/*     */       } 
/*     */     } 
/*     */     
/* 198 */     isrc.setSystemId(uri);
/*     */     
/* 200 */     SVGOMDocument doc = (SVGOMDocument)createDocument("http://www.w3.org/2000/svg", "svg", uri, isrc);
/*     */     
/* 202 */     doc.setParsedURL(purl);
/* 203 */     doc.setDocumentInputEncoding(charset);
/* 204 */     doc.setXmlStandalone(this.isStandalone);
/* 205 */     doc.setXmlVersion(this.xmlVersion);
/*     */     
/* 207 */     return doc;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String uri, InputStream inp) throws IOException {
/*     */     Document doc;
/* 219 */     InputSource is = new InputSource(inp);
/* 220 */     is.setSystemId(uri);
/*     */     
/*     */     try {
/* 223 */       doc = createDocument("http://www.w3.org/2000/svg", "svg", uri, is);
/*     */       
/* 225 */       if (uri != null) {
/* 226 */         ((SVGOMDocument)doc).setParsedURL(new ParsedURL(uri));
/*     */       }
/*     */       
/* 229 */       AbstractDocument d = (AbstractDocument)doc;
/* 230 */       d.setDocumentURI(uri);
/* 231 */       d.setXmlStandalone(this.isStandalone);
/* 232 */       d.setXmlVersion(this.xmlVersion);
/*     */     } catch (MalformedURLException e) {
/* 234 */       throw new IOException(e.getMessage());
/*     */     } 
/* 236 */     return doc;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String uri, Reader r) throws IOException {
/*     */     Document doc;
/* 248 */     InputSource is = new InputSource(r);
/* 249 */     is.setSystemId(uri);
/*     */     
/*     */     try {
/* 252 */       doc = createDocument("http://www.w3.org/2000/svg", "svg", uri, is);
/*     */       
/* 254 */       if (uri != null) {
/* 255 */         ((SVGOMDocument)doc).setParsedURL(new ParsedURL(uri));
/*     */       }
/*     */       
/* 258 */       AbstractDocument d = (AbstractDocument)doc;
/* 259 */       d.setDocumentURI(uri);
/* 260 */       d.setXmlStandalone(this.isStandalone);
/* 261 */       d.setXmlVersion(this.xmlVersion);
/*     */     } catch (MalformedURLException e) {
/* 263 */       throw new IOException(e.getMessage());
/*     */     } 
/* 265 */     return doc;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri) throws IOException {
/* 277 */     if (!"http://www.w3.org/2000/svg".equals(ns) || !"svg".equals(root))
/*     */     {
/* 279 */       throw new RuntimeException("Bad root element");
/*     */     }
/* 281 */     return createDocument(uri);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri, InputStream is) throws IOException {
/* 294 */     if (!"http://www.w3.org/2000/svg".equals(ns) || !"svg".equals(root))
/*     */     {
/* 296 */       throw new RuntimeException("Bad root element");
/*     */     }
/* 298 */     return createDocument(uri, is);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri, Reader r) throws IOException {
/* 311 */     if (!"http://www.w3.org/2000/svg".equals(ns) || !"svg".equals(root))
/*     */     {
/* 313 */       throw new RuntimeException("Bad root element");
/*     */     }
/* 315 */     return createDocument(uri, r);
/*     */   }
/*     */   
/*     */   public DOMImplementation getDOMImplementation(String ver) {
/* 319 */     if (ver == null || ver.length() == 0 || ver.equals("1.0") || ver.equals("1.1"))
/*     */     {
/* 321 */       return SVGDOMImplementation.getDOMImplementation(); } 
/* 322 */     if (ver.equals("1.2")) {
/* 323 */       return SVG12DOMImplementation.getDOMImplementation();
/*     */     }
/* 325 */     throw new RuntimeException("Unsupport SVG version '" + ver + "'");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 333 */   public void startDocument() throws SAXException { super.startDocument(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public InputSource resolveEntity(String publicId, String systemId) throws SAXException {
/*     */     try {
/* 346 */       synchronized (LOCK) {
/*     */         
/* 348 */         if (dtdProps == null) {
/* 349 */           dtdProps = new Properties();
/*     */           try {
/* 351 */             Class cls = SAXSVGDocumentFactory.class;
/* 352 */             InputStream is = cls.getResourceAsStream("resources/dtdids.properties");
/*     */             
/* 354 */             dtdProps.load(is);
/*     */           } catch (IOException ioe) {
/* 356 */             throw new SAXException(ioe);
/*     */           } 
/*     */         } 
/*     */         
/* 360 */         if (dtdids == null) {
/* 361 */           dtdids = dtdProps.getProperty("publicIds");
/*     */         }
/* 363 */         if (skippable_dtdids == null) {
/* 364 */           skippable_dtdids = dtdProps.getProperty("skippablePublicIds");
/*     */         }
/*     */         
/* 367 */         if (skip_dtd == null) {
/* 368 */           skip_dtd = dtdProps.getProperty("skipDTD");
/*     */         }
/*     */       } 
/* 371 */       if (publicId == null) {
/* 372 */         return null;
/*     */       }
/* 374 */       if (!this.isValidating && skippable_dtdids.indexOf(publicId) != -1)
/*     */       {
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 380 */         return new InputSource(new StringReader(skip_dtd));
/*     */       }
/*     */       
/* 383 */       if (dtdids.indexOf(publicId) != -1) {
/* 384 */         String localSystemId = dtdProps.getProperty("systemId." + publicId.replace(' ', '_'));
/*     */ 
/*     */ 
/*     */         
/* 388 */         if (localSystemId != null && !"".equals(localSystemId)) {
/* 389 */           return new InputSource(getClass().getResource(localSystemId).toString());
/*     */         }
/*     */       } 
/*     */     } catch (MissingResourceException e) {
/*     */       
/* 394 */       throw new SAXException(e);
/*     */     } 
/*     */     
/* 397 */     return null;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SAXSVGDocumentFactory.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */