/*      */ package org.apache.batik.dom.svg;
/*      */ 
/*      */ import java.net.URL;
/*      */ import org.apache.batik.css.dom.CSSOMSVGViewCSS;
/*      */ import org.apache.batik.css.engine.CSSContext;
/*      */ import org.apache.batik.css.engine.CSSEngine;
/*      */ import org.apache.batik.css.engine.SVGCSSEngine;
/*      */ import org.apache.batik.css.engine.value.ShorthandManager;
/*      */ import org.apache.batik.css.engine.value.ValueManager;
/*      */ import org.apache.batik.css.parser.ExtendedParser;
/*      */ import org.apache.batik.dom.AbstractDocument;
/*      */ import org.apache.batik.dom.AbstractStylableDocument;
/*      */ import org.apache.batik.dom.ExtensibleDOMImplementation;
/*      */ import org.apache.batik.dom.GenericDocumentType;
/*      */ import org.apache.batik.dom.events.DOMTimeEvent;
/*      */ import org.apache.batik.dom.events.DocumentEventSupport;
/*      */ import org.apache.batik.dom.util.CSSStyleDeclarationFactory;
/*      */ import org.apache.batik.dom.util.DOMUtilities;
/*      */ import org.apache.batik.dom.util.HashTable;
/*      */ import org.apache.batik.i18n.LocalizableSupport;
/*      */ import org.apache.batik.util.ParsedURL;
/*      */ import org.w3c.css.sac.InputSource;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.DOMImplementation;
/*      */ import org.w3c.dom.Document;
/*      */ import org.w3c.dom.DocumentType;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.css.CSSStyleDeclaration;
/*      */ import org.w3c.dom.css.CSSStyleSheet;
/*      */ import org.w3c.dom.css.ViewCSS;
/*      */ import org.w3c.dom.events.Event;
/*      */ import org.w3c.dom.stylesheets.StyleSheet;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class SVGDOMImplementation
/*      */   extends ExtensibleDOMImplementation
/*      */   implements CSSStyleDeclarationFactory
/*      */ {
/*      */   public static final String SVG_NAMESPACE_URI = "http://www.w3.org/2000/svg";
/*      */   protected static final String RESOURCES = "org.apache.batik.dom.svg.resources.Messages";
/*      */   protected HashTable factories;
/*      */   
/*   85 */   public static DOMImplementation getDOMImplementation() { return DOM_IMPLEMENTATION; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public SVGDOMImplementation() {
/*   92 */     this.factories = svg11Factories;
/*   93 */     registerFeature("CSS", "2.0");
/*   94 */     registerFeature("StyleSheets", "2.0");
/*   95 */     registerFeature("SVG", new String[] { "1.0", "1.1" });
/*   96 */     registerFeature("SVGEvents", new String[] { "1.0", "1.1" });
/*      */   }
/*      */ 
/*      */   
/*  100 */   protected void initLocalizable() { this.localizableSupport = new LocalizableSupport("org.apache.batik.dom.svg.resources.Messages", getClass().getClassLoader()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public CSSEngine createCSSEngine(AbstractStylableDocument doc, CSSContext ctx, ExtendedParser ep, ValueManager[] vms, ShorthandManager[] sms) {
/*  110 */     ParsedURL durl = ((SVGOMDocument)doc).getParsedURL();
/*  111 */     SVGCSSEngine sVGCSSEngine = new SVGCSSEngine(doc, durl, ep, vms, sms, ctx);
/*      */     
/*  113 */     URL url = getClass().getResource("resources/UserAgentStyleSheet.css");
/*  114 */     if (url != null) {
/*  115 */       ParsedURL purl = new ParsedURL(url);
/*  116 */       InputSource is = new InputSource(purl.toString());
/*  117 */       sVGCSSEngine.setUserAgentStyleSheet(sVGCSSEngine.parseStyleSheet(is, purl, "all"));
/*      */     } 
/*      */ 
/*      */     
/*  121 */     return sVGCSSEngine;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  128 */   public ViewCSS createViewCSS(AbstractStylableDocument doc) { return new CSSOMSVGViewCSS(doc.getCSSEngine()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  138 */   public DocumentType createDocumentType(String qualifiedName, String publicId, String systemId) { return new GenericDocumentType(qualifiedName, publicId, systemId); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Document createDocument(String namespaceURI, String qualifiedName, DocumentType doctype) throws DOMException {
/*  149 */     SVGOMDocument sVGOMDocument = new SVGOMDocument(doctype, this);
/*      */     
/*  151 */     if (qualifiedName != null) {
/*  152 */       sVGOMDocument.appendChild(sVGOMDocument.createElementNS(namespaceURI, qualifiedName));
/*      */     }
/*  154 */     return sVGOMDocument;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  164 */   public CSSStyleSheet createCSSStyleSheet(String title, String media) { throw new UnsupportedOperationException("DOMImplementationCSS.createCSSStyleSheet is not implemented"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  175 */   public CSSStyleDeclaration createCSSStyleDeclaration() { throw new UnsupportedOperationException("CSSStyleDeclarationFactory.createCSSStyleDeclaration is not implemented"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  186 */   public StyleSheet createStyleSheet(Node n, HashTable attrs) { throw new UnsupportedOperationException("StyleSheetFactory.createStyleSheet is not implemented"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  194 */   public CSSStyleSheet getUserAgentStyleSheet() { throw new UnsupportedOperationException("StyleSheetFactory.getUserAgentStyleSheet is not implemented"); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element createElementNS(AbstractDocument document, String namespaceURI, String qualifiedName) {
/*  205 */     if ("http://www.w3.org/2000/svg".equals(namespaceURI)) {
/*  206 */       String name = DOMUtilities.getLocalName(qualifiedName);
/*  207 */       ExtensibleDOMImplementation.ElementFactory ef = (ExtensibleDOMImplementation.ElementFactory)this.factories.get(name);
/*  208 */       if (ef != null) {
/*  209 */         return ef.create(DOMUtilities.getPrefix(qualifiedName), document);
/*      */       }
/*  211 */       throw document.createDOMException((short)8, "invalid.element", new Object[] { namespaceURI, qualifiedName });
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  216 */     return super.createElementNS(document, namespaceURI, qualifiedName);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public DocumentEventSupport createDocumentEventSupport() {
/*  224 */     DocumentEventSupport result = new DocumentEventSupport();
/*  225 */     result.registerEventFactory("SVGEvents", new DocumentEventSupport.EventFactory(this) {
/*      */           private final SVGDOMImplementation this$0;
/*      */           
/*  228 */           public Event createEvent() { return new SVGOMEvent(); }
/*      */         
/*      */         });
/*  231 */     result.registerEventFactory("TimeEvent", new DocumentEventSupport.EventFactory(this) {
/*      */           private final SVGDOMImplementation this$0;
/*      */           
/*  234 */           public Event createEvent() { return new DOMTimeEvent(); }
/*      */         
/*      */         });
/*  237 */     return result;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  245 */   protected static HashTable svg11Factories = new HashTable();
/*      */   
/*      */   static  {
/*  248 */     svg11Factories.put("a", new AElementFactory());
/*      */ 
/*      */     
/*  251 */     svg11Factories.put("altGlyph", new AltGlyphElementFactory());
/*      */ 
/*      */     
/*  254 */     svg11Factories.put("altGlyphDef", new AltGlyphDefElementFactory());
/*      */ 
/*      */     
/*  257 */     svg11Factories.put("altGlyphItem", new AltGlyphItemElementFactory());
/*      */ 
/*      */     
/*  260 */     svg11Factories.put("animate", new AnimateElementFactory());
/*      */ 
/*      */     
/*  263 */     svg11Factories.put("animateColor", new AnimateColorElementFactory());
/*      */ 
/*      */     
/*  266 */     svg11Factories.put("animateMotion", new AnimateMotionElementFactory());
/*      */ 
/*      */     
/*  269 */     svg11Factories.put("animateTransform", new AnimateTransformElementFactory());
/*      */ 
/*      */     
/*  272 */     svg11Factories.put("circle", new CircleElementFactory());
/*      */ 
/*      */     
/*  275 */     svg11Factories.put("clipPath", new ClipPathElementFactory());
/*      */ 
/*      */     
/*  278 */     svg11Factories.put("color-profile", new ColorProfileElementFactory());
/*      */ 
/*      */     
/*  281 */     svg11Factories.put("cursor", new CursorElementFactory());
/*      */ 
/*      */     
/*  284 */     svg11Factories.put("definition-src", new DefinitionSrcElementFactory());
/*      */ 
/*      */     
/*  287 */     svg11Factories.put("defs", new DefsElementFactory());
/*      */ 
/*      */     
/*  290 */     svg11Factories.put("desc", new DescElementFactory());
/*      */ 
/*      */     
/*  293 */     svg11Factories.put("ellipse", new EllipseElementFactory());
/*      */ 
/*      */     
/*  296 */     svg11Factories.put("feBlend", new FeBlendElementFactory());
/*      */ 
/*      */     
/*  299 */     svg11Factories.put("feColorMatrix", new FeColorMatrixElementFactory());
/*      */ 
/*      */     
/*  302 */     svg11Factories.put("feComponentTransfer", new FeComponentTransferElementFactory());
/*      */ 
/*      */     
/*  305 */     svg11Factories.put("feComposite", new FeCompositeElementFactory());
/*      */ 
/*      */     
/*  308 */     svg11Factories.put("feConvolveMatrix", new FeConvolveMatrixElementFactory());
/*      */ 
/*      */     
/*  311 */     svg11Factories.put("feDiffuseLighting", new FeDiffuseLightingElementFactory());
/*      */ 
/*      */     
/*  314 */     svg11Factories.put("feDisplacementMap", new FeDisplacementMapElementFactory());
/*      */ 
/*      */     
/*  317 */     svg11Factories.put("feDistantLight", new FeDistantLightElementFactory());
/*      */ 
/*      */     
/*  320 */     svg11Factories.put("feFlood", new FeFloodElementFactory());
/*      */ 
/*      */     
/*  323 */     svg11Factories.put("feFuncA", new FeFuncAElementFactory());
/*      */ 
/*      */     
/*  326 */     svg11Factories.put("feFuncR", new FeFuncRElementFactory());
/*      */ 
/*      */     
/*  329 */     svg11Factories.put("feFuncG", new FeFuncGElementFactory());
/*      */ 
/*      */     
/*  332 */     svg11Factories.put("feFuncB", new FeFuncBElementFactory());
/*      */ 
/*      */     
/*  335 */     svg11Factories.put("feGaussianBlur", new FeGaussianBlurElementFactory());
/*      */ 
/*      */     
/*  338 */     svg11Factories.put("feImage", new FeImageElementFactory());
/*      */ 
/*      */     
/*  341 */     svg11Factories.put("feMerge", new FeMergeElementFactory());
/*      */ 
/*      */     
/*  344 */     svg11Factories.put("feMergeNode", new FeMergeNodeElementFactory());
/*      */ 
/*      */     
/*  347 */     svg11Factories.put("feMorphology", new FeMorphologyElementFactory());
/*      */ 
/*      */     
/*  350 */     svg11Factories.put("feOffset", new FeOffsetElementFactory());
/*      */ 
/*      */     
/*  353 */     svg11Factories.put("fePointLight", new FePointLightElementFactory());
/*      */ 
/*      */     
/*  356 */     svg11Factories.put("feSpecularLighting", new FeSpecularLightingElementFactory());
/*      */ 
/*      */     
/*  359 */     svg11Factories.put("feSpotLight", new FeSpotLightElementFactory());
/*      */ 
/*      */     
/*  362 */     svg11Factories.put("feTile", new FeTileElementFactory());
/*      */ 
/*      */     
/*  365 */     svg11Factories.put("feTurbulence", new FeTurbulenceElementFactory());
/*      */ 
/*      */     
/*  368 */     svg11Factories.put("filter", new FilterElementFactory());
/*      */ 
/*      */     
/*  371 */     svg11Factories.put("font", new FontElementFactory());
/*      */ 
/*      */     
/*  374 */     svg11Factories.put("font-face", new FontFaceElementFactory());
/*      */ 
/*      */     
/*  377 */     svg11Factories.put("font-face-format", new FontFaceFormatElementFactory());
/*      */ 
/*      */     
/*  380 */     svg11Factories.put("font-face-name", new FontFaceNameElementFactory());
/*      */ 
/*      */     
/*  383 */     svg11Factories.put("font-face-src", new FontFaceSrcElementFactory());
/*      */ 
/*      */     
/*  386 */     svg11Factories.put("font-face-uri", new FontFaceUriElementFactory());
/*      */ 
/*      */     
/*  389 */     svg11Factories.put("foreignObject", new ForeignObjectElementFactory());
/*      */ 
/*      */     
/*  392 */     svg11Factories.put("g", new GElementFactory());
/*      */ 
/*      */     
/*  395 */     svg11Factories.put("glyph", new GlyphElementFactory());
/*      */ 
/*      */     
/*  398 */     svg11Factories.put("glyphRef", new GlyphRefElementFactory());
/*      */ 
/*      */     
/*  401 */     svg11Factories.put("hkern", new HkernElementFactory());
/*      */ 
/*      */     
/*  404 */     svg11Factories.put("image", new ImageElementFactory());
/*      */ 
/*      */     
/*  407 */     svg11Factories.put("line", new LineElementFactory());
/*      */ 
/*      */     
/*  410 */     svg11Factories.put("linearGradient", new LinearGradientElementFactory());
/*      */ 
/*      */     
/*  413 */     svg11Factories.put("marker", new MarkerElementFactory());
/*      */ 
/*      */     
/*  416 */     svg11Factories.put("mask", new MaskElementFactory());
/*      */ 
/*      */     
/*  419 */     svg11Factories.put("metadata", new MetadataElementFactory());
/*      */ 
/*      */     
/*  422 */     svg11Factories.put("missing-glyph", new MissingGlyphElementFactory());
/*      */ 
/*      */     
/*  425 */     svg11Factories.put("mpath", new MpathElementFactory());
/*      */ 
/*      */     
/*  428 */     svg11Factories.put("path", new PathElementFactory());
/*      */ 
/*      */     
/*  431 */     svg11Factories.put("pattern", new PatternElementFactory());
/*      */ 
/*      */     
/*  434 */     svg11Factories.put("polygon", new PolygonElementFactory());
/*      */ 
/*      */     
/*  437 */     svg11Factories.put("polyline", new PolylineElementFactory());
/*      */ 
/*      */     
/*  440 */     svg11Factories.put("radialGradient", new RadialGradientElementFactory());
/*      */ 
/*      */     
/*  443 */     svg11Factories.put("rect", new RectElementFactory());
/*      */ 
/*      */     
/*  446 */     svg11Factories.put("set", new SetElementFactory());
/*      */ 
/*      */     
/*  449 */     svg11Factories.put("script", new ScriptElementFactory());
/*      */ 
/*      */     
/*  452 */     svg11Factories.put("stop", new StopElementFactory());
/*      */ 
/*      */     
/*  455 */     svg11Factories.put("style", new StyleElementFactory());
/*      */ 
/*      */     
/*  458 */     svg11Factories.put("svg", new SvgElementFactory());
/*      */ 
/*      */     
/*  461 */     svg11Factories.put("switch", new SwitchElementFactory());
/*      */ 
/*      */     
/*  464 */     svg11Factories.put("symbol", new SymbolElementFactory());
/*      */ 
/*      */     
/*  467 */     svg11Factories.put("text", new TextElementFactory());
/*      */ 
/*      */     
/*  470 */     svg11Factories.put("textPath", new TextPathElementFactory());
/*      */ 
/*      */     
/*  473 */     svg11Factories.put("title", new TitleElementFactory());
/*      */ 
/*      */     
/*  476 */     svg11Factories.put("tref", new TrefElementFactory());
/*      */ 
/*      */     
/*  479 */     svg11Factories.put("tspan", new TspanElementFactory());
/*      */ 
/*      */     
/*  482 */     svg11Factories.put("use", new UseElementFactory());
/*      */ 
/*      */     
/*  485 */     svg11Factories.put("view", new ViewElementFactory());
/*      */ 
/*      */     
/*  488 */     svg11Factories.put("vkern", new VkernElementFactory());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1596 */     DOM_IMPLEMENTATION = new SVGDOMImplementation();
/*      */   }
/*      */   
/*      */   protected static final DOMImplementation DOM_IMPLEMENTATION;
/*      */   
/*      */   protected static class AElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AltGlyphElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAltGlyphElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AltGlyphDefElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAltGlyphDefElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AltGlyphItemElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAltGlyphItemElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AnimateElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAnimateElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AnimateColorElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAnimateColorElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AnimateMotionElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAnimateMotionElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class AnimateTransformElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMAnimateTransformElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class CircleElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMCircleElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ClipPathElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMClipPathElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ColorProfileElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMColorProfileElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class CursorElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMCursorElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class DefinitionSrcElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMDefinitionSrcElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class DefsElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMDefsElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class DescElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMDescElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class EllipseElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMEllipseElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeBlendElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEBlendElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeColorMatrixElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEColorMatrixElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeComponentTransferElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEComponentTransferElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeCompositeElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFECompositeElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeConvolveMatrixElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEConvolveMatrixElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeDiffuseLightingElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEDiffuseLightingElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeDisplacementMapElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEDisplacementMapElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeDistantLightElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEDistantLightElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeFloodElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEFloodElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeFuncAElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEFuncAElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeFuncRElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEFuncRElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeFuncGElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEFuncGElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeFuncBElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEFuncBElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeGaussianBlurElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEGaussianBlurElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeImageElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEImageElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeMergeElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEMergeElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeMergeNodeElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEMergeNodeElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeMorphologyElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEMorphologyElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeOffsetElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEOffsetElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FePointLightElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFEPointLightElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeSpecularLightingElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFESpecularLightingElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeSpotLightElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFESpotLightElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeTileElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFETileElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FeTurbulenceElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFETurbulenceElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FilterElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFilterElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontFaceElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontFaceElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontFaceFormatElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontFaceFormatElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontFaceNameElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontFaceNameElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontFaceSrcElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontFaceSrcElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class FontFaceUriElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMFontFaceUriElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ForeignObjectElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMForeignObjectElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class GElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMGElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class GlyphElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMGlyphElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class GlyphRefElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMGlyphRefElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class HkernElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMHKernElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ImageElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMImageElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class LineElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMLineElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class LinearGradientElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMLinearGradientElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class MarkerElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMMarkerElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class MaskElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMMaskElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class MetadataElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMMetadataElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class MissingGlyphElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMMissingGlyphElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class MpathElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMMPathElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class PathElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMPathElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class PatternElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMPatternElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class PolygonElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMPolygonElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class PolylineElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMPolylineElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class RadialGradientElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMRadialGradientElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class RectElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMRectElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ScriptElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMScriptElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class SetElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMSetElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class StopElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMStopElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class StyleElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMStyleElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class SvgElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMSVGElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class SwitchElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMSwitchElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class SymbolElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMSymbolElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class TextElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMTextElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class TextPathElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMTextPathElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class TitleElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMTitleElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class TrefElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMTRefElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class TspanElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMTSpanElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class UseElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMUseElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class ViewElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMViewElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */   
/*      */   protected static class VkernElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*      */     public Element create(String prefix, Document doc) { return new SVGOMVKernElement(prefix, (AbstractDocument)doc); }
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGDOMImplementation.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */