/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.awt.geom.AffineTransform;
/*     */ import org.apache.batik.anim.values.AnimatableMotionPointValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedTransformList;
/*     */ import org.w3c.dom.svg.SVGElement;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ import org.w3c.dom.svg.SVGStringList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class SVGGraphicsElement
/*     */   extends SVGStylableElement
/*     */   implements SVGMotionAnimatableElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected SVGOMAnimatedTransformList transform;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   protected AffineTransform motionTransform;
/*     */   
/*     */   static  {
/*  53 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  55 */     t.put(null, "transform", new TraitInformation(true, 9));
/*     */     
/*  57 */     t.put(null, "externalResourcesRequired", new TraitInformation(true, 49));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  65 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGGraphicsElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGGraphicsElement(String prefix, AbstractDocument owner) {
/*  96 */     super(prefix, owner);
/*  97 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 104 */     super.initializeAllLiveAttributes();
/* 105 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 112 */     this.transform = createLiveAnimatedTransformList(null, "transform", "");
/*     */     
/* 114 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 123 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 133 */   public SVGElement getNearestViewportElement() { return SVGLocatableSupport.getNearestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 141 */   public SVGElement getFarthestViewportElement() { return SVGLocatableSupport.getFarthestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 149 */   public SVGRect getBBox() { return SVGLocatableSupport.getBBox(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 157 */   public SVGMatrix getCTM() { return SVGLocatableSupport.getCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 165 */   public SVGMatrix getScreenCTM() { return SVGLocatableSupport.getScreenCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 174 */   public SVGMatrix getTransformToElement(SVGElement element) throws SVGException { return SVGLocatableSupport.getTransformToElement(this, element); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 184 */   public SVGAnimatedTransformList getTransform() { return this.transform; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 194 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 203 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 210 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 217 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 224 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 234 */   public SVGStringList getRequiredFeatures() { return SVGTestsSupport.getRequiredFeatures(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 242 */   public SVGStringList getRequiredExtensions() { return SVGTestsSupport.getRequiredExtensions(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 250 */   public SVGStringList getSystemLanguage() { return SVGTestsSupport.getSystemLanguage(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 258 */   public boolean hasExtension(String extension) { return SVGTestsSupport.hasExtension(this, extension); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 268 */   public AffineTransform getMotionTransform() { return this.motionTransform; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updateOtherValue(String type, AnimatableValue val) {
/* 277 */     if (type.equals("motion")) {
/* 278 */       if (this.motionTransform == null) {
/* 279 */         this.motionTransform = new AffineTransform();
/*     */       }
/* 281 */       if (val == null) {
/* 282 */         this.motionTransform.setToIdentity();
/*     */       } else {
/* 284 */         AnimatableMotionPointValue p = (AnimatableMotionPointValue)val;
/* 285 */         this.motionTransform.setToTranslation(p.getX(), p.getY());
/* 286 */         this.motionTransform.rotate(p.getAngle());
/*     */       } 
/* 288 */       SVGOMDocument d = (SVGOMDocument)this.ownerDocument;
/* 289 */       d.getAnimatedAttributeListener().otherAnimationChanged(this, type);
/*     */     } else {
/* 291 */       super.updateOtherValue(type, val);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGGraphicsElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */