/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.awt.geom.AffineTransform;
/*     */ import java.awt.geom.NoninvertibleTransformException;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.svg.SVGElement;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGLocatableSupport
/*     */ {
/*     */   public static SVGElement getNearestViewportElement(Element e) {
/*  52 */     CSSStylableElement cSSStylableElement = e;
/*  53 */     while (cSSStylableElement != null) {
/*  54 */       cSSStylableElement = CSSEngine.getParentCSSStylableElement(cSSStylableElement);
/*  55 */       if (cSSStylableElement instanceof org.w3c.dom.svg.SVGFitToViewBox) {
/*     */         break;
/*     */       }
/*     */     } 
/*  59 */     return (SVGElement)cSSStylableElement;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  67 */   public static SVGElement getFarthestViewportElement(Element elt) { return (SVGElement)elt.getOwnerDocument().getDocumentElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static SVGRect getBBox(Element elt) {
/*  74 */     SVGOMElement svgelt = (SVGOMElement)elt;
/*  75 */     SVGContext svgctx = svgelt.getSVGContext();
/*  76 */     if (svgctx == null) return null; 
/*  77 */     if (svgctx.getBBox() == null) return null;
/*     */     
/*  79 */     return new SVGRect(svgelt) { private final SVGOMElement val$svgelt;
/*     */         
/*  81 */         public float getX() { return (float)this.val$svgelt.getSVGContext().getBBox().getX(); }
/*     */ 
/*     */         
/*  84 */         public void setX(float x) throws DOMException { throw this.val$svgelt.createDOMException((short)7, "readonly.rect", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*  89 */         public float getY() { return (float)this.val$svgelt.getSVGContext().getBBox().getY(); }
/*     */ 
/*     */         
/*  92 */         public void setY(float y) throws DOMException { throw this.val$svgelt.createDOMException((short)7, "readonly.rect", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*  97 */         public float getWidth() { return (float)this.val$svgelt.getSVGContext().getBBox().getWidth(); }
/*     */ 
/*     */         
/* 100 */         public void setWidth(float width) throws DOMException { throw this.val$svgelt.createDOMException((short)7, "readonly.rect", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 105 */         public float getHeight() { return (float)this.val$svgelt.getSVGContext().getBBox().getHeight(); }
/*     */ 
/*     */         
/* 108 */         public void setHeight(float height) throws DOMException { throw this.val$svgelt.createDOMException((short)7, "readonly.rect", null); } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static SVGMatrix getCTM(Element elt) {
/* 119 */     SVGOMElement svgelt = (SVGOMElement)elt;
/* 120 */     return new AbstractSVGMatrix(svgelt) { private final SVGOMElement val$svgelt;
/*     */         
/* 122 */         protected AffineTransform getAffineTransform() { return this.val$svgelt.getSVGContext().getCTM(); } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static SVGMatrix getScreenCTM(Element elt) {
/* 131 */     SVGOMElement svgelt = (SVGOMElement)elt;
/* 132 */     return new AbstractSVGMatrix(svgelt) {
/*     */         protected AffineTransform getAffineTransform() {
/* 134 */           SVGContext context = this.val$svgelt.getSVGContext();
/* 135 */           AffineTransform ret = context.getGlobalTransform();
/* 136 */           AffineTransform scrnTrans = context.getScreenTransform();
/* 137 */           if (scrnTrans != null)
/* 138 */             ret.preConcatenate(scrnTrans); 
/* 139 */           return ret;
/*     */         }
/*     */ 
/*     */ 
/*     */         
/*     */         private final SVGOMElement val$svgelt;
/*     */       };
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public static SVGMatrix getTransformToElement(Element elt, SVGElement element) throws SVGException {
/* 151 */     SVGOMElement currentElt = (SVGOMElement)elt;
/* 152 */     SVGOMElement targetElt = (SVGOMElement)element;
/* 153 */     return new AbstractSVGMatrix(currentElt, targetElt) {
/*     */         protected AffineTransform getAffineTransform() {
/* 155 */           AffineTransform cat = this.val$currentElt.getSVGContext().getGlobalTransform();
/*     */           
/* 157 */           if (cat == null) {
/* 158 */             cat = new AffineTransform();
/*     */           }
/* 160 */           AffineTransform tat = this.val$targetElt.getSVGContext().getGlobalTransform();
/*     */           
/* 162 */           if (tat == null) {
/* 163 */             tat = new AffineTransform();
/*     */           }
/* 165 */           AffineTransform at = new AffineTransform(cat);
/*     */           try {
/* 167 */             at.preConcatenate(tat.createInverse());
/* 168 */             return at;
/*     */           } catch (NoninvertibleTransformException ex) {
/* 170 */             throw this.val$currentElt.createSVGException((short)2, "noninvertiblematrix", null);
/*     */           } 
/*     */         }
/*     */         
/*     */         private final SVGOMElement val$currentElt;
/*     */         private final SVGOMElement val$targetElt;
/*     */       };
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGLocatableSupport.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */