/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.parser.AngleParser;
/*     */ import org.apache.batik.parser.DefaultAngleHandler;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAngle;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAngle
/*     */   implements SVGAngle
/*     */ {
/*     */   protected short unitType;
/*     */   protected float value;
/*  49 */   protected static final String[] UNITS = { "", "", "deg", "rad", "grad" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public short getUnitType() {
/*  57 */     revalidate();
/*  58 */     return this.unitType;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getValue() {
/*  65 */     revalidate();
/*  66 */     return toUnit(this.unitType, this.value, (short)2);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValue(float value) throws DOMException {
/*  73 */     revalidate();
/*  74 */     this.unitType = 2;
/*  75 */     this.value = value;
/*  76 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getValueInSpecifiedUnits() {
/*  83 */     revalidate();
/*  84 */     return this.value;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValueInSpecifiedUnits(float value) throws DOMException {
/*  92 */     revalidate();
/*  93 */     this.value = value;
/*  94 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getValueAsString() {
/* 101 */     revalidate();
/* 102 */     return Float.toString(this.value) + UNITS[this.unitType];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setValueAsString(String value) throws DOMException {
/* 109 */     parse(value);
/* 110 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void newValueSpecifiedUnits(short unit, float value) {
/* 118 */     this.unitType = unit;
/* 119 */     this.value = value;
/* 120 */     reset();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void convertToSpecifiedUnits(short unit) {
/* 128 */     this.value = toUnit(this.unitType, this.value, unit);
/* 129 */     this.unitType = unit;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void reset() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void revalidate() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void parse(String s) throws DOMException {
/*     */     try {
/* 153 */       AngleParser angleParser = new AngleParser();
/* 154 */       angleParser.setAngleHandler(new DefaultAngleHandler(this)
/*     */           {
/* 156 */             public void angleValue(float v) throws DOMException { this.this$0.value = v; }
/*     */             private final SVGOMAngle this$0;
/*     */             
/* 159 */             public void deg() { this.this$0.unitType = 2; }
/*     */ 
/*     */             
/* 162 */             public void rad() { this.this$0.unitType = 3; }
/*     */             
/*     */             public void grad() {
/* 165 */               this.this$0.unitType = 4;
/*     */             }
/*     */           });
/* 168 */       this.unitType = 1;
/* 169 */       angleParser.parse(s);
/*     */     } catch (ParseException e) {
/* 171 */       this.unitType = 0;
/* 172 */       this.value = 0.0F;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 179 */   protected static double[][] K = { { 1.0D, 0.017453292519943295D, 0.015707963267948967D }, { 57.29577951308232D, 1.0D, 63.66197723675813D }, { 0.9D, 0.015707963267948967D, 1.0D } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static float toUnit(short fromUnit, float value, short toUnit) {
/* 189 */     if (fromUnit == 1) {
/* 190 */       fromUnit = 2;
/*     */     }
/* 192 */     if (toUnit == 1) {
/* 193 */       toUnit = 2;
/*     */     }
/* 195 */     return (float)(K[fromUnit - 2][toUnit - 2] * value);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAngle.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */