/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import org.apache.batik.anim.values.AnimatableLengthListValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.svg.SVGAnimatedLengthList;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ import org.w3c.dom.svg.SVGLengthList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedLengthList
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedLengthList
/*     */ {
/*     */   protected BaseSVGLengthList baseVal;
/*     */   protected AnimSVGLengthList animVal;
/*     */   protected boolean changing;
/*     */   protected String defaultValue;
/*     */   protected boolean emptyAllowed;
/*     */   protected short direction;
/*     */   
/*     */   public SVGOMAnimatedLengthList(AbstractElement elt, String ns, String ln, String defaultValue, boolean emptyAllowed, short direction) {
/*  94 */     super(elt, ns, ln);
/*  95 */     this.defaultValue = defaultValue;
/*  96 */     this.emptyAllowed = emptyAllowed;
/*  97 */     this.direction = direction;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGLengthList getBaseVal() {
/* 104 */     if (this.baseVal == null) {
/* 105 */       this.baseVal = new BaseSVGLengthList(this);
/*     */     }
/* 107 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGLengthList getAnimVal() {
/* 114 */     if (this.animVal == null) {
/* 115 */       this.animVal = new AnimSVGLengthList(this);
/*     */     }
/* 117 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/* 124 */     if (!this.hasAnimVal) {
/* 125 */       if (this.baseVal == null) {
/* 126 */         this.baseVal = new BaseSVGLengthList(this);
/*     */       }
/* 128 */       this.baseVal.revalidate();
/* 129 */       if (this.baseVal.missing) {
/* 130 */         throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */       }
/*     */ 
/*     */       
/* 134 */       if (this.baseVal.malformed) {
/* 135 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 147 */     SVGLengthList ll = getBaseVal();
/* 148 */     int n = ll.getNumberOfItems();
/* 149 */     short[] types = new short[n];
/* 150 */     float[] values = new float[n];
/* 151 */     for (int i = 0; i < n; i++) {
/* 152 */       SVGLength l = ll.getItem(i);
/* 153 */       types[i] = l.getUnitType();
/* 154 */       values[i] = l.getValueInSpecifiedUnits();
/*     */     } 
/* 156 */     return new AnimatableLengthListValue(target, types, values, target.getPercentageInterpretation(getNamespaceURI(), getLocalName(), false));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 166 */     if (val == null) {
/* 167 */       this.hasAnimVal = false;
/*     */     } else {
/* 169 */       this.hasAnimVal = true;
/* 170 */       AnimatableLengthListValue animLengths = (AnimatableLengthListValue)val;
/*     */       
/* 172 */       if (this.animVal == null) {
/* 173 */         this.animVal = new AnimSVGLengthList(this);
/*     */       }
/* 175 */       this.animVal.setAnimatedValue(animLengths.getLengthTypes(), animLengths.getLengthValues());
/*     */     } 
/*     */     
/* 178 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 185 */     if (!this.changing && this.baseVal != null) {
/* 186 */       this.baseVal.invalidate();
/*     */     }
/* 188 */     fireBaseAttributeListeners();
/* 189 */     if (!this.hasAnimVal) {
/* 190 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 198 */     if (!this.changing && this.baseVal != null) {
/* 199 */       this.baseVal.invalidate();
/*     */     }
/* 201 */     fireBaseAttributeListeners();
/* 202 */     if (!this.hasAnimVal) {
/* 203 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 211 */     if (!this.changing && this.baseVal != null) {
/* 212 */       this.baseVal.invalidate();
/*     */     }
/* 214 */     fireBaseAttributeListeners();
/* 215 */     if (!this.hasAnimVal) {
/* 216 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class BaseSVGLengthList
/*     */     extends AbstractSVGLengthList
/*     */   {
/*     */     protected boolean missing;
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean malformed;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGOMAnimatedLengthList this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public BaseSVGLengthList(SVGOMAnimatedLengthList this$0) {
/* 239 */       super(this$0.direction);
/*     */       this.this$0 = this$0;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 247 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 256 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 264 */     protected Element getElement() { return this.this$0.element; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 271 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 272 */       if (attr == null) {
/* 273 */         return this.this$0.defaultValue;
/*     */       }
/* 275 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 283 */         this.this$0.changing = true;
/* 284 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 286 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 294 */       super.resetAttribute();
/* 295 */       this.missing = false;
/* 296 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {
/* 305 */       super.resetAttribute(item);
/* 306 */       this.missing = false;
/* 307 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 314 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 318 */       this.valid = true;
/* 319 */       this.missing = false;
/* 320 */       this.malformed = false;
/*     */       
/* 322 */       String s = getValueAsString();
/* 323 */       boolean isEmpty = (s != null && s.length() == 0);
/* 324 */       if (s == null || (isEmpty && !this.this$0.emptyAllowed)) {
/* 325 */         this.missing = true;
/*     */         return;
/*     */       } 
/* 328 */       if (isEmpty) {
/* 329 */         this.itemList = new ArrayList(1);
/*     */       } else {
/*     */         try {
/* 332 */           AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */           
/* 334 */           doParse(s, builder);
/*     */           
/* 336 */           if (builder.getList() != null) {
/* 337 */             clear(this.itemList);
/*     */           }
/* 339 */           this.itemList = builder.getList();
/*     */         } catch (ParseException e) {
/* 341 */           this.itemList = new ArrayList(1);
/* 342 */           this.valid = true;
/* 343 */           this.malformed = true;
/*     */         } 
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class AnimSVGLengthList
/*     */     extends AbstractSVGLengthList
/*     */   {
/*     */     private final SVGOMAnimatedLengthList this$0;
/*     */ 
/*     */     
/*     */     public AnimSVGLengthList(SVGOMAnimatedLengthList this$0) {
/* 358 */       super(this$0.direction); this.this$0 = this$0;
/* 359 */       this.itemList = new ArrayList(1);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 367 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 376 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 383 */     protected Element getElement() { return this.this$0.element; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public int getNumberOfItems() {
/* 390 */       if (this.this$0.hasAnimVal) {
/* 391 */         return super.getNumberOfItems();
/*     */       }
/* 393 */       return this.this$0.getBaseVal().getNumberOfItems();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public SVGLength getItem(int index) throws DOMException {
/* 400 */       if (this.this$0.hasAnimVal) {
/* 401 */         return super.getItem(index);
/*     */       }
/* 403 */       return this.this$0.getBaseVal().getItem(index);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 410 */       if (this.itemList.size() == 0) {
/* 411 */         return "";
/*     */       }
/* 413 */       StringBuffer sb = new StringBuffer(this.itemList.size() * 8);
/* 414 */       Iterator i = this.itemList.iterator();
/* 415 */       if (i.hasNext()) {
/* 416 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       }
/* 418 */       while (i.hasNext()) {
/* 419 */         sb.append(getItemSeparator());
/* 420 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       } 
/* 422 */       return sb.toString();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 435 */     public void clear() { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 445 */     public SVGLength initialize(SVGLength newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 456 */     public SVGLength insertItemBefore(SVGLength newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 467 */     public SVGLength replaceItem(SVGLength newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 476 */     public SVGLength removeItem(int index) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 485 */     public SVGLength appendItem(SVGLength newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.length.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(short[] types, float[] values) {
/* 494 */       int size = this.itemList.size();
/* 495 */       int i = 0;
/* 496 */       while (i < size && i < types.length) {
/* 497 */         AbstractSVGLengthList.SVGLengthItem l = (AbstractSVGLengthList.SVGLengthItem)this.itemList.get(i);
/* 498 */         l.unitType = types[i];
/* 499 */         l.value = values[i];
/* 500 */         l.direction = this.direction;
/* 501 */         i++;
/*     */       } 
/* 503 */       while (i < types.length) {
/* 504 */         appendItemImpl(new AbstractSVGLengthList.SVGLengthItem(this, types[i], values[i], this.direction));
/*     */         
/* 506 */         i++;
/*     */       } 
/* 508 */       while (size > types.length) {
/* 509 */         removeItemImpl(--size);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 532 */     protected void revalidate() { this.valid = true; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedLengthList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */