/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatableNumberValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedNumber
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedNumber
/*     */ {
/*     */   protected float defaultValue;
/*     */   protected boolean allowPercentage;
/*     */   protected boolean valid;
/*     */   protected float baseVal;
/*     */   protected float animVal;
/*     */   protected boolean changing;
/*     */   
/*  80 */   public SVGOMAnimatedNumber(AbstractElement elt, String ns, String ln, float val) { this(elt, ns, ln, val, false); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMAnimatedNumber(AbstractElement elt, String ns, String ln, float val, boolean allowPercentage) {
/*  96 */     super(elt, ns, ln);
/*  97 */     this.defaultValue = val;
/*  98 */     this.allowPercentage = allowPercentage;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getBaseVal() {
/* 105 */     if (!this.valid) {
/* 106 */       update();
/*     */     }
/* 108 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void update() {
/* 115 */     Attr attr = this.element.getAttributeNodeNS(this.namespaceURI, this.localName);
/* 116 */     if (attr == null) {
/* 117 */       this.baseVal = this.defaultValue;
/*     */     } else {
/* 119 */       String v = attr.getValue();
/* 120 */       int len = v.length();
/* 121 */       if (this.allowPercentage && len > 1 && v.charAt(len - 1) == '%') {
/* 122 */         this.baseVal = 0.01F * Float.parseFloat(v.substring(0, len - 1));
/*     */       } else {
/* 124 */         this.baseVal = Float.parseFloat(v);
/*     */       } 
/*     */     } 
/* 127 */     this.valid = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setBaseVal(float baseVal) throws DOMException {
/*     */     try {
/* 135 */       this.baseVal = baseVal;
/* 136 */       this.valid = true;
/* 137 */       this.changing = true;
/* 138 */       this.element.setAttributeNS(this.namespaceURI, this.localName, String.valueOf(baseVal));
/*     */     } finally {
/*     */       
/* 141 */       this.changing = false;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getAnimVal() {
/* 149 */     if (this.hasAnimVal) {
/* 150 */       return this.animVal;
/*     */     }
/* 152 */     if (!this.valid) {
/* 153 */       update();
/*     */     }
/* 155 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 162 */   public AnimatableValue getUnderlyingValue(AnimationTarget target) { return new AnimatableNumberValue(target, getBaseVal()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 169 */     if (val == null) {
/* 170 */       this.hasAnimVal = false;
/*     */     } else {
/* 172 */       this.hasAnimVal = true;
/* 173 */       this.animVal = ((AnimatableNumberValue)val).getValue();
/*     */     } 
/* 175 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 182 */     if (!this.changing) {
/* 183 */       this.valid = false;
/*     */     }
/* 185 */     fireBaseAttributeListeners();
/* 186 */     if (!this.hasAnimVal) {
/* 187 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 195 */     if (!this.changing) {
/* 196 */       this.valid = false;
/*     */     }
/* 198 */     fireBaseAttributeListeners();
/* 199 */     if (!this.hasAnimVal) {
/* 200 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 208 */     if (!this.changing) {
/* 209 */       this.valid = false;
/*     */     }
/* 211 */     fireBaseAttributeListeners();
/* 212 */     if (!this.hasAnimVal)
/* 213 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedNumber.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */