/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import org.apache.batik.anim.values.AnimatableNumberListValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumberList;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGNumber;
/*     */ import org.w3c.dom.svg.SVGNumberList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedNumberList
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedNumberList
/*     */ {
/*     */   protected BaseSVGNumberList baseVal;
/*     */   protected AnimSVGNumberList animVal;
/*     */   protected boolean changing;
/*     */   protected String defaultValue;
/*     */   protected boolean emptyAllowed;
/*     */   
/*     */   public SVGOMAnimatedNumberList(AbstractElement elt, String ns, String ln, String defaultValue, boolean emptyAllowed) {
/*  87 */     super(elt, ns, ln);
/*  88 */     this.defaultValue = defaultValue;
/*  89 */     this.emptyAllowed = emptyAllowed;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGNumberList getBaseVal() {
/*  96 */     if (this.baseVal == null) {
/*  97 */       this.baseVal = new BaseSVGNumberList(this);
/*     */     }
/*  99 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGNumberList getAnimVal() {
/* 106 */     if (this.animVal == null) {
/* 107 */       this.animVal = new AnimSVGNumberList(this);
/*     */     }
/* 109 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/* 116 */     if (!this.hasAnimVal) {
/* 117 */       if (this.baseVal == null) {
/* 118 */         this.baseVal = new BaseSVGNumberList(this);
/*     */       }
/* 120 */       this.baseVal.revalidate();
/* 121 */       if (this.baseVal.missing) {
/* 122 */         throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */       }
/*     */ 
/*     */       
/* 126 */       if (this.baseVal.malformed) {
/* 127 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 139 */     SVGNumberList nl = getBaseVal();
/* 140 */     int n = nl.getNumberOfItems();
/* 141 */     float[] numbers = new float[n];
/* 142 */     for (int i = 0; i < n; i++) {
/* 143 */       numbers[i] = nl.getItem(n).getValue();
/*     */     }
/* 145 */     return new AnimatableNumberListValue(target, numbers);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 152 */     if (val == null) {
/* 153 */       this.hasAnimVal = false;
/*     */     } else {
/* 155 */       this.hasAnimVal = true;
/* 156 */       AnimatableNumberListValue animNumList = (AnimatableNumberListValue)val;
/*     */       
/* 158 */       if (this.animVal == null) {
/* 159 */         this.animVal = new AnimSVGNumberList(this);
/*     */       }
/* 161 */       this.animVal.setAnimatedValue(animNumList.getNumbers());
/*     */     } 
/* 163 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 170 */     if (!this.changing && this.baseVal != null) {
/* 171 */       this.baseVal.invalidate();
/*     */     }
/* 173 */     fireBaseAttributeListeners();
/* 174 */     if (!this.hasAnimVal) {
/* 175 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 183 */     if (!this.changing && this.baseVal != null) {
/* 184 */       this.baseVal.invalidate();
/*     */     }
/* 186 */     fireBaseAttributeListeners();
/* 187 */     if (!this.hasAnimVal) {
/* 188 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 196 */     if (!this.changing && this.baseVal != null) {
/* 197 */       this.baseVal.invalidate();
/*     */     }
/* 199 */     fireBaseAttributeListeners();
/* 200 */     if (!this.hasAnimVal)
/* 201 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */   
/*     */   public class BaseSVGNumberList
/*     */     extends AbstractSVGNumberList {
/*     */     protected boolean missing;
/*     */     
/* 208 */     public BaseSVGNumberList(SVGOMAnimatedNumberList this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean malformed;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGOMAnimatedNumberList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 225 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 234 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 242 */     protected Element getElement() { return this.this$0.element; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 249 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 250 */       if (attr == null) {
/* 251 */         return this.this$0.defaultValue;
/*     */       }
/* 253 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 261 */         this.this$0.changing = true;
/* 262 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 264 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 272 */       super.resetAttribute();
/* 273 */       this.missing = false;
/* 274 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {
/* 283 */       super.resetAttribute(item);
/* 284 */       this.missing = false;
/* 285 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 292 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 296 */       this.valid = true;
/* 297 */       this.missing = false;
/* 298 */       this.malformed = false;
/*     */       
/* 300 */       String s = getValueAsString();
/* 301 */       boolean isEmpty = (s != null && s.length() == 0);
/* 302 */       if (s == null || (isEmpty && !this.this$0.emptyAllowed)) {
/* 303 */         this.missing = true;
/*     */         return;
/*     */       } 
/* 306 */       if (isEmpty) {
/* 307 */         this.itemList = new ArrayList(1);
/*     */       } else {
/*     */         try {
/* 310 */           AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */           
/* 312 */           doParse(s, builder);
/*     */           
/* 314 */           if (builder.getList() != null) {
/* 315 */             clear(this.itemList);
/*     */           }
/* 317 */           this.itemList = builder.getList();
/*     */         } catch (ParseException e) {
/* 319 */           this.itemList = new ArrayList(1);
/* 320 */           this.valid = true;
/* 321 */           this.malformed = true;
/*     */         } 
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   protected class AnimSVGNumberList
/*     */     extends AbstractSVGNumberList
/*     */   {
/*     */     private final SVGOMAnimatedNumberList this$0;
/*     */ 
/*     */     
/*     */     public AnimSVGNumberList(SVGOMAnimatedNumberList this$0) {
/* 335 */       this.this$0 = this$0;
/* 336 */       this.itemList = new ArrayList(1);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 344 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 353 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 360 */     protected Element getElement() { return this.this$0.element; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public int getNumberOfItems() {
/* 367 */       if (this.this$0.hasAnimVal) {
/* 368 */         return super.getNumberOfItems();
/*     */       }
/* 370 */       return this.this$0.getBaseVal().getNumberOfItems();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public SVGNumber getItem(int index) throws DOMException {
/* 377 */       if (this.this$0.hasAnimVal) {
/* 378 */         return super.getItem(index);
/*     */       }
/* 380 */       return this.this$0.getBaseVal().getItem(index);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 387 */       if (this.itemList.size() == 0) {
/* 388 */         return "";
/*     */       }
/* 390 */       StringBuffer sb = new StringBuffer(this.itemList.size() * 8);
/* 391 */       Iterator i = this.itemList.iterator();
/* 392 */       if (i.hasNext()) {
/* 393 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       }
/* 395 */       while (i.hasNext()) {
/* 396 */         sb.append(getItemSeparator());
/* 397 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       } 
/* 399 */       return sb.toString();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 412 */     public void clear() { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 422 */     public SVGNumber initialize(SVGNumber newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 433 */     public SVGNumber insertItemBefore(SVGNumber newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 444 */     public SVGNumber replaceItem(SVGNumber newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 453 */     public SVGNumber removeItem(int index) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 462 */     public SVGNumber appendItem(SVGNumber newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.number.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(float[] values) {
/* 471 */       int size = this.itemList.size();
/* 472 */       int i = 0;
/* 473 */       while (i < size && i < values.length) {
/* 474 */         AbstractSVGNumberList.SVGNumberItem n = (AbstractSVGNumberList.SVGNumberItem)this.itemList.get(i);
/* 475 */         n.value = values[i];
/* 476 */         i++;
/*     */       } 
/* 478 */       while (i < values.length) {
/* 479 */         appendItemImpl(new AbstractSVGNumberList.SVGNumberItem(this, values[i]));
/* 480 */         i++;
/*     */       } 
/* 482 */       while (size > values.length) {
/* 483 */         removeItemImpl(--size);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 506 */     protected void revalidate() { this.valid = true; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedNumberList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */