/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import org.apache.batik.anim.values.AnimatablePathDataValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.apache.batik.parser.PathArrayProducer;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedPathData;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGPathSeg;
/*     */ import org.w3c.dom.svg.SVGPathSegList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedPathData
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedPathData
/*     */ {
/*     */   protected boolean changing;
/*     */   protected BaseSVGPathSegList pathSegs;
/*     */   protected NormalizedBaseSVGPathSegList normalizedPathSegs;
/*     */   protected AnimSVGPathSegList animPathSegs;
/*     */   protected String defaultValue;
/*     */   
/*     */   public SVGOMAnimatedPathData(AbstractElement elt, String ns, String ln, String defaultValue) {
/*  91 */     super(elt, ns, ln);
/*  92 */     this.defaultValue = defaultValue;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 100 */   public SVGPathSegList getAnimatedNormalizedPathSegList() { throw new UnsupportedOperationException("SVGAnimatedPathData.getAnimatedNormalizedPathSegList is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegList getAnimatedPathSegList() {
/* 109 */     if (this.animPathSegs == null) {
/* 110 */       this.animPathSegs = new AnimSVGPathSegList(this);
/*     */     }
/* 112 */     return this.animPathSegs;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegList getNormalizedPathSegList() {
/* 141 */     if (this.normalizedPathSegs == null) {
/* 142 */       this.normalizedPathSegs = new NormalizedBaseSVGPathSegList(this);
/*     */     }
/* 144 */     return this.normalizedPathSegs;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegList getPathSegList() {
/* 152 */     if (this.pathSegs == null) {
/* 153 */       this.pathSegs = new BaseSVGPathSegList(this);
/*     */     }
/* 155 */     return this.pathSegs;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/* 162 */     if (!this.hasAnimVal) {
/* 163 */       if (this.pathSegs == null) {
/* 164 */         this.pathSegs = new BaseSVGPathSegList(this);
/*     */       }
/* 166 */       this.pathSegs.revalidate();
/* 167 */       if (this.pathSegs.missing) {
/* 168 */         throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */       }
/*     */ 
/*     */       
/* 172 */       if (this.pathSegs.malformed) {
/* 173 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.pathSegs.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 185 */     SVGPathSegList psl = getPathSegList();
/* 186 */     PathArrayProducer pp = new PathArrayProducer();
/* 187 */     SVGAnimatedPathDataSupport.handlePathSegList(psl, pp);
/* 188 */     return new AnimatablePathDataValue(target, pp.getPathCommands(), pp.getPathParameters());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 196 */     if (val == null) {
/* 197 */       this.hasAnimVal = false;
/*     */     } else {
/* 199 */       this.hasAnimVal = true;
/* 200 */       AnimatablePathDataValue animPath = (AnimatablePathDataValue)val;
/* 201 */       if (this.animPathSegs == null) {
/* 202 */         this.animPathSegs = new AnimSVGPathSegList(this);
/*     */       }
/* 204 */       this.animPathSegs.setAnimatedValue(animPath.getCommands(), animPath.getParameters());
/*     */     } 
/*     */     
/* 207 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 214 */     if (!this.changing) {
/* 215 */       if (this.pathSegs != null) {
/* 216 */         this.pathSegs.invalidate();
/*     */       }
/* 218 */       if (this.normalizedPathSegs != null) {
/* 219 */         this.normalizedPathSegs.invalidate();
/*     */       }
/*     */     } 
/* 222 */     fireBaseAttributeListeners();
/* 223 */     if (!this.hasAnimVal) {
/* 224 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 232 */     if (!this.changing) {
/* 233 */       if (this.pathSegs != null) {
/* 234 */         this.pathSegs.invalidate();
/*     */       }
/* 236 */       if (this.normalizedPathSegs != null) {
/* 237 */         this.normalizedPathSegs.invalidate();
/*     */       }
/*     */     } 
/* 240 */     fireBaseAttributeListeners();
/* 241 */     if (!this.hasAnimVal) {
/* 242 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 250 */     if (!this.changing) {
/* 251 */       if (this.pathSegs != null) {
/* 252 */         this.pathSegs.invalidate();
/*     */       }
/* 254 */       if (this.normalizedPathSegs != null) {
/* 255 */         this.normalizedPathSegs.invalidate();
/*     */       }
/*     */     } 
/* 258 */     fireBaseAttributeListeners();
/* 259 */     if (!this.hasAnimVal)
/* 260 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */   
/*     */   public class BaseSVGPathSegList extends AbstractSVGPathSegList { protected boolean missing;
/*     */     protected boolean malformed;
/*     */     private final SVGOMAnimatedPathData this$0;
/*     */     
/* 267 */     public BaseSVGPathSegList(SVGOMAnimatedPathData this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 284 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 292 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 299 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 300 */       if (attr == null) {
/* 301 */         return this.this$0.defaultValue;
/*     */       }
/* 303 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 311 */         this.this$0.changing = true;
/* 312 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 314 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 322 */       super.resetAttribute();
/* 323 */       this.missing = false;
/* 324 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {
/* 333 */       super.resetAttribute(item);
/* 334 */       this.missing = false;
/* 335 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 342 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 346 */       this.valid = true;
/* 347 */       this.missing = false;
/* 348 */       this.malformed = false;
/*     */       
/* 350 */       String s = getValueAsString();
/* 351 */       if (s == null) {
/* 352 */         this.missing = true;
/*     */         return;
/*     */       } 
/*     */       try {
/* 356 */         AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */         
/* 358 */         doParse(s, builder);
/*     */         
/* 360 */         if (builder.getList() != null) {
/* 361 */           clear(this.itemList);
/*     */         }
/* 363 */         this.itemList = builder.getList();
/*     */       } catch (ParseException e) {
/* 365 */         this.itemList = new ArrayList(1);
/* 366 */         this.malformed = true;
/*     */       } 
/*     */     } }
/*     */   
/*     */   public class NormalizedBaseSVGPathSegList extends AbstractSVGNormPathSegList {
/*     */     protected boolean missing;
/*     */     protected boolean malformed;
/*     */     private final SVGOMAnimatedPathData this$0;
/*     */     
/* 375 */     public NormalizedBaseSVGPathSegList(SVGOMAnimatedPathData this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 393 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 401 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 408 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 409 */       if (attr == null) {
/* 410 */         return this.this$0.defaultValue;
/*     */       }
/* 412 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 420 */         this.this$0.changing = true;
/* 421 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 423 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 431 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 435 */       this.valid = true;
/* 436 */       this.missing = false;
/* 437 */       this.malformed = false;
/*     */       
/* 439 */       String s = getValueAsString();
/* 440 */       if (s == null) {
/* 441 */         this.missing = true;
/*     */         return;
/*     */       } 
/*     */       try {
/* 445 */         AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */         
/* 447 */         doParse(s, builder);
/*     */         
/* 449 */         if (builder.getList() != null) {
/* 450 */           clear(this.itemList);
/*     */         }
/* 452 */         this.itemList = builder.getList();
/*     */       } catch (ParseException e) {
/* 454 */         this.itemList = new ArrayList(1);
/* 455 */         this.malformed = true;
/*     */       } 
/*     */     }
/*     */   } public class AnimSVGPathSegList extends AbstractSVGPathSegList {
/*     */     private int[] parameterIndex; private final SVGOMAnimatedPathData this$0; protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); } protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); } public int getNumberOfItems() { if (this.this$0.hasAnimVal)
/*     */         return super.getNumberOfItems();  return this.this$0.getPathSegList().getNumberOfItems(); } public SVGPathSeg getItem(int index) throws DOMException { if (this.this$0.hasAnimVal)
/*     */         return super.getItem(index);  return this.this$0.getPathSegList().getItem(index); } protected String getValueAsString() { if (this.itemList.size() == 0)
/*     */         return "";  StringBuffer sb = new StringBuffer(this.itemList.size() * 8); Iterator i = this.itemList.iterator(); if (i.hasNext())
/*     */         sb.append(((SVGItem)i.next()).getValueAsString()); 
/*     */       while (i.hasNext()) {
/*     */         sb.append(getItemSeparator());
/*     */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       } 
/* 468 */       return sb.toString(); } public AnimSVGPathSegList(SVGOMAnimatedPathData this$0) { this.this$0 = this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 595 */       this.parameterIndex = new int[1];
/*     */       this.itemList = new ArrayList(1); }
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {}
/*     */     
/*     */     protected AbstractSVGPathSegList.SVGPathSegItem newItem(short command, float[] parameters, int[] j) {
/* 603 */       switch (command) {
/*     */         case 10:
/*     */         case 11:
/* 606 */           j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegArcItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]], parameters[j[0]], (parameters[j[0]] != 0.0F), (parameters[j[0]] != 0.0F), parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 1:
/* 616 */           return new AbstractSVGPathSegList.SVGPathSegItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command]);
/*     */         
/*     */         case 6:
/*     */         case 7:
/* 620 */           j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegCurvetoCubicItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]], parameters[j[0]], parameters[j[0]], parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 16:
/*     */         case 17:
/* 630 */           j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegCurvetoCubicSmoothItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]], parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 8:
/*     */         case 9:
/* 638 */           j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]], parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 18:
/*     */         case 19:
/* 646 */           j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticSmoothItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */         
/*     */         case 2:
/*     */         case 3:
/*     */         case 4:
/*     */         case 5:
/* 654 */           j[0] = j[0] + 1; j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]], parameters[j[0]]);
/*     */ 
/*     */ 
/*     */         
/*     */         case 12:
/*     */         case 13:
/* 660 */           j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegLinetoHorizontalItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]]);
/*     */ 
/*     */         
/*     */         case 14:
/*     */         case 15:
/* 665 */           j[0] = j[0] + 1; return new AbstractSVGPathSegList.SVGPathSegLinetoVerticalItem(this, command, SVGPathSegConstants.PATHSEG_LETTERS[command], parameters[j[0]]);
/*     */       } 
/*     */ 
/*     */       
/* 669 */       return null;
/*     */     } public void clear() { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); } public SVGPathSeg initialize(SVGPathSeg newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); }
/*     */     public SVGPathSeg insertItemBefore(SVGPathSeg newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); }
/*     */     public SVGPathSeg replaceItem(SVGPathSeg newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); }
/*     */     public SVGPathSeg removeItem(int index) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); }
/*     */     public SVGPathSeg appendItem(SVGPathSeg newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.pathseg.list", null); }
/*     */     protected void setAnimatedValue(short[] commands, float[] parameters) {
/* 676 */       int size = this.itemList.size();
/* 677 */       int i = 0;
/* 678 */       int[] j = this.parameterIndex;
/* 679 */       j[0] = 0;
/* 680 */       while (i < size && i < commands.length) {
/* 681 */         SVGPathSeg s = (SVGPathSeg)this.itemList.get(i);
/* 682 */         if (s.getPathSegType() != commands[i]) {
/* 683 */           s = newItem(commands[i], parameters, j);
/*     */         } else {
/* 685 */           AbstractSVGPathSegList.SVGPathSegArcItem ps; AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticSmoothItem ps; AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem ps; AbstractSVGPathSegList.SVGPathSegLinetoHorizontalItem ps; AbstractSVGPathSegList.SVGPathSegCurvetoCubicSmoothItem ps; AbstractSVGPathSegList.SVGPathSegCurvetoCubicItem ps; AbstractSVGPathSegList.SVGPathSegLinetoVerticalItem ps; AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticItem ps; switch (commands[i]) {
/*     */             case 10:
/*     */             case 11:
/* 688 */               ps = (AbstractSVGPathSegList.SVGPathSegArcItem)s;
/* 689 */               j[0] = j[0] + 1; ps.r1 = parameters[j[0]];
/* 690 */               j[0] = j[0] + 1; ps.r2 = parameters[j[0]];
/* 691 */               j[0] = j[0] + 1; ps.angle = parameters[j[0]];
/* 692 */               j[0] = j[0] + 1; ps.largeArcFlag = (parameters[j[0]] != 0.0F);
/* 693 */               j[0] = j[0] + 1; ps.sweepFlag = (parameters[j[0]] != 0.0F);
/* 694 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 695 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */ 
/*     */ 
/*     */ 
/*     */             
/*     */             case 6:
/*     */             case 7:
/* 703 */               ps = (AbstractSVGPathSegList.SVGPathSegCurvetoCubicItem)s;
/*     */               
/* 705 */               j[0] = j[0] + 1; ps.x1 = parameters[j[0]];
/* 706 */               j[0] = j[0] + 1; ps.y1 = parameters[j[0]];
/* 707 */               j[0] = j[0] + 1; ps.x2 = parameters[j[0]];
/* 708 */               j[0] = j[0] + 1; ps.y2 = parameters[j[0]];
/* 709 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 710 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 16:
/*     */             case 17:
/* 715 */               ps = (AbstractSVGPathSegList.SVGPathSegCurvetoCubicSmoothItem)s;
/*     */               
/* 717 */               j[0] = j[0] + 1; ps.x2 = parameters[j[0]];
/* 718 */               j[0] = j[0] + 1; ps.y2 = parameters[j[0]];
/* 719 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 720 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 8:
/*     */             case 9:
/* 725 */               ps = (AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticItem)s;
/*     */               
/* 727 */               j[0] = j[0] + 1; ps.x1 = parameters[j[0]];
/* 728 */               j[0] = j[0] + 1; ps.y1 = parameters[j[0]];
/* 729 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 730 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 18:
/*     */             case 19:
/* 735 */               ps = (AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticSmoothItem)s;
/*     */               
/* 737 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 738 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 2:
/*     */             case 3:
/*     */             case 4:
/*     */             case 5:
/* 745 */               ps = (AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem)s;
/*     */               
/* 747 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/* 748 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 12:
/*     */             case 13:
/* 753 */               ps = (AbstractSVGPathSegList.SVGPathSegLinetoHorizontalItem)s;
/*     */               
/* 755 */               j[0] = j[0] + 1; ps.x = parameters[j[0]];
/*     */               break;
/*     */             
/*     */             case 14:
/*     */             case 15:
/* 760 */               ps = (AbstractSVGPathSegList.SVGPathSegLinetoVerticalItem)s;
/*     */               
/* 762 */               j[0] = j[0] + 1; ps.y = parameters[j[0]];
/*     */               break;
/*     */           } 
/*     */         
/*     */         } 
/* 767 */         i++;
/*     */       } 
/* 769 */       while (i < commands.length) {
/* 770 */         appendItemImpl(newItem(commands[i], parameters, j));
/* 771 */         i++;
/*     */       } 
/* 773 */       while (size > commands.length) {
/* 774 */         removeItemImpl(--size);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 797 */     protected void revalidate() { this.valid = true; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedPathData.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */