/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import org.apache.batik.anim.values.AnimatablePointListValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedPoints;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGPoint;
/*     */ import org.w3c.dom.svg.SVGPointList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedPoints
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedPoints
/*     */ {
/*     */   protected BaseSVGPointList baseVal;
/*     */   protected AnimSVGPointList animVal;
/*     */   protected boolean changing;
/*     */   protected String defaultValue;
/*     */   
/*     */   public SVGOMAnimatedPoints(AbstractElement elt, String ns, String ln, String defaultValue) {
/*  78 */     super(elt, ns, ln);
/*  79 */     this.defaultValue = defaultValue;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPointList getPoints() {
/*  86 */     if (this.baseVal == null) {
/*  87 */       this.baseVal = new BaseSVGPointList(this);
/*     */     }
/*  89 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPointList getAnimatedPoints() {
/*  96 */     if (this.animVal == null) {
/*  97 */       this.animVal = new AnimSVGPointList(this);
/*     */     }
/*  99 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/* 106 */     if (!this.hasAnimVal) {
/* 107 */       if (this.baseVal == null) {
/* 108 */         this.baseVal = new BaseSVGPointList(this);
/*     */       }
/* 110 */       this.baseVal.revalidate();
/* 111 */       if (this.baseVal.missing) {
/* 112 */         throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */       }
/*     */ 
/*     */       
/* 116 */       if (this.baseVal.malformed) {
/* 117 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 129 */     SVGPointList pl = getPoints();
/* 130 */     int n = pl.getNumberOfItems();
/* 131 */     float[] points = new float[n * 2];
/* 132 */     for (int i = 0; i < n; i++) {
/* 133 */       SVGPoint p = pl.getItem(i);
/* 134 */       points[i * 2] = p.getX();
/* 135 */       points[i * 2 + 1] = p.getY();
/*     */     } 
/* 137 */     return new AnimatablePointListValue(target, points);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 144 */     if (val == null) {
/* 145 */       this.hasAnimVal = false;
/*     */     } else {
/* 147 */       this.hasAnimVal = true;
/* 148 */       AnimatablePointListValue animPointList = (AnimatablePointListValue)val;
/*     */       
/* 150 */       if (this.animVal == null) {
/* 151 */         this.animVal = new AnimSVGPointList(this);
/*     */       }
/* 153 */       this.animVal.setAnimatedValue(animPointList.getNumbers());
/*     */     } 
/* 155 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 162 */     if (!this.changing && this.baseVal != null) {
/* 163 */       this.baseVal.invalidate();
/*     */     }
/* 165 */     fireBaseAttributeListeners();
/* 166 */     if (!this.hasAnimVal) {
/* 167 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 175 */     if (!this.changing && this.baseVal != null) {
/* 176 */       this.baseVal.invalidate();
/*     */     }
/* 178 */     fireBaseAttributeListeners();
/* 179 */     if (!this.hasAnimVal) {
/* 180 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 188 */     if (!this.changing && this.baseVal != null) {
/* 189 */       this.baseVal.invalidate();
/*     */     }
/* 191 */     fireBaseAttributeListeners();
/* 192 */     if (!this.hasAnimVal)
/* 193 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */   
/*     */   protected class BaseSVGPointList
/*     */     extends AbstractSVGPointList {
/*     */     protected boolean missing;
/*     */     
/* 200 */     protected BaseSVGPointList(SVGOMAnimatedPoints this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean malformed;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGOMAnimatedPoints this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 217 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 226 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 233 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 234 */       if (attr == null) {
/* 235 */         return this.this$0.defaultValue;
/*     */       }
/* 237 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 245 */         this.this$0.changing = true;
/* 246 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 248 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 256 */       super.resetAttribute();
/* 257 */       this.missing = false;
/* 258 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {
/* 267 */       super.resetAttribute(item);
/* 268 */       this.missing = false;
/* 269 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 276 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 280 */       this.valid = true;
/* 281 */       this.missing = false;
/* 282 */       this.malformed = false;
/*     */       
/* 284 */       String s = getValueAsString();
/* 285 */       if (s == null) {
/* 286 */         this.missing = true;
/*     */         return;
/*     */       } 
/*     */       try {
/* 290 */         AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */         
/* 292 */         doParse(s, builder);
/*     */         
/* 294 */         if (builder.getList() != null) {
/* 295 */           clear(this.itemList);
/*     */         }
/* 297 */         this.itemList = builder.getList();
/*     */       } catch (ParseException e) {
/* 299 */         this.itemList = new ArrayList(1);
/* 300 */         this.malformed = true;
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   protected class AnimSVGPointList
/*     */     extends AbstractSVGPointList
/*     */   {
/*     */     private final SVGOMAnimatedPoints this$0;
/*     */ 
/*     */     
/*     */     public AnimSVGPointList(SVGOMAnimatedPoints this$0) {
/* 313 */       this.this$0 = this$0;
/* 314 */       this.itemList = new ArrayList(1);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 322 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 331 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public int getNumberOfItems() {
/* 338 */       if (this.this$0.hasAnimVal) {
/* 339 */         return super.getNumberOfItems();
/*     */       }
/* 341 */       return this.this$0.getPoints().getNumberOfItems();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public SVGPoint getItem(int index) throws DOMException {
/* 348 */       if (this.this$0.hasAnimVal) {
/* 349 */         return super.getItem(index);
/*     */       }
/* 351 */       return this.this$0.getPoints().getItem(index);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 358 */       if (this.itemList.size() == 0) {
/* 359 */         return "";
/*     */       }
/* 361 */       StringBuffer sb = new StringBuffer(this.itemList.size() * 8);
/* 362 */       Iterator i = this.itemList.iterator();
/* 363 */       if (i.hasNext()) {
/* 364 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       }
/* 366 */       while (i.hasNext()) {
/* 367 */         sb.append(getItemSeparator());
/* 368 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       } 
/* 370 */       return sb.toString();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 383 */     public void clear() { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 393 */     public SVGPoint initialize(SVGPoint newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 404 */     public SVGPoint insertItemBefore(SVGPoint newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 415 */     public SVGPoint replaceItem(SVGPoint newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 424 */     public SVGPoint removeItem(int index) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 433 */     public SVGPoint appendItem(SVGPoint newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.point.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(float[] pts) {
/* 442 */       int size = this.itemList.size();
/* 443 */       int i = 0;
/* 444 */       while (i < size && i < pts.length / 2) {
/* 445 */         AbstractSVGPointList.SVGPointItem p = (AbstractSVGPointList.SVGPointItem)this.itemList.get(i);
/* 446 */         p.x = pts[i * 2];
/* 447 */         p.y = pts[i * 2 + 1];
/* 448 */         i++;
/*     */       } 
/* 450 */       while (i < pts.length / 2) {
/* 451 */         appendItemImpl(new AbstractSVGPointList.SVGPointItem(this, pts[i * 2], pts[i * 2 + 1]));
/* 452 */         i++;
/*     */       } 
/* 454 */       while (size > pts.length / 2) {
/* 455 */         removeItemImpl(--size);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 478 */     protected void revalidate() { this.valid = true; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedPoints.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */