/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatablePreserveAspectRatioValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedPreserveAspectRatio;
/*     */ import org.w3c.dom.svg.SVGPreserveAspectRatio;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedPreserveAspectRatio
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedPreserveAspectRatio
/*     */ {
/*     */   protected BaseSVGPARValue baseVal;
/*     */   protected AnimSVGPARValue animVal;
/*     */   protected boolean changing;
/*     */   
/*  62 */   public SVGOMAnimatedPreserveAspectRatio(AbstractElement elt) { super(elt, null, "preserveAspectRatio"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPreserveAspectRatio getBaseVal() {
/*  69 */     if (this.baseVal == null) {
/*  70 */       this.baseVal = new BaseSVGPARValue(this);
/*     */     }
/*  72 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPreserveAspectRatio getAnimVal() {
/*  79 */     if (this.animVal == null) {
/*  80 */       this.animVal = new AnimSVGPARValue(this);
/*     */     }
/*  82 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/*  90 */     if (!this.hasAnimVal) {
/*  91 */       if (this.baseVal == null) {
/*  92 */         this.baseVal = new BaseSVGPARValue(this);
/*     */       }
/*  94 */       if (this.baseVal.malformed) {
/*  95 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 107 */     SVGPreserveAspectRatio par = getBaseVal();
/* 108 */     return new AnimatablePreserveAspectRatioValue(target, par.getAlign(), par.getMeetOrSlice());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 116 */     if (val == null) {
/* 117 */       this.hasAnimVal = false;
/*     */     } else {
/* 119 */       this.hasAnimVal = true;
/* 120 */       if (this.animVal == null) {
/* 121 */         this.animVal = new AnimSVGPARValue(this);
/*     */       }
/* 123 */       AnimatablePreserveAspectRatioValue animPAR = (AnimatablePreserveAspectRatioValue)val;
/*     */       
/* 125 */       this.animVal.setAnimatedValue(animPAR.getAlign(), animPAR.getMeetOrSlice());
/*     */     } 
/*     */     
/* 128 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 135 */     if (!this.changing && this.baseVal != null) {
/* 136 */       this.baseVal.invalidate();
/*     */     }
/* 138 */     fireBaseAttributeListeners();
/* 139 */     if (!this.hasAnimVal) {
/* 140 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 148 */     if (!this.changing && this.baseVal != null) {
/* 149 */       this.baseVal.invalidate();
/*     */     }
/* 151 */     fireBaseAttributeListeners();
/* 152 */     if (!this.hasAnimVal) {
/* 153 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 161 */     if (!this.changing && this.baseVal != null) {
/* 162 */       this.baseVal.invalidate();
/*     */     }
/* 164 */     fireBaseAttributeListeners();
/* 165 */     if (!this.hasAnimVal) {
/* 166 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class BaseSVGPARValue
/*     */     extends AbstractSVGPreserveAspectRatio
/*     */   {
/*     */     protected boolean malformed;
/*     */ 
/*     */     
/*     */     private final SVGOMAnimatedPreserveAspectRatio this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public BaseSVGPARValue(SVGOMAnimatedPreserveAspectRatio this$0) {
/* 184 */       this.this$0 = this$0;
/* 185 */       invalidate();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 193 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) throws DOMException {
/*     */       try {
/* 201 */         this.this$0.changing = true;
/* 202 */         this.this$0.element.setAttributeNS(null, "preserveAspectRatio", value);
/*     */ 
/*     */         
/* 205 */         this.malformed = false;
/*     */       } finally {
/* 207 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void invalidate() {
/* 215 */       String s = this.this$0.element.getAttributeNS(null, "preserveAspectRatio");
/*     */       
/* 217 */       setValueAsString(s);
/*     */     }
/*     */   }
/*     */   
/*     */   public class AnimSVGPARValue
/*     */     extends AbstractSVGPreserveAspectRatio {
/*     */     private final SVGOMAnimatedPreserveAspectRatio this$0;
/*     */     
/* 225 */     public AnimSVGPARValue(SVGOMAnimatedPreserveAspectRatio this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 232 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) throws DOMException {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public short getAlign() {
/* 246 */       if (this.this$0.hasAnimVal) {
/* 247 */         return super.getAlign();
/*     */       }
/* 249 */       return this.this$0.getBaseVal().getAlign();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public short getMeetOrSlice() {
/* 256 */       if (this.this$0.hasAnimVal) {
/* 257 */         return super.getMeetOrSlice();
/*     */       }
/* 259 */       return this.this$0.getBaseVal().getMeetOrSlice();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 266 */     public void setAlign(short align) { throw this.this$0.element.createDOMException((short)7, "readonly.preserve.aspect.ratio", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 275 */     public void setMeetOrSlice(short meetOrSlice) { throw this.this$0.element.createDOMException((short)7, "readonly.preserve.aspect.ratio", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(short align, short meetOrSlice) {
/* 284 */       this.align = align;
/* 285 */       this.meetOrSlice = meetOrSlice;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedPreserveAspectRatio.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */