/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatableRectValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.NumberListParser;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedRect;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedRect
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedRect
/*     */ {
/*     */   protected BaseSVGRect baseVal;
/*     */   protected AnimSVGRect animVal;
/*     */   protected boolean changing;
/*     */   protected String defaultValue;
/*     */   
/*     */   public SVGOMAnimatedRect(AbstractElement elt, String ns, String ln, String def) {
/*  72 */     super(elt, ns, ln);
/*  73 */     this.defaultValue = def;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGRect getBaseVal() {
/*  80 */     if (this.baseVal == null) {
/*  81 */       this.baseVal = new BaseSVGRect(this);
/*     */     }
/*  83 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGRect getAnimVal() {
/*  90 */     if (this.animVal == null) {
/*  91 */       this.animVal = new AnimSVGRect(this);
/*     */     }
/*  93 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 100 */     if (val == null) {
/* 101 */       this.hasAnimVal = false;
/*     */     } else {
/* 103 */       this.hasAnimVal = true;
/* 104 */       AnimatableRectValue animRect = (AnimatableRectValue)val;
/* 105 */       if (this.animVal == null) {
/* 106 */         this.animVal = new AnimSVGRect(this);
/*     */       }
/* 108 */       this.animVal.setAnimatedValue(animRect.getX(), animRect.getY(), animRect.getWidth(), animRect.getHeight());
/*     */     } 
/*     */     
/* 111 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 118 */     SVGRect r = getBaseVal();
/* 119 */     return new AnimatableRectValue(target, r.getX(), r.getY(), r.getWidth(), r.getHeight());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 127 */     if (!this.changing && this.baseVal != null) {
/* 128 */       this.baseVal.invalidate();
/*     */     }
/* 130 */     fireBaseAttributeListeners();
/* 131 */     if (!this.hasAnimVal) {
/* 132 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 140 */     if (!this.changing && this.baseVal != null) {
/* 141 */       this.baseVal.invalidate();
/*     */     }
/* 143 */     fireBaseAttributeListeners();
/* 144 */     if (!this.hasAnimVal) {
/* 145 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 153 */     if (!this.changing && this.baseVal != null) {
/* 154 */       this.baseVal.invalidate();
/*     */     }
/* 156 */     fireBaseAttributeListeners();
/* 157 */     if (!this.hasAnimVal)
/* 158 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */   
/*     */   protected class BaseSVGRect extends SVGOMRect {
/*     */     protected boolean valid;
/*     */     private final SVGOMAnimatedRect this$0;
/*     */     
/* 165 */     protected BaseSVGRect(SVGOMAnimatedRect this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 176 */     public void invalidate() { this.valid = false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void reset() {
/*     */       try {
/* 184 */         this.this$0.changing = true;
/* 185 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, Float.toString(this.x) + ' ' + this.y + ' ' + this.w + ' ' + this.h);
/*     */       }
/*     */       finally {
/*     */         
/* 189 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 197 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 201 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/*     */       
/* 203 */       String s = (attr == null) ? this.this$0.defaultValue : attr.getValue();
/* 204 */       float[] numbers = new float[4];
/* 205 */       NumberListParser p = new NumberListParser();
/* 206 */       p.setNumberListHandler(new SVGOMAnimatedRect$1(this, s, numbers));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 229 */       p.parse(s);
/* 230 */       this.x = numbers[0];
/* 231 */       this.y = numbers[1];
/* 232 */       this.w = numbers[2];
/* 233 */       this.h = numbers[3];
/*     */       
/* 235 */       this.valid = true;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getX() {
/* 242 */       revalidate();
/* 243 */       return this.x;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setX(float x) throws DOMException {
/* 250 */       this.x = x;
/* 251 */       reset();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getY() {
/* 258 */       revalidate();
/* 259 */       return this.y;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setY(float y) throws DOMException {
/* 266 */       this.y = y;
/* 267 */       reset();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getWidth() {
/* 274 */       revalidate();
/* 275 */       return this.w;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setWidth(float width) throws DOMException {
/* 282 */       this.w = width;
/* 283 */       reset();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getHeight() {
/* 290 */       revalidate();
/* 291 */       return this.h;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setHeight(float height) throws DOMException {
/* 298 */       this.h = height;
/* 299 */       reset();
/*     */     }
/*     */   }
/*     */   
/*     */   protected class AnimSVGRect extends SVGOMRect {
/*     */     private final SVGOMAnimatedRect this$0;
/*     */     
/* 306 */     protected AnimSVGRect(SVGOMAnimatedRect this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getX() {
/* 312 */       if (this.this$0.hasAnimVal) {
/* 313 */         return super.getX();
/*     */       }
/* 315 */       return this.this$0.getBaseVal().getX();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getY() {
/* 322 */       if (this.this$0.hasAnimVal) {
/* 323 */         return super.getY();
/*     */       }
/* 325 */       return this.this$0.getBaseVal().getY();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getWidth() {
/* 332 */       if (this.this$0.hasAnimVal) {
/* 333 */         return super.getWidth();
/*     */       }
/* 335 */       return this.this$0.getBaseVal().getWidth();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public float getHeight() {
/* 342 */       if (this.this$0.hasAnimVal) {
/* 343 */         return super.getHeight();
/*     */       }
/* 345 */       return this.this$0.getBaseVal().getHeight();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 352 */     public void setX(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 361 */     public void setY(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 370 */     public void setWidth(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 379 */     public void setHeight(float value) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.length", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(float x, float y, float w, float h) {
/* 388 */       this.x = x;
/* 389 */       this.y = y;
/* 390 */       this.w = w;
/* 391 */       this.h = h;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedRect.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */