/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import org.apache.batik.anim.values.AnimatableTransformListValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedTransformList;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGTransform;
/*     */ import org.w3c.dom.svg.SVGTransformList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMAnimatedTransformList
/*     */   extends AbstractSVGAnimatedValue
/*     */   implements SVGAnimatedTransformList
/*     */ {
/*     */   protected BaseSVGTransformList baseVal;
/*     */   protected AnimSVGTransformList animVal;
/*     */   protected boolean changing;
/*     */   protected String defaultValue;
/*     */   
/*     */   public SVGOMAnimatedTransformList(AbstractElement elt, String ns, String ln, String defaultValue) {
/*  79 */     super(elt, ns, ln);
/*  80 */     this.defaultValue = defaultValue;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransformList getBaseVal() {
/*  87 */     if (this.baseVal == null) {
/*  88 */       this.baseVal = new BaseSVGTransformList(this);
/*     */     }
/*  90 */     return this.baseVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransformList getAnimVal() {
/*  97 */     if (this.animVal == null) {
/*  98 */       this.animVal = new AnimSVGTransformList(this);
/*     */     }
/* 100 */     return this.animVal;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void check() {
/* 107 */     if (!this.hasAnimVal) {
/* 108 */       if (this.baseVal == null) {
/* 109 */         this.baseVal = new BaseSVGTransformList(this);
/*     */       }
/* 111 */       this.baseVal.revalidate();
/* 112 */       if (this.baseVal.missing) {
/* 113 */         throw new LiveAttributeException(this.element, this.localName, (short)0, null);
/*     */       }
/*     */ 
/*     */       
/* 117 */       if (this.baseVal.malformed) {
/* 118 */         throw new LiveAttributeException(this.element, this.localName, (short)1, this.baseVal.getValueAsString());
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(AnimationTarget target) {
/* 130 */     SVGTransformList tl = getBaseVal();
/* 131 */     int n = tl.getNumberOfItems();
/* 132 */     List v = new ArrayList(n);
/* 133 */     for (int i = 0; i < n; i++) {
/* 134 */       v.add(tl.getItem(i));
/*     */     }
/* 136 */     return new AnimatableTransformListValue(target, v);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void updateAnimatedValue(AnimatableValue val) {
/* 143 */     if (val == null) {
/* 144 */       this.hasAnimVal = false;
/*     */     } else {
/* 146 */       this.hasAnimVal = true;
/* 147 */       AnimatableTransformListValue aval = (AnimatableTransformListValue)val;
/*     */       
/* 149 */       if (this.animVal == null) {
/* 150 */         this.animVal = new AnimSVGTransformList(this);
/*     */       }
/* 152 */       this.animVal.setAnimatedValue(aval.getTransforms());
/*     */     } 
/* 154 */     fireAnimatedAttributeListeners();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrAdded(Attr node, String newv) {
/* 161 */     if (!this.changing && this.baseVal != null) {
/* 162 */       this.baseVal.invalidate();
/*     */     }
/* 164 */     fireBaseAttributeListeners();
/* 165 */     if (!this.hasAnimVal) {
/* 166 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrModified(Attr node, String oldv, String newv) {
/* 174 */     if (!this.changing && this.baseVal != null) {
/* 175 */       this.baseVal.invalidate();
/*     */     }
/* 177 */     fireBaseAttributeListeners();
/* 178 */     if (!this.hasAnimVal) {
/* 179 */       fireAnimatedAttributeListeners();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void attrRemoved(Attr node, String oldv) {
/* 187 */     if (!this.changing && this.baseVal != null) {
/* 188 */       this.baseVal.invalidate();
/*     */     }
/* 190 */     fireBaseAttributeListeners();
/* 191 */     if (!this.hasAnimVal)
/* 192 */       fireAnimatedAttributeListeners(); 
/*     */   }
/*     */   
/*     */   public class BaseSVGTransformList
/*     */     extends AbstractSVGTransformList {
/*     */     protected boolean missing;
/*     */     
/* 199 */     public BaseSVGTransformList(SVGOMAnimatedTransformList this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean malformed;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGOMAnimatedTransformList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 216 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 225 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 232 */       Attr attr = this.this$0.element.getAttributeNodeNS(this.this$0.namespaceURI, this.this$0.localName);
/* 233 */       if (attr == null) {
/* 234 */         return this.this$0.defaultValue;
/*     */       }
/* 236 */       return attr.getValue();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {
/*     */       try {
/* 244 */         this.this$0.changing = true;
/* 245 */         this.this$0.element.setAttributeNS(this.this$0.namespaceURI, this.this$0.localName, value);
/*     */       } finally {
/* 247 */         this.this$0.changing = false;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 255 */       super.resetAttribute();
/* 256 */       this.missing = false;
/* 257 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {
/* 266 */       super.resetAttribute(item);
/* 267 */       this.missing = false;
/* 268 */       this.malformed = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void revalidate() {
/* 275 */       if (this.valid) {
/*     */         return;
/*     */       }
/*     */       
/* 279 */       this.valid = true;
/* 280 */       this.missing = false;
/* 281 */       this.malformed = false;
/*     */       
/* 283 */       String s = getValueAsString();
/* 284 */       if (s == null) {
/* 285 */         this.missing = true;
/*     */         return;
/*     */       } 
/*     */       try {
/* 289 */         AbstractSVGList.ListBuilder builder = new AbstractSVGList.ListBuilder(this);
/*     */         
/* 291 */         doParse(s, builder);
/*     */         
/* 293 */         if (builder.getList() != null) {
/* 294 */           clear(this.itemList);
/*     */         }
/* 296 */         this.itemList = builder.getList();
/*     */       } catch (ParseException e) {
/* 298 */         this.itemList = new ArrayList(1);
/* 299 */         this.malformed = true;
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class AnimSVGTransformList
/*     */     extends AbstractSVGTransformList
/*     */   {
/*     */     private final SVGOMAnimatedTransformList this$0;
/*     */ 
/*     */     
/*     */     public AnimSVGTransformList(SVGOMAnimatedTransformList this$0) {
/* 313 */       this.this$0 = this$0;
/* 314 */       this.itemList = new ArrayList(1);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 322 */     protected DOMException createDOMException(short type, String key, Object[] args) { return this.this$0.element.createDOMException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 331 */     protected SVGException createSVGException(short type, String key, Object[] args) { return ((SVGOMElement)this.this$0.element).createSVGException(type, key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public int getNumberOfItems() {
/* 338 */       if (this.this$0.hasAnimVal) {
/* 339 */         return super.getNumberOfItems();
/*     */       }
/* 341 */       return this.this$0.getBaseVal().getNumberOfItems();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public SVGTransform getItem(int index) throws DOMException {
/* 348 */       if (this.this$0.hasAnimVal) {
/* 349 */         return super.getItem(index);
/*     */       }
/* 351 */       return this.this$0.getBaseVal().getItem(index);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getValueAsString() {
/* 358 */       if (this.itemList.size() == 0) {
/* 359 */         return "";
/*     */       }
/* 361 */       StringBuffer sb = new StringBuffer(this.itemList.size() * 8);
/* 362 */       Iterator i = this.itemList.iterator();
/* 363 */       if (i.hasNext()) {
/* 364 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       }
/* 366 */       while (i.hasNext()) {
/* 367 */         sb.append(getItemSeparator());
/* 368 */         sb.append(((SVGItem)i.next()).getValueAsString());
/*     */       } 
/* 370 */       return sb.toString();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAttributeValue(String value) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 383 */     public void clear() { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 393 */     public SVGTransform initialize(SVGTransform newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 404 */     public SVGTransform insertItemBefore(SVGTransform newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 415 */     public SVGTransform replaceItem(SVGTransform newItem, int index) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 424 */     public SVGTransform removeItem(int index) throws DOMException { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 433 */     public SVGTransform appendItem(SVGTransform newItem) throws DOMException, SVGException { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 442 */     public SVGTransform consolidate() { throw this.this$0.element.createDOMException((short)7, "readonly.transform.list", null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(Iterator it) {
/* 451 */       int size = this.itemList.size();
/* 452 */       int i = 0;
/* 453 */       while (i < size && it.hasNext()) {
/* 454 */         AbstractSVGTransformList.SVGTransformItem t = (AbstractSVGTransformList.SVGTransformItem)this.itemList.get(i);
/* 455 */         t.assign((SVGTransform)it.next());
/* 456 */         i++;
/*     */       } 
/* 458 */       while (it.hasNext()) {
/* 459 */         appendItemImpl(new AbstractSVGTransformList.SVGTransformItem(this, (SVGTransform)it.next()));
/* 460 */         i++;
/*     */       } 
/* 462 */       while (size > i) {
/* 463 */         removeItemImpl(--size);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void setAnimatedValue(SVGTransform transform) {
/* 471 */       int size = this.itemList.size();
/* 472 */       while (size > 1) {
/* 473 */         removeItemImpl(--size);
/*     */       }
/* 475 */       if (size == 0) {
/* 476 */         appendItemImpl(new AbstractSVGTransformList.SVGTransformItem(this, transform));
/*     */       } else {
/* 478 */         AbstractSVGTransformList.SVGTransformItem t = (AbstractSVGTransformList.SVGTransformItem)this.itemList.get(0);
/* 479 */         t.assign(transform);
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute(SVGItem item) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 502 */     protected void revalidate() { this.valid = true; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMAnimatedTransformList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */