/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumberList;
/*     */ import org.w3c.dom.svg.SVGComponentTransferFunctionElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class SVGOMComponentTransferFunctionElement
/*     */   extends SVGOMElement
/*     */   implements SVGComponentTransferFunctionElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final String[] TYPE_VALUES;
/*     */   protected SVGOMAnimatedEnumeration type;
/*     */   protected SVGOMAnimatedNumberList tableValues;
/*     */   protected SVGOMAnimatedNumber slope;
/*     */   protected SVGOMAnimatedNumber intercept;
/*     */   protected SVGOMAnimatedNumber amplitude;
/*     */   protected SVGOMAnimatedNumber exponent;
/*     */   protected SVGOMAnimatedNumber offset;
/*     */   
/*     */   static  {
/*  45 */     t = new DoublyIndexedTable(SVGOMElement.xmlTraitInformation);
/*     */     
/*  47 */     t.put(null, "type", new TraitInformation(true, 15));
/*     */     
/*  49 */     t.put(null, "tableValues", new TraitInformation(true, 13));
/*     */     
/*  51 */     t.put(null, "slope", new TraitInformation(true, 2));
/*     */     
/*  53 */     t.put(null, "intercept", new TraitInformation(true, 2));
/*     */     
/*  55 */     t.put(null, "amplitude", new TraitInformation(true, 2));
/*     */     
/*  57 */     t.put(null, "exponent", new TraitInformation(true, 2));
/*     */     
/*  59 */     t.put(null, "offset", new TraitInformation(true, 2));
/*     */     
/*  61 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  67 */     TYPE_VALUES = new String[] { "", "identity", "table", "discrete", "linear", "gamma" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMComponentTransferFunctionElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMComponentTransferFunctionElement(String prefix, AbstractDocument owner) {
/* 124 */     super(prefix, owner);
/* 125 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 132 */     super.initializeAllLiveAttributes();
/* 133 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 140 */     this.type = createLiveAnimatedEnumeration(null, "type", TYPE_VALUES, (short)1);
/*     */ 
/*     */     
/* 143 */     this.tableValues = createLiveAnimatedNumberList(null, "tableValues", "", false);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 148 */     this.slope = createLiveAnimatedNumber(null, "slope", 1.0F);
/* 149 */     this.intercept = createLiveAnimatedNumber(null, "intercept", 0.0F);
/* 150 */     this.amplitude = createLiveAnimatedNumber(null, "amplitude", 1.0F);
/* 151 */     this.exponent = createLiveAnimatedNumber(null, "exponent", 1.0F);
/* 152 */     this.offset = createLiveAnimatedNumber(null, "exponent", 0.0F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 160 */   public SVGAnimatedEnumeration getType() { return this.type; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 169 */   public SVGAnimatedNumberList getTableValues() { throw new UnsupportedOperationException("SVGComponentTransferFunctionElement.getTableValues is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 179 */   public SVGAnimatedNumber getSlope() { return this.slope; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 187 */   public SVGAnimatedNumber getIntercept() { return this.intercept; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 195 */   public SVGAnimatedNumber getAmplitude() { return this.amplitude; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 203 */   public SVGAnimatedNumber getExponent() { return this.exponent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 211 */   public SVGAnimatedNumber getOffset() { return this.offset; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 218 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMComponentTransferFunctionElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */