/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.ObjectInputStream;
/*     */ import java.net.MalformedURLException;
/*     */ import java.net.URL;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.Locale;
/*     */ import java.util.MissingResourceException;
/*     */ import org.apache.batik.css.engine.CSSNavigableDocument;
/*     */ import org.apache.batik.css.engine.CSSNavigableDocumentListener;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.apache.batik.dom.AbstractStylableDocument;
/*     */ import org.apache.batik.dom.GenericAttr;
/*     */ import org.apache.batik.dom.GenericAttrNS;
/*     */ import org.apache.batik.dom.GenericCDATASection;
/*     */ import org.apache.batik.dom.GenericComment;
/*     */ import org.apache.batik.dom.GenericDocumentFragment;
/*     */ import org.apache.batik.dom.GenericElement;
/*     */ import org.apache.batik.dom.GenericEntityReference;
/*     */ import org.apache.batik.dom.GenericProcessingInstruction;
/*     */ import org.apache.batik.dom.GenericText;
/*     */ import org.apache.batik.dom.StyleSheetFactory;
/*     */ import org.apache.batik.dom.events.EventSupport;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.i18n.LocalizableSupport;
/*     */ import org.apache.batik.util.ParsedURL;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.CDATASection;
/*     */ import org.w3c.dom.Comment;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.DocumentFragment;
/*     */ import org.w3c.dom.DocumentType;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.EntityReference;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.ProcessingInstruction;
/*     */ import org.w3c.dom.Text;
/*     */ import org.w3c.dom.css.CSSStyleDeclaration;
/*     */ import org.w3c.dom.events.Event;
/*     */ import org.w3c.dom.events.EventListener;
/*     */ import org.w3c.dom.events.MutationEvent;
/*     */ import org.w3c.dom.svg.SVGDocument;
/*     */ import org.w3c.dom.svg.SVGLangSpace;
/*     */ import org.w3c.dom.svg.SVGSVGElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMDocument
/*     */   extends AbstractStylableDocument
/*     */   implements SVGDocument, SVGConstants, CSSNavigableDocument, IdContainer
/*     */ {
/*     */   protected static final String RESOURCES = "org.apache.batik.dom.svg.resources.Messages";
/*  97 */   protected LocalizableSupport localizableSupport = new LocalizableSupport("org.apache.batik.dom.svg.resources.Messages", getClass().getClassLoader());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 103 */   protected String referrer = "";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected ParsedURL url;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean readonly;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean isSVG12;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 124 */   protected HashMap cssNavigableDocumentListeners = new HashMap();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 130 */   protected AnimatedAttributeListener mainAnimatedAttributeListener = new AnimAttrListener(this);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 136 */   protected LinkedList animatedAttributeListeners = new LinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGContext svgContext;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMDocument() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 153 */   public SVGOMDocument(DocumentType dt, DOMImplementation impl) { super(dt, impl); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setLocale(Locale l) {
/* 160 */     super.setLocale(l);
/* 161 */     this.localizableSupport.setLocale(l);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String formatMessage(String key, Object[] args) throws MissingResourceException {
/*     */     try {
/* 170 */       return super.formatMessage(key, args);
/*     */     } catch (MissingResourceException e) {
/* 172 */       return this.localizableSupport.formatMessage(key, args);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getTitle() {
/* 180 */     StringBuffer sb = new StringBuffer();
/* 181 */     boolean preserve = false;
/*     */     
/* 183 */     Node n = getDocumentElement().getFirstChild();
/* 184 */     for (; n != null; 
/* 185 */       n = n.getNextSibling()) {
/* 186 */       String ns = n.getNamespaceURI();
/* 187 */       if (ns != null && ns.equals("http://www.w3.org/2000/svg") && 
/* 188 */         n.getLocalName().equals("title")) {
/* 189 */         preserve = ((SVGLangSpace)n).getXMLspace().equals("preserve");
/* 190 */         n = n.getFirstChild();
/* 191 */         for (; n != null; 
/* 192 */           n = n.getNextSibling()) {
/* 193 */           if (n.getNodeType() == 3) {
/* 194 */             sb.append(n.getNodeValue());
/*     */           }
/*     */         } 
/*     */         
/*     */         break;
/*     */       } 
/*     */     } 
/*     */     
/* 202 */     String s = sb.toString();
/* 203 */     return preserve ? XMLSupport.preserveXMLSpace(s) : XMLSupport.defaultXMLSpace(s);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 212 */   public String getReferrer() { return this.referrer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 219 */   public void setReferrer(String s) { this.referrer = s; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 226 */   public String getDomain() { return (this.url == null) ? null : this.url.getHost(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 233 */   public SVGSVGElement getRootElement() { return (SVGSVGElement)getDocumentElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 240 */   public String getURL() { return this.documentURI; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public URL getURLObject() {
/*     */     try {
/* 250 */       return new URL(this.documentURI);
/*     */     } catch (MalformedURLException e) {
/* 252 */       return null;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 260 */   public ParsedURL getParsedURL() { return this.url; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 267 */   public void setURLObject(URL url) { setParsedURL(new ParsedURL(url)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setParsedURL(ParsedURL url) {
/* 274 */     this.url = url;
/* 275 */     this.documentURI = (url == null) ? null : url.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setDocumentURI(String uri) {
/* 282 */     this.documentURI = uri;
/* 283 */     this.url = (uri == null) ? null : new ParsedURL(uri);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 290 */   public Element createElement(String tagName) throws DOMException { return new GenericElement(tagName.intern(), this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 297 */   public DocumentFragment createDocumentFragment() { return new GenericDocumentFragment(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 304 */   public Text createTextNode(String data) { return new GenericText(data, this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 311 */   public Comment createComment(String data) { return new GenericComment(data, this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 318 */   public CDATASection createCDATASection(String data) throws DOMException { return new GenericCDATASection(data, this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ProcessingInstruction createProcessingInstruction(String target, String data) throws DOMException {
/* 330 */     if ("xml-stylesheet".equals(target)) {
/* 331 */       return new SVGStyleSheetProcessingInstruction(data, this, (StyleSheetFactory)getImplementation());
/*     */     }
/*     */     
/* 334 */     return new GenericProcessingInstruction(target, data, this);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 341 */   public Attr createAttribute(String name) throws DOMException { return new GenericAttr(name.intern(), this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 349 */   public EntityReference createEntityReference(String name) throws DOMException { return new GenericEntityReference(name, this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Attr createAttributeNS(String namespaceURI, String qualifiedName) throws DOMException {
/* 357 */     if (namespaceURI == null) {
/* 358 */       return new GenericAttr(qualifiedName.intern(), this);
/*     */     }
/* 360 */     return new GenericAttrNS(namespaceURI.intern(), qualifiedName.intern(), this);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element createElementNS(String namespaceURI, String qualifiedName) throws DOMException {
/* 371 */     SVGDOMImplementation impl = (SVGDOMImplementation)this.implementation;
/* 372 */     return impl.createElementNS(this, namespaceURI, qualifiedName);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 379 */   public boolean isSVG12() { return this.isSVG12; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 386 */   public void setIsSVG12(boolean b) { this.isSVG12 = b; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isId(Attr node) {
/* 394 */     if (node.getNamespaceURI() == null) {
/* 395 */       return "id".equals(node.getNodeName());
/*     */     }
/* 397 */     return node.getNodeName().equals("xml:id");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 406 */   public void setSVGContext(SVGContext ctx) { this.svgContext = ctx; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 413 */   public SVGContext getSVGContext() { return this.svgContext; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addCSSNavigableDocumentListener(CSSNavigableDocumentListener l) {
/* 424 */     if (this.cssNavigableDocumentListeners.containsKey(l)) {
/*     */       return;
/*     */     }
/*     */     
/* 428 */     DOMNodeInsertedListenerWrapper nodeInserted = new DOMNodeInsertedListenerWrapper(this, l);
/*     */     
/* 430 */     DOMNodeRemovedListenerWrapper nodeRemoved = new DOMNodeRemovedListenerWrapper(this, l);
/*     */     
/* 432 */     DOMSubtreeModifiedListenerWrapper subtreeModified = new DOMSubtreeModifiedListenerWrapper(this, l);
/*     */     
/* 434 */     DOMCharacterDataModifiedListenerWrapper cdataModified = new DOMCharacterDataModifiedListenerWrapper(this, l);
/*     */     
/* 436 */     DOMAttrModifiedListenerWrapper attrModified = new DOMAttrModifiedListenerWrapper(this, l);
/*     */ 
/*     */     
/* 439 */     this.cssNavigableDocumentListeners.put(l, new EventListener[] { nodeInserted, nodeRemoved, subtreeModified, cdataModified, attrModified });
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 446 */     addEventListenerNS("http://www.w3.org/2001/xml-events", "DOMNodeInserted", nodeInserted, false, null);
/*     */     
/* 448 */     addEventListenerNS("http://www.w3.org/2001/xml-events", "DOMNodeRemoved", nodeRemoved, false, null);
/*     */     
/* 450 */     addEventListenerNS("http://www.w3.org/2001/xml-events", "DOMSubtreeModified", subtreeModified, false, null);
/*     */     
/* 452 */     addEventListenerNS("http://www.w3.org/2001/xml-events", "DOMCharacterDataModified", cdataModified, false, null);
/*     */ 
/*     */     
/* 455 */     addEventListenerNS("http://www.w3.org/2001/xml-events", "DOMAttrModified", attrModified, false, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeCSSNavigableDocumentListener(CSSNavigableDocumentListener l) {
/* 465 */     EventListener[] listeners = (EventListener[])this.cssNavigableDocumentListeners.get(l);
/*     */     
/* 467 */     if (listeners == null) {
/*     */       return;
/*     */     }
/*     */     
/* 471 */     removeEventListenerNS("http://www.w3.org/2001/xml-events", "DOMNodeInserted", listeners[0], false);
/*     */     
/* 473 */     removeEventListenerNS("http://www.w3.org/2001/xml-events", "DOMNodeRemoved", listeners[1], false);
/*     */     
/* 475 */     removeEventListenerNS("http://www.w3.org/2001/xml-events", "DOMSubtreeModified", listeners[2], false);
/*     */     
/* 477 */     removeEventListenerNS("http://www.w3.org/2001/xml-events", "DOMCharacterDataModified", listeners[3], false);
/*     */     
/* 479 */     removeEventListenerNS("http://www.w3.org/2001/xml-events", "DOMAttrModified", listeners[4], false);
/*     */ 
/*     */     
/* 482 */     this.cssNavigableDocumentListeners.remove(l);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 489 */   protected AnimatedAttributeListener getAnimatedAttributeListener() { return this.mainAnimatedAttributeListener; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void overrideStyleTextChanged(CSSStylableElement e, String text) {
/* 497 */     Iterator i = this.cssNavigableDocumentListeners.keySet().iterator();
/* 498 */     while (i.hasNext()) {
/* 499 */       CSSNavigableDocumentListener l = (CSSNavigableDocumentListener)i.next();
/*     */       
/* 501 */       l.overrideStyleTextChanged(e, text);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void overrideStylePropertyRemoved(CSSStylableElement e, String name) {
/* 510 */     Iterator i = this.cssNavigableDocumentListeners.keySet().iterator();
/* 511 */     while (i.hasNext()) {
/* 512 */       CSSNavigableDocumentListener l = (CSSNavigableDocumentListener)i.next();
/*     */       
/* 514 */       l.overrideStylePropertyRemoved(e, name);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void overrideStylePropertyChanged(CSSStylableElement e, String name, String value, String prio) {
/* 523 */     Iterator i = this.cssNavigableDocumentListeners.keySet().iterator();
/* 524 */     while (i.hasNext()) {
/* 525 */       CSSNavigableDocumentListener l = (CSSNavigableDocumentListener)i.next();
/*     */       
/* 527 */       l.overrideStylePropertyChanged(e, name, value, prio);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addAnimatedAttributeListener(AnimatedAttributeListener aal) {
/* 537 */     if (this.animatedAttributeListeners.contains(aal)) {
/*     */       return;
/*     */     }
/* 540 */     this.animatedAttributeListeners.add(aal);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 548 */   public void removeAnimatedAttributeListener(AnimatedAttributeListener aal) { this.animatedAttributeListeners.remove(aal); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class DOMNodeInsertedListenerWrapper
/*     */     implements EventListener
/*     */   {
/*     */     protected CSSNavigableDocumentListener listener;
/*     */ 
/*     */     
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public DOMNodeInsertedListenerWrapper(SVGOMDocument this$0, CSSNavigableDocumentListener l) {
/* 564 */       this.this$0 = this$0;
/* 565 */       this.listener = l;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void handleEvent(Event evt) {
/* 572 */       evt = EventSupport.getUltimateOriginalEvent(evt);
/* 573 */       this.listener.nodeInserted((Node)evt.getTarget());
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class DOMNodeRemovedListenerWrapper
/*     */     implements EventListener
/*     */   {
/*     */     protected CSSNavigableDocumentListener listener;
/*     */ 
/*     */     
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public DOMNodeRemovedListenerWrapper(SVGOMDocument this$0, CSSNavigableDocumentListener l) {
/* 590 */       this.this$0 = this$0;
/* 591 */       this.listener = l;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void handleEvent(Event evt) {
/* 598 */       evt = EventSupport.getUltimateOriginalEvent(evt);
/* 599 */       this.listener.nodeToBeRemoved((Node)evt.getTarget());
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class DOMSubtreeModifiedListenerWrapper
/*     */     implements EventListener
/*     */   {
/*     */     protected CSSNavigableDocumentListener listener;
/*     */ 
/*     */     
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public DOMSubtreeModifiedListenerWrapper(SVGOMDocument this$0, CSSNavigableDocumentListener l) {
/* 617 */       this.this$0 = this$0;
/* 618 */       this.listener = l;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void handleEvent(Event evt) {
/* 625 */       evt = EventSupport.getUltimateOriginalEvent(evt);
/* 626 */       this.listener.subtreeModified((Node)evt.getTarget());
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class DOMCharacterDataModifiedListenerWrapper
/*     */     implements EventListener
/*     */   {
/*     */     protected CSSNavigableDocumentListener listener;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public DOMCharacterDataModifiedListenerWrapper(SVGOMDocument this$0, CSSNavigableDocumentListener l) {
/* 645 */       this.this$0 = this$0;
/* 646 */       this.listener = l;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void handleEvent(Event evt) {
/* 653 */       evt = EventSupport.getUltimateOriginalEvent(evt);
/* 654 */       this.listener.subtreeModified((Node)evt.getTarget());
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class DOMAttrModifiedListenerWrapper
/*     */     implements EventListener
/*     */   {
/*     */     protected CSSNavigableDocumentListener listener;
/*     */ 
/*     */     
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public DOMAttrModifiedListenerWrapper(SVGOMDocument this$0, CSSNavigableDocumentListener l) {
/* 671 */       this.this$0 = this$0;
/* 672 */       this.listener = l;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void handleEvent(Event evt) {
/* 679 */       evt = EventSupport.getUltimateOriginalEvent(evt);
/* 680 */       MutationEvent mevt = (MutationEvent)evt;
/* 681 */       this.listener.attrModified((Element)evt.getTarget(), (Attr)mevt.getRelatedNode(), mevt.getAttrChange(), mevt.getPrevValue(), mevt.getNewValue());
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   protected class AnimAttrListener
/*     */     implements AnimatedAttributeListener
/*     */   {
/*     */     private final SVGOMDocument this$0;
/*     */ 
/*     */     
/* 692 */     protected AnimAttrListener(SVGOMDocument this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void animatedAttributeChanged(Element e, AnimatedLiveAttributeValue alav) {
/* 702 */       Iterator i = this.this$0.animatedAttributeListeners.iterator();
/* 703 */       while (i.hasNext()) {
/* 704 */         AnimatedAttributeListener aal = (AnimatedAttributeListener)i.next();
/*     */         
/* 706 */         aal.animatedAttributeChanged(e, alav);
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void otherAnimationChanged(Element e, String type) {
/* 717 */       Iterator i = this.this$0.animatedAttributeListeners.iterator();
/* 718 */       while (i.hasNext()) {
/* 719 */         AnimatedAttributeListener aal = (AnimatedAttributeListener)i.next();
/*     */         
/* 721 */         aal.otherAnimationChanged(e, type);
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSStyleDeclaration getOverrideStyle(Element elt, String pseudoElt) {
/* 734 */     if (elt instanceof SVGStylableElement && pseudoElt == null) {
/* 735 */       return ((SVGStylableElement)elt).getOverrideStyle();
/*     */     }
/* 737 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 746 */   public boolean isReadonly() { return this.readonly; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 753 */   public void setReadonly(boolean v) { this.readonly = v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 760 */   protected Node newNode() { return new SVGOMDocument(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node copyInto(Node n) {
/* 768 */     super.copyInto(n);
/* 769 */     SVGOMDocument sd = (SVGOMDocument)n;
/* 770 */     sd.localizableSupport = new LocalizableSupport("org.apache.batik.dom.svg.resources.Messages", getClass().getClassLoader());
/*     */     
/* 772 */     sd.referrer = this.referrer;
/* 773 */     sd.url = this.url;
/* 774 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepCopyInto(Node n) {
/* 782 */     super.deepCopyInto(n);
/* 783 */     SVGOMDocument sd = (SVGOMDocument)n;
/* 784 */     sd.localizableSupport = new LocalizableSupport("org.apache.batik.dom.svg.resources.Messages", getClass().getClassLoader());
/*     */     
/* 786 */     sd.referrer = this.referrer;
/* 787 */     sd.url = this.url;
/* 788 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void readObject(ObjectInputStream s) throws IOException, ClassNotFoundException {
/* 798 */     s.defaultReadObject();
/*     */     
/* 800 */     this.localizableSupport = new LocalizableSupport("org.apache.batik.dom.svg.resources.Messages", getClass().getClassLoader());
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMDocument.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */