/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import org.apache.batik.anim.values.AnimatableNumberOptionalNumberValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.CSSNavigableNode;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.apache.batik.css.engine.value.ShorthandManager;
/*     */ import org.apache.batik.css.engine.value.ValueManager;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.AbstractStylableDocument;
/*     */ import org.apache.batik.dom.anim.AnimationTarget;
/*     */ import org.apache.batik.dom.anim.AnimationTargetListener;
/*     */ import org.apache.batik.dom.util.DOMUtilities;
/*     */ import org.apache.batik.parser.UnitProcessor;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.apache.batik.util.ParsedURL;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedInteger;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGElement;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGSVGElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class SVGOMElement
/*     */   extends AbstractElement
/*     */   implements SVGElement, ExtendedTraitAccess, AnimationTarget
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected boolean readonly;
/*     */   protected String prefix;
/*     */   protected SVGContext svgContext;
/*     */   protected DoublyIndexedTable targetListeners;
/*     */   protected UnitProcessor.Context unitContext;
/*     */   
/*     */   static  {
/*  70 */     t = new DoublyIndexedTable();
/*  71 */     t.put(null, "id", new TraitInformation(false, 16));
/*     */     
/*  73 */     t.put("http://www.w3.org/XML/1998/namespace", "base", new TraitInformation(false, 10));
/*     */     
/*  75 */     t.put("http://www.w3.org/XML/1998/namespace", "space", new TraitInformation(false, 15));
/*     */     
/*  77 */     t.put("http://www.w3.org/XML/1998/namespace", "id", new TraitInformation(false, 16));
/*     */     
/*  79 */     t.put("http://www.w3.org/XML/1998/namespace", "lang", new TraitInformation(false, 45));
/*     */     
/*  81 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 122 */   protected SVGOMElement(String prefix, AbstractDocument owner) { super(prefix, owner); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getId() {
/* 146 */     if (((SVGOMDocument)this.ownerDocument).isSVG12) {
/* 147 */       Attr a = getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "id");
/* 148 */       if (a != null) {
/* 149 */         return a.getNodeValue();
/*     */       }
/*     */     } 
/* 152 */     return getAttributeNS(null, "id");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setId(String id) {
/* 159 */     if (((SVGOMDocument)this.ownerDocument).isSVG12) {
/* 160 */       setAttributeNS("http://www.w3.org/XML/1998/namespace", "id", id);
/* 161 */       Attr a = getAttributeNodeNS(null, "id");
/* 162 */       if (a != null) {
/* 163 */         a.setNodeValue(id);
/*     */       }
/*     */     } else {
/* 166 */       setAttributeNS(null, "id", id);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 174 */   public String getXMLbase() { return getAttributeNS("http://www.w3.org/XML/1998/namespace", "base"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 181 */   public void setXMLbase(String xmlbase) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:base", xmlbase); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGSVGElement getOwnerSVGElement() {
/* 188 */     CSSStylableElement cSSStylableElement = CSSEngine.getParentCSSStylableElement(this);
/* 189 */     for (; cSSStylableElement != null; 
/* 190 */       cSSStylableElement = CSSEngine.getParentCSSStylableElement(cSSStylableElement)) {
/* 191 */       if (cSSStylableElement instanceof SVGSVGElement) {
/* 192 */         return (SVGSVGElement)cSSStylableElement;
/*     */       }
/*     */     } 
/* 195 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGElement getViewportElement() {
/* 202 */     CSSStylableElement cSSStylableElement = CSSEngine.getParentCSSStylableElement(this);
/* 203 */     for (; cSSStylableElement != null; 
/* 204 */       cSSStylableElement = CSSEngine.getParentCSSStylableElement(cSSStylableElement)) {
/* 205 */       if (cSSStylableElement instanceof org.w3c.dom.svg.SVGFitToViewBox) {
/* 206 */         return (SVGElement)cSSStylableElement;
/*     */       }
/*     */     } 
/* 209 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getNodeName() {
/* 216 */     if (this.prefix == null || this.prefix.equals("")) {
/* 217 */       return getLocalName();
/*     */     }
/*     */     
/* 220 */     return this.prefix + ':' + getLocalName();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 227 */   public String getNamespaceURI() { return "http://www.w3.org/2000/svg"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setPrefix(String prefix) {
/* 234 */     if (isReadonly()) {
/* 235 */       throw createDOMException((short)7, "readonly.node", new Object[] { new Integer(getNodeType()), getNodeName() });
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 240 */     if (prefix != null && !prefix.equals("") && !DOMUtilities.isValidName(prefix))
/*     */     {
/*     */       
/* 243 */       throw createDOMException((short)5, "prefix", new Object[] { new Integer(getNodeType()), getNodeName(), prefix });
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 249 */     this.prefix = prefix;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String getCascadedXMLBase(Node node) {
/* 258 */     String base = null;
/* 259 */     Node n = node.getParentNode();
/* 260 */     while (n != null) {
/* 261 */       if (n.getNodeType() == 1) {
/* 262 */         base = getCascadedXMLBase(n);
/*     */         break;
/*     */       } 
/* 265 */       if (n instanceof CSSNavigableNode) {
/* 266 */         n = ((CSSNavigableNode)n).getCSSParentNode(); continue;
/*     */       } 
/* 268 */       n = n.getParentNode();
/*     */     } 
/*     */     
/* 271 */     if (base == null) {
/*     */       AbstractDocument abstractDocument;
/* 273 */       if (node.getNodeType() == 9) {
/* 274 */         abstractDocument = (AbstractDocument)node;
/*     */       } else {
/* 276 */         abstractDocument = (AbstractDocument)node.getOwnerDocument();
/*     */       } 
/* 278 */       base = abstractDocument.getDocumentURI();
/*     */     } 
/* 280 */     while (node != null && node.getNodeType() != 1) {
/* 281 */       node = node.getParentNode();
/*     */     }
/* 283 */     if (node == null) {
/* 284 */       return base;
/*     */     }
/* 286 */     Element e = (Element)node;
/* 287 */     Attr attr = e.getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "base");
/* 288 */     if (attr != null) {
/* 289 */       if (base == null) {
/* 290 */         base = attr.getNodeValue();
/*     */       } else {
/* 292 */         base = (new ParsedURL(base, attr.getNodeValue())).toString();
/*     */       } 
/*     */     }
/* 295 */     return base;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 306 */   public void setSVGContext(SVGContext ctx) { this.svgContext = ctx; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 313 */   public SVGContext getSVGContext() { return this.svgContext; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGException createSVGException(short type, String key, Object[] args) {
/*     */     try {
/* 325 */       return new SVGOMException(type, getCurrentDocument().formatMessage(key, args));
/*     */     } catch (Exception e) {
/*     */       
/* 328 */       return new SVGOMException(type, key);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 336 */   public boolean isReadonly() { return this.readonly; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 343 */   public void setReadonly(boolean v) { this.readonly = v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 350 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedTransformList createLiveAnimatedTransformList(String ns, String ln, String def) {
/* 359 */     SVGOMAnimatedTransformList v = new SVGOMAnimatedTransformList(this, ns, ln, def);
/*     */     
/* 361 */     this.liveAttributeValues.put(ns, ln, v);
/* 362 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 364 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedBoolean createLiveAnimatedBoolean(String ns, String ln, boolean def) {
/* 373 */     SVGOMAnimatedBoolean v = new SVGOMAnimatedBoolean(this, ns, ln, def);
/*     */     
/* 375 */     this.liveAttributeValues.put(ns, ln, v);
/* 376 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 378 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedString createLiveAnimatedString(String ns, String ln) {
/* 387 */     SVGOMAnimatedString v = new SVGOMAnimatedString(this, ns, ln);
/*     */     
/* 389 */     this.liveAttributeValues.put(ns, ln, v);
/* 390 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 392 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedPreserveAspectRatio createLiveAnimatedPreserveAspectRatio() {
/* 401 */     SVGOMAnimatedPreserveAspectRatio v = new SVGOMAnimatedPreserveAspectRatio(this);
/*     */     
/* 403 */     this.liveAttributeValues.put(null, "preserveAspectRatio", v);
/* 404 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 406 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedMarkerOrientValue createLiveAnimatedMarkerOrientValue(String ns, String ln) {
/* 415 */     SVGOMAnimatedMarkerOrientValue v = new SVGOMAnimatedMarkerOrientValue(this, ns, ln);
/*     */     
/* 417 */     this.liveAttributeValues.put(ns, ln, v);
/* 418 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 420 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedPathData createLiveAnimatedPathData(String ns, String ln, String def) {
/* 429 */     SVGOMAnimatedPathData v = new SVGOMAnimatedPathData(this, ns, ln, def);
/*     */     
/* 431 */     this.liveAttributeValues.put(ns, ln, v);
/* 432 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 434 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 443 */   protected SVGOMAnimatedNumber createLiveAnimatedNumber(String ns, String ln, float def) { return createLiveAnimatedNumber(ns, ln, def, false); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedNumber createLiveAnimatedNumber(String ns, String ln, float def, boolean allowPercentage) {
/* 452 */     SVGOMAnimatedNumber v = new SVGOMAnimatedNumber(this, ns, ln, def, allowPercentage);
/*     */     
/* 454 */     this.liveAttributeValues.put(ns, ln, v);
/* 455 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 457 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedNumberList createLiveAnimatedNumberList(String ns, String ln, String def, boolean canEmpty) {
/* 466 */     SVGOMAnimatedNumberList v = new SVGOMAnimatedNumberList(this, ns, ln, def, canEmpty);
/*     */     
/* 468 */     this.liveAttributeValues.put(ns, ln, v);
/* 469 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 471 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedPoints createLiveAnimatedPoints(String ns, String ln, String def) {
/* 480 */     SVGOMAnimatedPoints v = new SVGOMAnimatedPoints(this, ns, ln, def);
/*     */     
/* 482 */     this.liveAttributeValues.put(ns, ln, v);
/* 483 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 485 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedLengthList createLiveAnimatedLengthList(String ns, String ln, String def, boolean emptyAllowed, short dir) {
/* 495 */     SVGOMAnimatedLengthList v = new SVGOMAnimatedLengthList(this, ns, ln, def, emptyAllowed, dir);
/*     */     
/* 497 */     this.liveAttributeValues.put(ns, ln, v);
/* 498 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 500 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedInteger createLiveAnimatedInteger(String ns, String ln, int def) {
/* 509 */     SVGOMAnimatedInteger v = new SVGOMAnimatedInteger(this, ns, ln, def);
/*     */     
/* 511 */     this.liveAttributeValues.put(ns, ln, v);
/* 512 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 514 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedEnumeration createLiveAnimatedEnumeration(String ns, String ln, String[] val, short def) {
/* 523 */     SVGOMAnimatedEnumeration v = new SVGOMAnimatedEnumeration(this, ns, ln, val, def);
/*     */     
/* 525 */     this.liveAttributeValues.put(ns, ln, v);
/* 526 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 528 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedLength createLiveAnimatedLength(String ns, String ln, String val, short dir, boolean nonneg) {
/* 537 */     SVGOMAnimatedLength v = new SVGOMAnimatedLength(this, ns, ln, val, dir, nonneg);
/*     */     
/* 539 */     this.liveAttributeValues.put(ns, ln, v);
/* 540 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 542 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMAnimatedRect createLiveAnimatedRect(String ns, String ln, String value) {
/* 551 */     SVGOMAnimatedRect v = new SVGOMAnimatedRect(this, ns, ln, value);
/* 552 */     this.liveAttributeValues.put(ns, ln, v);
/* 553 */     v.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */     
/* 555 */     return v;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean hasProperty(String pn) {
/* 564 */     AbstractStylableDocument doc = (AbstractStylableDocument)this.ownerDocument;
/* 565 */     CSSEngine eng = doc.getCSSEngine();
/* 566 */     return (eng.getPropertyIndex(pn) != -1 || eng.getShorthandIndex(pn) != -1);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 575 */   public boolean hasTrait(String ns, String ln) { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isPropertyAnimatable(String pn) {
/* 582 */     AbstractStylableDocument doc = (AbstractStylableDocument)this.ownerDocument;
/* 583 */     CSSEngine eng = doc.getCSSEngine();
/* 584 */     int idx = eng.getPropertyIndex(pn);
/* 585 */     if (idx != -1) {
/* 586 */       ValueManager[] vms = eng.getValueManagers();
/* 587 */       return vms[idx].isAnimatableProperty();
/*     */     } 
/* 589 */     idx = eng.getShorthandIndex(pn);
/* 590 */     if (idx != -1) {
/* 591 */       ShorthandManager[] sms = eng.getShorthandManagers();
/* 592 */       return sms[idx].isAnimatableProperty();
/*     */     } 
/* 594 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final boolean isAttributeAnimatable(String ns, String ln) {
/* 601 */     DoublyIndexedTable t = getTraitInformationTable();
/* 602 */     TraitInformation ti = (TraitInformation)t.get(ns, ln);
/* 603 */     if (ti != null) {
/* 604 */       return ti.isAnimatable();
/*     */     }
/* 606 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isPropertyAdditive(String pn) {
/* 613 */     AbstractStylableDocument doc = (AbstractStylableDocument)this.ownerDocument;
/* 614 */     CSSEngine eng = doc.getCSSEngine();
/* 615 */     int idx = eng.getPropertyIndex(pn);
/* 616 */     if (idx != -1) {
/* 617 */       ValueManager[] vms = eng.getValueManagers();
/* 618 */       return vms[idx].isAdditiveProperty();
/*     */     } 
/* 620 */     idx = eng.getShorthandIndex(pn);
/* 621 */     if (idx != -1) {
/* 622 */       ShorthandManager[] sms = eng.getShorthandManagers();
/* 623 */       return sms[idx].isAdditiveProperty();
/*     */     } 
/* 625 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 632 */   public boolean isAttributeAdditive(String ns, String ln) { return true; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 640 */   public boolean isTraitAnimatable(String ns, String tn) { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 648 */   public boolean isTraitAdditive(String ns, String tn) { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getPropertyType(String pn) {
/* 655 */     AbstractStylableDocument doc = (AbstractStylableDocument)this.ownerDocument;
/*     */     
/* 657 */     CSSEngine eng = doc.getCSSEngine();
/* 658 */     int idx = eng.getPropertyIndex(pn);
/* 659 */     if (idx != -1) {
/* 660 */       ValueManager[] vms = eng.getValueManagers();
/* 661 */       return vms[idx].getPropertyType();
/*     */     } 
/* 663 */     return 0;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final int getAttributeType(String ns, String ln) {
/* 670 */     DoublyIndexedTable t = getTraitInformationTable();
/* 671 */     TraitInformation ti = (TraitInformation)t.get(ns, ln);
/* 672 */     if (ti != null) {
/* 673 */       return ti.getType();
/*     */     }
/* 675 */     return 0;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 684 */   public Element getElement() { return this; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updatePropertyValue(String pn, AnimatableValue val) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updateAttributeValue(String ns, String ln, AnimatableValue val) {
/* 700 */     LiveAttributeValue a = getLiveAttributeValue(ns, ln);
/* 701 */     ((AbstractSVGAnimatedValue)a).updateAnimatedValue(val);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updateOtherValue(String type, AnimatableValue val) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AnimatableValue getUnderlyingValue(String ns, String ln) {
/* 715 */     LiveAttributeValue a = getLiveAttributeValue(ns, ln);
/* 716 */     if (!(a instanceof AnimatedLiveAttributeValue)) {
/* 717 */       return null;
/*     */     }
/* 719 */     return ((AnimatedLiveAttributeValue)a).getUnderlyingValue(this);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 729 */   protected AnimatableValue getBaseValue(SVGAnimatedInteger n, SVGAnimatedInteger on) { return new AnimatableNumberOptionalNumberValue(this, n.getBaseVal(), on.getBaseVal()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 739 */   protected AnimatableValue getBaseValue(SVGAnimatedNumber n, SVGAnimatedNumber on) { return new AnimatableNumberOptionalNumberValue(this, n.getBaseVal(), on.getBaseVal()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public short getPercentageInterpretation(String ns, String an, boolean isCSS) {
/* 749 */     if ((isCSS || ns == null) && (
/* 750 */       an.equals("baseline-shift") || an.equals("font-size")))
/*     */     {
/* 752 */       return 0;
/*     */     }
/*     */     
/* 755 */     if (!isCSS) {
/* 756 */       DoublyIndexedTable t = getTraitInformationTable();
/* 757 */       TraitInformation ti = (TraitInformation)t.get(ns, an);
/* 758 */       if (ti != null) {
/* 759 */         return ti.getPercentageInterpretation();
/*     */       }
/* 761 */       return 3;
/*     */     } 
/*     */     
/* 764 */     return 3;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 771 */   protected final short getAttributePercentageInterpretation(String ns, String ln) { return 3; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 780 */   public boolean useLinearRGBColorInterpolation() { return false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float svgToUserSpace(float v, short type, short pcInterp) {
/* 793 */     if (this.unitContext == null) {
/* 794 */       this.unitContext = new UnitContext(this);
/*     */     }
/* 796 */     if (pcInterp == 0 && type == 2)
/*     */     {
/*     */       
/* 799 */       return 0.0F;
/*     */     }
/* 801 */     return UnitProcessor.svgToUserSpace(v, type, (short)(3 - pcInterp), this.unitContext);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addTargetListener(String ns, String an, boolean isCSS, AnimationTargetListener l) {
/* 811 */     if (!isCSS) {
/* 812 */       if (this.targetListeners == null) {
/* 813 */         this.targetListeners = new DoublyIndexedTable();
/*     */       }
/* 815 */       LinkedList ll = (LinkedList)this.targetListeners.get(ns, an);
/* 816 */       if (ll == null) {
/* 817 */         ll = new LinkedList();
/* 818 */         this.targetListeners.put(ns, an, ll);
/*     */       } 
/* 820 */       ll.add(l);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeTargetListener(String ns, String an, boolean isCSS, AnimationTargetListener l) {
/* 829 */     if (!isCSS) {
/* 830 */       LinkedList ll = (LinkedList)this.targetListeners.get(ns, an);
/* 831 */       ll.remove(l);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void fireBaseAttributeListeners(String ns, String ln) {
/* 840 */     if (this.targetListeners != null) {
/* 841 */       LinkedList ll = (LinkedList)this.targetListeners.get(ns, ln);
/* 842 */       Iterator it = ll.iterator();
/* 843 */       while (it.hasNext()) {
/* 844 */         AnimationTargetListener l = (AnimationTargetListener)it.next();
/* 845 */         l.baseValueChanged(this, ns, ln, false);
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node export(Node n, AbstractDocument d) {
/* 856 */     super.export(n, d);
/* 857 */     SVGOMElement e = (SVGOMElement)n;
/* 858 */     e.prefix = this.prefix;
/* 859 */     e.initializeAllLiveAttributes();
/* 860 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepExport(Node n, AbstractDocument d) {
/* 867 */     super.deepExport(n, d);
/* 868 */     SVGOMElement e = (SVGOMElement)n;
/* 869 */     e.prefix = this.prefix;
/* 870 */     e.initializeAllLiveAttributes();
/* 871 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node copyInto(Node n) {
/* 879 */     super.copyInto(n);
/* 880 */     SVGOMElement e = (SVGOMElement)n;
/* 881 */     e.prefix = this.prefix;
/* 882 */     e.initializeAllLiveAttributes();
/* 883 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepCopyInto(Node n) {
/* 891 */     super.deepCopyInto(n);
/* 892 */     SVGOMElement e = (SVGOMElement)n;
/* 893 */     e.prefix = this.prefix;
/* 894 */     e.initializeAllLiveAttributes();
/* 895 */     return n;
/*     */   }
/*     */   
/*     */   protected class UnitContext implements UnitProcessor.Context {
/*     */     private final SVGOMElement this$0;
/*     */     
/* 901 */     protected UnitContext(SVGOMElement this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 907 */     public Element getElement() { return this.this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 914 */     public float getPixelUnitToMillimeter() { return this.this$0.getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 923 */     public float getPixelToMM() { return getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 930 */     public float getFontSize() { return this.this$0.getSVGContext().getFontSize(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 937 */     public float getXHeight() { return 0.5F; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 944 */     public float getViewportWidth() { return this.this$0.getSVGContext().getViewportWidth(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 951 */     public float getViewportHeight() { return this.this$0.getSVGContext().getViewportHeight(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */