/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ import org.w3c.dom.svg.SVGFECompositeElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMFECompositeElement
/*     */   extends SVGOMFilterPrimitiveStandardAttributes
/*     */   implements SVGFECompositeElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final String[] OPERATOR_VALUES;
/*     */   protected SVGOMAnimatedString in;
/*     */   protected SVGOMAnimatedString in2;
/*     */   protected SVGOMAnimatedEnumeration operator;
/*     */   protected SVGOMAnimatedNumber k1;
/*     */   protected SVGOMAnimatedNumber k2;
/*     */   protected SVGOMAnimatedNumber k3;
/*     */   protected SVGOMAnimatedNumber k4;
/*     */   
/*     */   static  {
/*  46 */     t = new DoublyIndexedTable(SVGOMFilterPrimitiveStandardAttributes.xmlTraitInformation);
/*     */     
/*  48 */     t.put(null, "in", new TraitInformation(true, 16));
/*     */     
/*  50 */     t.put(null, "in2", new TraitInformation(true, 16));
/*     */     
/*  52 */     t.put(null, "operator", new TraitInformation(true, 15));
/*     */     
/*  54 */     t.put(null, "k1", new TraitInformation(true, 2));
/*     */     
/*  56 */     t.put(null, "k2", new TraitInformation(true, 2));
/*     */     
/*  58 */     t.put(null, "k3", new TraitInformation(true, 2));
/*     */     
/*  60 */     t.put(null, "k4", new TraitInformation(true, 2));
/*     */     
/*  62 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  68 */     OPERATOR_VALUES = new String[] { "", "over", "in", "out", "atop", "xor", "arithmetic" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMFECompositeElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMFECompositeElement(String prefix, AbstractDocument owner) {
/* 125 */     super(prefix, owner);
/* 126 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 133 */     super.initializeAllLiveAttributes();
/* 134 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 141 */     this.in = createLiveAnimatedString(null, "in");
/* 142 */     this.in2 = createLiveAnimatedString(null, "in2");
/* 143 */     this.operator = createLiveAnimatedEnumeration(null, "operator", OPERATOR_VALUES, (short)1);
/*     */ 
/*     */     
/* 146 */     this.k1 = createLiveAnimatedNumber(null, "k1", 0.0F);
/* 147 */     this.k2 = createLiveAnimatedNumber(null, "k2", 0.0F);
/* 148 */     this.k3 = createLiveAnimatedNumber(null, "k3", 0.0F);
/* 149 */     this.k4 = createLiveAnimatedNumber(null, "k4", 0.0F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 156 */   public String getLocalName() { return "feComposite"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 163 */   public SVGAnimatedString getIn1() { return this.in; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 170 */   public SVGAnimatedString getIn2() { return this.in2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 177 */   public SVGAnimatedEnumeration getOperator() { return this.operator; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 184 */   public SVGAnimatedNumber getK1() { return this.k1; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 191 */   public SVGAnimatedNumber getK2() { return this.k2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 198 */   public SVGAnimatedNumber getK3() { return this.k3; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 205 */   public SVGAnimatedNumber getK4() { return this.k4; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 212 */   protected Node newNode() { return new SVGOMFECompositeElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 219 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMFECompositeElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */