/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedInteger;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumberList;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ import org.w3c.dom.svg.SVGFEConvolveMatrixElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMFEConvolveMatrixElement
/*     */   extends SVGOMFilterPrimitiveStandardAttributes
/*     */   implements SVGFEConvolveMatrixElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final String[] EDGE_MODE_VALUES;
/*     */   protected SVGOMAnimatedString in;
/*     */   protected SVGOMAnimatedEnumeration edgeMode;
/*     */   protected SVGOMAnimatedNumber bias;
/*     */   protected SVGOMAnimatedBoolean preserveAlpha;
/*     */   
/*     */   static  {
/*  49 */     t = new DoublyIndexedTable(SVGOMFilterPrimitiveStandardAttributes.xmlTraitInformation);
/*     */     
/*  51 */     t.put(null, "in", new TraitInformation(true, 16));
/*     */     
/*  53 */     t.put(null, "order", new TraitInformation(true, 4));
/*     */     
/*  55 */     t.put(null, "kernelUnitLength", new TraitInformation(true, 4));
/*     */     
/*  57 */     t.put(null, "kernelMatrix", new TraitInformation(true, 13));
/*     */     
/*  59 */     t.put(null, "divisor", new TraitInformation(true, 2));
/*     */     
/*  61 */     t.put(null, "bias", new TraitInformation(true, 2));
/*     */     
/*  63 */     t.put(null, "targetX", new TraitInformation(true, 1));
/*     */     
/*  65 */     t.put(null, "targetY", new TraitInformation(true, 1));
/*     */     
/*  67 */     t.put(null, "edgeMode", new TraitInformation(true, 15));
/*     */     
/*  69 */     t.put(null, "preserveAlpha", new TraitInformation(true, 49));
/*     */     
/*  71 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  77 */     EDGE_MODE_VALUES = new String[] { "", "duplicate", "wrap", "none" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMFEConvolveMatrixElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMFEConvolveMatrixElement(String prefix, AbstractDocument owner) {
/* 117 */     super(prefix, owner);
/* 118 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 125 */     super.initializeAllLiveAttributes();
/* 126 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 133 */     this.in = createLiveAnimatedString(null, "in");
/* 134 */     this.edgeMode = createLiveAnimatedEnumeration(null, "edgeMode", EDGE_MODE_VALUES, (short)1);
/*     */ 
/*     */     
/* 137 */     this.bias = createLiveAnimatedNumber(null, "bias", 0.0F);
/* 138 */     this.preserveAlpha = createLiveAnimatedBoolean(null, "preserveAlpha", false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 147 */   public String getLocalName() { return "feConvolveMatrix"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 154 */   public SVGAnimatedString getIn1() { return this.in; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 161 */   public SVGAnimatedEnumeration getEdgeMode() { return this.edgeMode; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 168 */   public SVGAnimatedNumberList getKernelMatrix() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getKernelMatrix is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 176 */   public SVGAnimatedInteger getOrderX() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getOrderX is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 184 */   public SVGAnimatedInteger getOrderY() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getOrderY is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 193 */   public SVGAnimatedInteger getTargetX() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getTargetX is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 202 */   public SVGAnimatedInteger getTargetY() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getTargetY is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 211 */   public SVGAnimatedNumber getDivisor() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getDivisor is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 220 */   public SVGAnimatedNumber getBias() { return this.bias; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 228 */   public SVGAnimatedNumber getKernelUnitLengthX() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getKernelUnitLengthX is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 237 */   public SVGAnimatedNumber getKernelUnitLengthY() { throw new UnsupportedOperationException("SVGFEConvolveMatrixElement.getKernelUnitLengthY is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 246 */   public SVGAnimatedBoolean getPreserveAlpha() { return this.preserveAlpha; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 253 */   protected Node newNode() { return new SVGOMFEConvolveMatrixElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 260 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMFEConvolveMatrixElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */