/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedInteger;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGFETurbulenceElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMFETurbulenceElement
/*     */   extends SVGOMFilterPrimitiveStandardAttributes
/*     */   implements SVGFETurbulenceElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final String[] STITCH_TILES_VALUES;
/*     */   protected static final String[] TYPE_VALUES;
/*     */   protected SVGOMAnimatedInteger numOctaves;
/*     */   protected SVGOMAnimatedNumber seed;
/*     */   protected SVGOMAnimatedEnumeration stitchTiles;
/*     */   protected SVGOMAnimatedEnumeration type;
/*     */   
/*     */   static  {
/*  46 */     t = new DoublyIndexedTable(SVGOMFilterPrimitiveStandardAttributes.xmlTraitInformation);
/*     */     
/*  48 */     t.put(null, "baseFrequency", new TraitInformation(true, 4));
/*     */     
/*  50 */     t.put(null, "numOctaves", new TraitInformation(true, 1));
/*     */     
/*  52 */     t.put(null, "seed", new TraitInformation(true, 2));
/*     */     
/*  54 */     t.put(null, "stitchTiles", new TraitInformation(true, 15));
/*     */     
/*  56 */     t.put(null, "type", new TraitInformation(true, 15));
/*     */     
/*  58 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  64 */     STITCH_TILES_VALUES = new String[] { "", "stitch", "noStitch" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  73 */     TYPE_VALUES = new String[] { "", "fractalNoise", "turbulence" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMFETurbulenceElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMFETurbulenceElement(String prefix, AbstractDocument owner) {
/* 112 */     super(prefix, owner);
/* 113 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 120 */     super.initializeAllLiveAttributes();
/* 121 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 128 */     this.numOctaves = createLiveAnimatedInteger(null, "numOctaves", 1);
/*     */     
/* 130 */     this.seed = createLiveAnimatedNumber(null, "seed", 0.0F);
/* 131 */     this.stitchTiles = createLiveAnimatedEnumeration(null, "stitchTiles", STITCH_TILES_VALUES, (short)2);
/*     */ 
/*     */ 
/*     */     
/* 135 */     this.type = createLiveAnimatedEnumeration(null, "type", TYPE_VALUES, (short)2);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 144 */   public String getLocalName() { return "feTurbulence"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 152 */   public SVGAnimatedNumber getBaseFrequencyX() { throw new UnsupportedOperationException("SVGFETurbulenceElement.getBaseFrequencyX is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 161 */   public SVGAnimatedNumber getBaseFrequencyY() { throw new UnsupportedOperationException("SVGFETurbulenceElement.getBaseFrequencyY is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 169 */   public SVGAnimatedInteger getNumOctaves() { return this.numOctaves; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 176 */   public SVGAnimatedNumber getSeed() { return this.seed; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 183 */   public SVGAnimatedEnumeration getStitchTiles() { return this.stitchTiles; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 190 */   public SVGAnimatedEnumeration getType() { return this.type; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 197 */   protected Node newNode() { return new SVGOMFETurbulenceElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 204 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMFETurbulenceElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */