/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedInteger;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ import org.w3c.dom.svg.SVGFilterElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMFilterElement
/*     */   extends SVGStylableElement
/*     */   implements SVGFilterElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final AttributeInitializer attributeInitializer;
/*     */   protected static final String[] UNITS_VALUES;
/*     */   protected SVGOMAnimatedEnumeration filterUnits;
/*     */   protected SVGOMAnimatedEnumeration primitiveUnits;
/*     */   protected SVGOMAnimatedLength x;
/*     */   protected SVGOMAnimatedLength y;
/*     */   protected SVGOMAnimatedLength width;
/*     */   protected SVGOMAnimatedLength height;
/*     */   protected SVGOMAnimatedString href;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   
/*     */   static  {
/*  50 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  52 */     t.put(null, "filterUnits", new TraitInformation(true, 15));
/*     */     
/*  54 */     t.put(null, "primitiveUnits", new TraitInformation(true, 15));
/*     */     
/*  56 */     t.put(null, "x", new TraitInformation(true, 3, (short)1));
/*     */     
/*  58 */     t.put(null, "y", new TraitInformation(true, 3, (short)2));
/*     */     
/*  60 */     t.put(null, "width", new TraitInformation(true, 3, (short)1));
/*     */     
/*  62 */     t.put(null, "height", new TraitInformation(true, 3, (short)2));
/*     */     
/*  64 */     t.put(null, "filterRes", new TraitInformation(true, 4));
/*     */     
/*  66 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  74 */     attributeInitializer = new AttributeInitializer(4);
/*  75 */     attributeInitializer.addAttribute("http://www.w3.org/2000/xmlns/", null, "xmlns:xlink", "http://www.w3.org/1999/xlink");
/*     */ 
/*     */     
/*  78 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "type", "simple");
/*     */     
/*  80 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "show", "other");
/*     */     
/*  82 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "actuate", "onLoad");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  89 */     UNITS_VALUES = new String[] { "", "userSpaceOnUse", "objectBoundingBox" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMFilterElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMFilterElement(String prefix, AbstractDocument owner) {
/* 147 */     super(prefix, owner);
/* 148 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 155 */     super.initializeAllLiveAttributes();
/* 156 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 163 */     this.filterUnits = createLiveAnimatedEnumeration(null, "filterUnits", UNITS_VALUES, (short)2);
/*     */ 
/*     */     
/* 166 */     this.primitiveUnits = createLiveAnimatedEnumeration(null, "primitiveUnits", UNITS_VALUES, (short)1);
/*     */ 
/*     */     
/* 169 */     this.x = createLiveAnimatedLength(null, "x", "-10%", (short)2, false);
/*     */ 
/*     */     
/* 172 */     this.y = createLiveAnimatedLength(null, "y", "-10%", (short)1, false);
/*     */ 
/*     */     
/* 175 */     this.width = createLiveAnimatedLength(null, "width", "120%", (short)2, true);
/*     */ 
/*     */ 
/*     */     
/* 179 */     this.height = createLiveAnimatedLength(null, "height", "120%", (short)1, true);
/*     */ 
/*     */ 
/*     */     
/* 183 */     this.href = createLiveAnimatedString("http://www.w3.org/1999/xlink", "href");
/*     */     
/* 185 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 194 */   public String getLocalName() { return "filter"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 201 */   public SVGAnimatedEnumeration getFilterUnits() { return this.filterUnits; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 208 */   public SVGAnimatedEnumeration getPrimitiveUnits() { return this.primitiveUnits; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 215 */   public SVGAnimatedLength getX() { return this.x; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 222 */   public SVGAnimatedLength getY() { return this.y; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 229 */   public SVGAnimatedLength getWidth() { return this.width; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 236 */   public SVGAnimatedLength getHeight() { return this.height; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 243 */   public SVGAnimatedInteger getFilterResX() { throw new UnsupportedOperationException("SVGFilterElement.getFilterResX is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 251 */   public SVGAnimatedInteger getFilterResY() { throw new UnsupportedOperationException("SVGFilterElement.getFilterResY is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 259 */   public void setFilterRes(int filterResX, int filterResY) { throw new UnsupportedOperationException("SVGFilterElement.setFilterRes is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 269 */   public SVGAnimatedString getHref() { return this.href; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 279 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 286 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 295 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 302 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 309 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 316 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 324 */   protected AttributeInitializer getAttributeInitializer() { return attributeInitializer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 331 */   protected Node newNode() { return new SVGOMFilterElement(); }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMFilterElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */