/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAngle;
/*     */ import org.w3c.dom.svg.SVGAnimatedAngle;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGAnimatedPreserveAspectRatio;
/*     */ import org.w3c.dom.svg.SVGAnimatedRect;
/*     */ import org.w3c.dom.svg.SVGMarkerElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMMarkerElement
/*     */   extends SVGStylableElement
/*     */   implements SVGMarkerElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final AttributeInitializer attributeInitializer;
/*     */   protected static final String[] UNITS_VALUES;
/*     */   protected static final String[] ORIENT_TYPE_VALUES;
/*     */   protected SVGOMAnimatedLength refX;
/*     */   protected SVGOMAnimatedLength refY;
/*     */   protected SVGOMAnimatedLength markerWidth;
/*     */   protected SVGOMAnimatedLength markerHeight;
/*     */   protected SVGOMAnimatedMarkerOrientValue orient;
/*     */   protected SVGOMAnimatedEnumeration markerUnits;
/*     */   protected SVGOMAnimatedPreserveAspectRatio preserveAspectRatio;
/*     */   protected SVGOMAnimatedRect viewBox;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   
/*     */   static  {
/*  51 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  53 */     t.put(null, "refX", new TraitInformation(true, 3, (short)1));
/*     */     
/*  55 */     t.put(null, "refY", new TraitInformation(true, 3, (short)2));
/*     */     
/*  57 */     t.put(null, "markerWidth", new TraitInformation(true, 3, (short)1));
/*     */     
/*  59 */     t.put(null, "markerHeight", new TraitInformation(true, 3, (short)2));
/*     */     
/*  61 */     t.put(null, "markerUnits", new TraitInformation(true, 15));
/*     */     
/*  63 */     t.put(null, "orient", new TraitInformation(true, 15));
/*     */     
/*  65 */     t.put(null, "preserveAspectRatio", new TraitInformation(true, 32));
/*     */     
/*  67 */     t.put(null, "externalResourcesRequired", new TraitInformation(true, 49));
/*     */     
/*  69 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  77 */     attributeInitializer = new AttributeInitializer(1);
/*  78 */     attributeInitializer.addAttribute(null, null, "preserveAspectRatio", "xMidYMid meet");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  87 */     UNITS_VALUES = new String[] { "", "userSpaceOnUse", "stroke-width" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  96 */     ORIENT_TYPE_VALUES = new String[] { "", "auto", "" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMMarkerElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMMarkerElement(String prefix, AbstractDocument owner) {
/* 159 */     super(prefix, owner);
/* 160 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 167 */     super.initializeAllLiveAttributes();
/* 168 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 175 */     this.refX = createLiveAnimatedLength(null, "refX", "0", (short)2, false);
/*     */ 
/*     */ 
/*     */     
/* 179 */     this.refY = createLiveAnimatedLength(null, "refY", "0", (short)1, false);
/*     */ 
/*     */ 
/*     */     
/* 183 */     this.markerWidth = createLiveAnimatedLength(null, "markerWidth", "3", (short)2, true);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 188 */     this.markerHeight = createLiveAnimatedLength(null, "markerHeight", "3", (short)1, true);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 193 */     this.orient = createLiveAnimatedMarkerOrientValue(null, "orient");
/*     */     
/* 195 */     this.markerUnits = createLiveAnimatedEnumeration(null, "markerUnits", UNITS_VALUES, (short)2);
/*     */ 
/*     */     
/* 198 */     this.preserveAspectRatio = createLiveAnimatedPreserveAspectRatio();
/*     */     
/* 200 */     this.viewBox = createLiveAnimatedRect(null, "viewBox", null);
/* 201 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 210 */   public String getLocalName() { return "marker"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 217 */   public SVGAnimatedLength getRefX() { return this.refX; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 224 */   public SVGAnimatedLength getRefY() { return this.refY; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 231 */   public SVGAnimatedEnumeration getMarkerUnits() { return this.markerUnits; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 238 */   public SVGAnimatedLength getMarkerWidth() { return this.markerWidth; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 245 */   public SVGAnimatedLength getMarkerHeight() { return this.markerHeight; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 252 */   public SVGAnimatedEnumeration getOrientType() { return this.orient.getAnimatedEnumeration(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 259 */   public SVGAnimatedAngle getOrientAngle() { return this.orient.getAnimatedAngle(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 266 */   public void setOrientToAuto() { setAttributeNS(null, "orient", "auto"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 274 */   public void setOrientToAngle(SVGAngle angle) { setAttributeNS(null, "orient", angle.getValueAsString()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 284 */   public SVGAnimatedRect getViewBox() { return this.viewBox; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 292 */   public SVGAnimatedPreserveAspectRatio getPreserveAspectRatio() { return this.preserveAspectRatio; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 302 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 311 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 318 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 325 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 332 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 340 */   protected AttributeInitializer getAttributeInitializer() { return attributeInitializer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 347 */   protected Node newNode() { return new SVGOMMarkerElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 354 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMMarkerElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */