/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedNumber;
/*     */ import org.w3c.dom.svg.SVGPathElement;
/*     */ import org.w3c.dom.svg.SVGPathSegArcAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegArcRel;
/*     */ import org.w3c.dom.svg.SVGPathSegClosePath;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicRel;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicSmoothAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicSmoothRel;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticRel;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticSmoothAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticSmoothRel;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoHorizontalAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoHorizontalRel;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoRel;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoVerticalAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegLinetoVerticalRel;
/*     */ import org.w3c.dom.svg.SVGPathSegList;
/*     */ import org.w3c.dom.svg.SVGPathSegMovetoAbs;
/*     */ import org.w3c.dom.svg.SVGPathSegMovetoRel;
/*     */ import org.w3c.dom.svg.SVGPoint;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMPathElement
/*     */   extends SVGGraphicsElement
/*     */   implements SVGPathElement, SVGPathSegConstants
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected SVGOMAnimatedPathData d;
/*     */   
/*     */   static  {
/*  67 */     t = new DoublyIndexedTable(SVGGraphicsElement.xmlTraitInformation);
/*     */     
/*  69 */     t.put(null, "d", new TraitInformation(true, 22));
/*     */     
/*  71 */     t.put(null, "pathLength", new TraitInformation(true, 2));
/*     */     
/*  73 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMPathElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMPathElement(String prefix, AbstractDocument owner) {
/*  93 */     super(prefix, owner);
/*  94 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 101 */     super.initializeAllLiveAttributes();
/* 102 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 109 */   private void initializeLiveAttributes() { this.d = createLiveAnimatedPathData(null, "d", ""); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   public String getLocalName() { return "path"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 123 */   public SVGAnimatedNumber getPathLength() { throw new UnsupportedOperationException("SVGPathElement.getPathLength is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 131 */   public float getTotalLength() { return SVGPathSupport.getTotalLength(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 138 */   public SVGPoint getPointAtLength(float distance) { return SVGPathSupport.getPointAtLength(this, distance); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 145 */   public int getPathSegAtLength(float distance) { return SVGPathSupport.getPathSegAtLength(this, distance); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 153 */   public SVGOMAnimatedPathData getAnimatedPathData() { return this.d; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 160 */   public SVGPathSegList getPathSegList() { return this.d.getPathSegList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 167 */   public SVGPathSegList getNormalizedPathSegList() { return this.d.getNormalizedPathSegList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 174 */   public SVGPathSegList getAnimatedPathSegList() { return this.d.getAnimatedPathSegList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 182 */   public SVGPathSegList getAnimatedNormalizedPathSegList() { return this.d.getAnimatedNormalizedPathSegList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegClosePath createSVGPathSegClosePath() {
/* 191 */     return new SVGPathSegClosePath(this) { private final SVGOMPathElement this$0;
/*     */         
/* 193 */         public short getPathSegType() { return 1; }
/*     */ 
/*     */         
/* 196 */         public String getPathSegTypeAsLetter() { return "z"; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegMovetoAbs createSVGPathSegMovetoAbs(float x_value, float y_value) {
/* 206 */     return new SVGPathSegMovetoAbs(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 211 */         public short getPathSegType() { return 2; }
/*     */ 
/*     */         
/* 214 */         public String getPathSegTypeAsLetter() { return "M"; }
/*     */ 
/*     */         
/* 217 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 220 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 223 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 226 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegMovetoRel createSVGPathSegMovetoRel(float x_value, float y_value) {
/* 236 */     return new SVGPathSegMovetoRel(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 241 */         public short getPathSegType() { return 3; }
/*     */ 
/*     */         
/* 244 */         public String getPathSegTypeAsLetter() { return "m"; }
/*     */ 
/*     */         
/* 247 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 250 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 253 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 256 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoAbs createSVGPathSegLinetoAbs(float x_value, float y_value) {
/* 266 */     return new SVGPathSegLinetoAbs(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 271 */         public short getPathSegType() { return 4; }
/*     */ 
/*     */         
/* 274 */         public String getPathSegTypeAsLetter() { return "L"; }
/*     */ 
/*     */         
/* 277 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 280 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 283 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 286 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoRel createSVGPathSegLinetoRel(float x_value, float y_value) {
/* 296 */     return new SVGPathSegLinetoRel(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 301 */         public short getPathSegType() { return 5; }
/*     */ 
/*     */         
/* 304 */         public String getPathSegTypeAsLetter() { return "l"; }
/*     */ 
/*     */         
/* 307 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 310 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 313 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 316 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoHorizontalAbs createSVGPathSegLinetoHorizontalAbs(float x_value) {
/* 326 */     return new SVGPathSegLinetoHorizontalAbs(this, x_value) { protected float x;
/*     */         private final float val$x_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 330 */         public short getPathSegType() { return 12; }
/*     */ 
/*     */         
/* 333 */         public String getPathSegTypeAsLetter() { return "H"; }
/*     */ 
/*     */         
/* 336 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 339 */         public void setX(float x) { this.x = x; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoHorizontalRel createSVGPathSegLinetoHorizontalRel(float x_value) {
/* 349 */     return new SVGPathSegLinetoHorizontalRel(this, x_value) { protected float x;
/*     */         private final float val$x_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 353 */         public short getPathSegType() { return 13; }
/*     */ 
/*     */         
/* 356 */         public String getPathSegTypeAsLetter() { return "h"; }
/*     */ 
/*     */         
/* 359 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 362 */         public void setX(float x) { this.x = x; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoVerticalAbs createSVGPathSegLinetoVerticalAbs(float y_value) {
/* 372 */     return new SVGPathSegLinetoVerticalAbs(this, y_value) { protected float y;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 376 */         public short getPathSegType() { return 14; }
/*     */ 
/*     */         
/* 379 */         public String getPathSegTypeAsLetter() { return "V"; }
/*     */ 
/*     */         
/* 382 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 385 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegLinetoVerticalRel createSVGPathSegLinetoVerticalRel(float y_value) {
/* 395 */     return new SVGPathSegLinetoVerticalRel(this, y_value) { protected float y;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 399 */         public short getPathSegType() { return 15; }
/*     */ 
/*     */         
/* 402 */         public String getPathSegTypeAsLetter() { return "v"; }
/*     */ 
/*     */         
/* 405 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 408 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoCubicAbs createSVGPathSegCurvetoCubicAbs(float x_value, float y_value, float x1_value, float y1_value, float x2_value, float y2_value) {
/* 421 */     return new SVGPathSegCurvetoCubicAbs(this, x_value, y_value, x1_value, y1_value, x2_value, y2_value) { protected float x; protected float y; protected float x1; protected float y1; protected float x2; protected float y2;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x1_value;
/*     */         private final float val$y1_value;
/*     */         private final float val$x2_value;
/*     */         private final float val$y2_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 430 */         public short getPathSegType() { return 6; }
/*     */ 
/*     */         
/* 433 */         public String getPathSegTypeAsLetter() { return "C"; }
/*     */ 
/*     */         
/* 436 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 439 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 442 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 445 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 448 */         public float getX1() { return this.x1; }
/*     */ 
/*     */         
/* 451 */         public void setX1(float x1) { this.x1 = x1; }
/*     */ 
/*     */         
/* 454 */         public float getY1() { return this.y1; }
/*     */ 
/*     */         
/* 457 */         public void setY1(float y1) { this.y1 = y1; }
/*     */ 
/*     */         
/* 460 */         public float getX2() { return this.x2; }
/*     */ 
/*     */         
/* 463 */         public void setX2(float x2) { this.x2 = x2; }
/*     */ 
/*     */         
/* 466 */         public float getY2() { return this.y2; }
/*     */ 
/*     */         
/* 469 */         public void setY2(float y2) { this.y2 = y2; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoCubicRel createSVGPathSegCurvetoCubicRel(float x_value, float y_value, float x1_value, float y1_value, float x2_value, float y2_value) {
/* 482 */     return new SVGPathSegCurvetoCubicRel(this, x_value, y_value, x1_value, y1_value, x2_value, y2_value) { protected float x; protected float y; protected float x1; protected float y1; protected float x2; protected float y2;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x1_value;
/*     */         private final float val$y1_value;
/*     */         private final float val$x2_value;
/*     */         private final float val$y2_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 491 */         public short getPathSegType() { return 7; }
/*     */ 
/*     */         
/* 494 */         public String getPathSegTypeAsLetter() { return "c"; }
/*     */ 
/*     */         
/* 497 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 500 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 503 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 506 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 509 */         public float getX1() { return this.x1; }
/*     */ 
/*     */         
/* 512 */         public void setX1(float x1) { this.x1 = x1; }
/*     */ 
/*     */         
/* 515 */         public float getY1() { return this.y1; }
/*     */ 
/*     */         
/* 518 */         public void setY1(float y1) { this.y1 = y1; }
/*     */ 
/*     */         
/* 521 */         public float getX2() { return this.x2; }
/*     */ 
/*     */         
/* 524 */         public void setX2(float x2) { this.x2 = x2; }
/*     */ 
/*     */         
/* 527 */         public float getY2() { return this.y2; }
/*     */ 
/*     */         
/* 530 */         public void setY2(float y2) { this.y2 = y2; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoQuadraticAbs createSVGPathSegCurvetoQuadraticAbs(float x_value, float y_value, float x1_value, float y1_value) {
/* 542 */     return new SVGPathSegCurvetoQuadraticAbs(this, x_value, y_value, x1_value, y1_value) { protected float x; protected float y; protected float x1; protected float y1;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x1_value;
/*     */         private final float val$y1_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 549 */         public short getPathSegType() { return 8; }
/*     */ 
/*     */         
/* 552 */         public String getPathSegTypeAsLetter() { return "Q"; }
/*     */ 
/*     */         
/* 555 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 558 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 561 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 564 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 567 */         public float getX1() { return this.x1; }
/*     */ 
/*     */         
/* 570 */         public void setX1(float x1) { this.x1 = x1; }
/*     */ 
/*     */         
/* 573 */         public float getY1() { return this.y1; }
/*     */ 
/*     */         
/* 576 */         public void setY1(float y1) { this.y1 = y1; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoQuadraticRel createSVGPathSegCurvetoQuadraticRel(float x_value, float y_value, float x1_value, float y1_value) {
/* 588 */     return new SVGPathSegCurvetoQuadraticRel(this, x_value, y_value, x1_value, y1_value) { protected float x; protected float y; protected float x1; protected float y1;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x1_value;
/*     */         private final float val$y1_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 595 */         public short getPathSegType() { return 9; }
/*     */ 
/*     */         
/* 598 */         public String getPathSegTypeAsLetter() { return "q"; }
/*     */ 
/*     */         
/* 601 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 604 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 607 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 610 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 613 */         public float getX1() { return this.x1; }
/*     */ 
/*     */         
/* 616 */         public void setX1(float x1) { this.x1 = x1; }
/*     */ 
/*     */         
/* 619 */         public float getY1() { return this.y1; }
/*     */ 
/*     */         
/* 622 */         public void setY1(float y1) { this.y1 = y1; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoCubicSmoothAbs createSVGPathSegCurvetoCubicSmoothAbs(float x_value, float y_value, float x2_value, float y2_value) {
/* 635 */     return new SVGPathSegCurvetoCubicSmoothAbs(this, x_value, y_value, x2_value, y2_value) { protected float x; protected float y; protected float x2; protected float y2;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x2_value;
/*     */         private final float val$y2_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 642 */         public short getPathSegType() { return 16; }
/*     */ 
/*     */         
/* 645 */         public String getPathSegTypeAsLetter() { return "S"; }
/*     */ 
/*     */         
/* 648 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 651 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 654 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 657 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 660 */         public float getX2() { return this.x2; }
/*     */ 
/*     */         
/* 663 */         public void setX2(float x2) { this.x2 = x2; }
/*     */ 
/*     */         
/* 666 */         public float getY2() { return this.y2; }
/*     */ 
/*     */         
/* 669 */         public void setY2(float y2) { this.y2 = y2; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoCubicSmoothRel createSVGPathSegCurvetoCubicSmoothRel(float x_value, float y_value, float x2_value, float y2_value) {
/* 682 */     return new SVGPathSegCurvetoCubicSmoothRel(this, x_value, y_value, x2_value, y2_value) { protected float x; protected float y; protected float x2; protected float y2;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$x2_value;
/*     */         private final float val$y2_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 689 */         public short getPathSegType() { return 17; }
/*     */ 
/*     */         
/* 692 */         public String getPathSegTypeAsLetter() { return "s"; }
/*     */ 
/*     */         
/* 695 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 698 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 701 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 704 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 707 */         public float getX2() { return this.x2; }
/*     */ 
/*     */         
/* 710 */         public void setX2(float x2) { this.x2 = x2; }
/*     */ 
/*     */         
/* 713 */         public float getY2() { return this.y2; }
/*     */ 
/*     */         
/* 716 */         public void setY2(float y2) { this.y2 = y2; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoQuadraticSmoothAbs createSVGPathSegCurvetoQuadraticSmoothAbs(float x_value, float y_value) {
/* 728 */     return new SVGPathSegCurvetoQuadraticSmoothAbs(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 733 */         public short getPathSegType() { return 18; }
/*     */ 
/*     */         
/* 736 */         public String getPathSegTypeAsLetter() { return "T"; }
/*     */ 
/*     */         
/* 739 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 742 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 745 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 748 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegCurvetoQuadraticSmoothRel createSVGPathSegCurvetoQuadraticSmoothRel(float x_value, float y_value) {
/* 761 */     return new SVGPathSegCurvetoQuadraticSmoothRel(this, x_value, y_value) { protected float x; protected float y;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 766 */         public short getPathSegType() { return 19; }
/*     */ 
/*     */         
/* 769 */         public String getPathSegTypeAsLetter() { return "t"; }
/*     */ 
/*     */         
/* 772 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 775 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 778 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 781 */         public void setY(float y) { this.y = y; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegArcAbs createSVGPathSegArcAbs(float x_value, float y_value, float r1_value, float r2_value, float angle_value, boolean largeArcFlag_value, boolean sweepFlag_value) {
/* 796 */     return new SVGPathSegArcAbs(this, x_value, y_value, r1_value, r2_value, angle_value, largeArcFlag_value, sweepFlag_value)
/*     */       {
/*     */         protected float x;
/*     */         protected float y;
/*     */         protected float r1;
/*     */         protected float r2;
/*     */         protected float angle;
/*     */         protected boolean largeArcFlag;
/*     */         protected boolean sweepFlag;
/*     */         
/* 806 */         public short getPathSegType() { return 10; }
/*     */         private final float val$x_value; private final float val$y_value; private final float val$r1_value; private final float val$r2_value; private final float val$angle_value; private final boolean val$largeArcFlag_value; private final boolean val$sweepFlag_value; private final SVGOMPathElement this$0;
/*     */         
/* 809 */         public String getPathSegTypeAsLetter() { return "A"; }
/*     */ 
/*     */         
/* 812 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 815 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 818 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 821 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 824 */         public float getR1() { return this.r1; }
/*     */ 
/*     */         
/* 827 */         public void setR1(float r1) { this.r1 = r1; }
/*     */ 
/*     */         
/* 830 */         public float getR2() { return this.r2; }
/*     */ 
/*     */         
/* 833 */         public void setR2(float r2) { this.r2 = r2; }
/*     */ 
/*     */         
/* 836 */         public float getAngle() { return this.angle; }
/*     */ 
/*     */         
/* 839 */         public void setAngle(float angle) { this.angle = angle; }
/*     */ 
/*     */         
/* 842 */         public boolean getLargeArcFlag() { return this.largeArcFlag; }
/*     */ 
/*     */         
/* 845 */         public void setLargeArcFlag(boolean largeArcFlag) { this.largeArcFlag = largeArcFlag; }
/*     */ 
/*     */         
/* 848 */         public boolean getSweepFlag() { return this.sweepFlag; }
/*     */ 
/*     */         
/* 851 */         public void setSweepFlag(boolean sweepFlag) { this.sweepFlag = sweepFlag; }
/*     */       };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPathSegArcRel createSVGPathSegArcRel(float x_value, float y_value, float r1_value, float r2_value, float angle_value, boolean largeArcFlag_value, boolean sweepFlag_value) {
/* 868 */     return new SVGPathSegArcRel(this, x_value, y_value, r1_value, r2_value, angle_value, largeArcFlag_value, sweepFlag_value) { protected float x; protected float y; protected float r1; protected float r2; protected float angle; protected boolean largeArcFlag; protected boolean sweepFlag;
/*     */         private final float val$x_value;
/*     */         private final float val$y_value;
/*     */         private final float val$r1_value;
/*     */         private final float val$r2_value;
/*     */         private final float val$angle_value;
/*     */         private final boolean val$largeArcFlag_value;
/*     */         private final boolean val$sweepFlag_value;
/*     */         private final SVGOMPathElement this$0;
/*     */         
/* 878 */         public short getPathSegType() { return 11; }
/*     */ 
/*     */         
/* 881 */         public String getPathSegTypeAsLetter() { return "a"; }
/*     */ 
/*     */         
/* 884 */         public float getX() { return this.x; }
/*     */ 
/*     */         
/* 887 */         public void setX(float x) { this.x = x; }
/*     */ 
/*     */         
/* 890 */         public float getY() { return this.y; }
/*     */ 
/*     */         
/* 893 */         public void setY(float y) { this.y = y; }
/*     */ 
/*     */         
/* 896 */         public float getR1() { return this.r1; }
/*     */ 
/*     */         
/* 899 */         public void setR1(float r1) { this.r1 = r1; }
/*     */ 
/*     */         
/* 902 */         public float getR2() { return this.r2; }
/*     */ 
/*     */         
/* 905 */         public void setR2(float r2) { this.r2 = r2; }
/*     */ 
/*     */         
/* 908 */         public float getAngle() { return this.angle; }
/*     */ 
/*     */         
/* 911 */         public void setAngle(float angle) { this.angle = angle; }
/*     */ 
/*     */         
/* 914 */         public boolean getLargeArcFlag() { return this.largeArcFlag; }
/*     */ 
/*     */         
/* 917 */         public void setLargeArcFlag(boolean largeArcFlag) { this.largeArcFlag = largeArcFlag; }
/*     */ 
/*     */         
/* 920 */         public boolean getSweepFlag() { return this.sweepFlag; }
/*     */ 
/*     */         
/* 923 */         public void setSweepFlag(boolean sweepFlag) { this.sweepFlag = sweepFlag; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 934 */   protected Node newNode() { return new SVGOMPathElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 941 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMPathElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */