/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGAnimatedPreserveAspectRatio;
/*     */ import org.w3c.dom.svg.SVGAnimatedRect;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ import org.w3c.dom.svg.SVGAnimatedTransformList;
/*     */ import org.w3c.dom.svg.SVGPatternElement;
/*     */ import org.w3c.dom.svg.SVGStringList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMPatternElement
/*     */   extends SVGStylableElement
/*     */   implements SVGPatternElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final AttributeInitializer attributeInitializer;
/*     */   protected static final String[] UNITS_VALUES;
/*     */   protected SVGOMAnimatedLength x;
/*     */   protected SVGOMAnimatedLength y;
/*     */   protected SVGOMAnimatedLength width;
/*     */   protected SVGOMAnimatedLength height;
/*     */   protected SVGOMAnimatedEnumeration patternUnits;
/*     */   protected SVGOMAnimatedEnumeration patternContentUnits;
/*     */   protected SVGOMAnimatedString href;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   protected SVGOMAnimatedPreserveAspectRatio preserveAspectRatio;
/*     */   
/*     */   static  {
/*  53 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  55 */     t.put(null, "x", new TraitInformation(true, 3, (short)1));
/*     */     
/*  57 */     t.put(null, "y", new TraitInformation(true, 3, (short)2));
/*     */     
/*  59 */     t.put(null, "width", new TraitInformation(true, 3, (short)1));
/*     */     
/*  61 */     t.put(null, "height", new TraitInformation(true, 3, (short)2));
/*     */     
/*  63 */     t.put(null, "patternUnits", new TraitInformation(true, 15));
/*     */     
/*  65 */     t.put(null, "patternContentUnits", new TraitInformation(true, 15));
/*     */     
/*  67 */     t.put(null, "patternTransform", new TraitInformation(true, 9));
/*     */     
/*  69 */     t.put(null, "viewBox", new TraitInformation(true, 13));
/*     */     
/*  71 */     t.put(null, "preserveAspectRatio", new TraitInformation(true, 32));
/*     */     
/*  73 */     t.put(null, "externalResourcesRequired", new TraitInformation(true, 49));
/*     */     
/*  75 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  83 */     attributeInitializer = new AttributeInitializer(5);
/*  84 */     attributeInitializer.addAttribute(null, null, "preserveAspectRatio", "xMidYMid meet");
/*     */ 
/*     */     
/*  87 */     attributeInitializer.addAttribute("http://www.w3.org/2000/xmlns/", null, "xmlns:xlink", "http://www.w3.org/1999/xlink");
/*     */ 
/*     */     
/*  90 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "type", "simple");
/*     */     
/*  92 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "show", "other");
/*     */     
/*  94 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "actuate", "onLoad");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 101 */     UNITS_VALUES = new String[] { "", "userSpaceOnUse", "objectBoundingBox" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMPatternElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMPatternElement(String prefix, AbstractDocument owner) {
/* 165 */     super(prefix, owner);
/* 166 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 173 */     super.initializeAllLiveAttributes();
/* 174 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 181 */     this.x = createLiveAnimatedLength(null, "x", "0", (short)2, false);
/*     */ 
/*     */     
/* 184 */     this.y = createLiveAnimatedLength(null, "y", "0", (short)1, false);
/*     */ 
/*     */     
/* 187 */     this.width = createLiveAnimatedLength(null, "width", "0", (short)2, true);
/*     */ 
/*     */ 
/*     */     
/* 191 */     this.height = createLiveAnimatedLength(null, "height", "0", (short)1, true);
/*     */ 
/*     */ 
/*     */     
/* 195 */     this.patternUnits = createLiveAnimatedEnumeration(null, "patternUnits", UNITS_VALUES, (short)2);
/*     */ 
/*     */     
/* 198 */     this.patternContentUnits = createLiveAnimatedEnumeration(null, "patternContentUnits", UNITS_VALUES, (short)1);
/*     */ 
/*     */ 
/*     */     
/* 202 */     this.href = createLiveAnimatedString("http://www.w3.org/1999/xlink", "href");
/*     */     
/* 204 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */ 
/*     */     
/* 207 */     this.preserveAspectRatio = createLiveAnimatedPreserveAspectRatio();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 214 */   public String getLocalName() { return "pattern"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 221 */   public SVGAnimatedTransformList getPatternTransform() { throw new UnsupportedOperationException("SVGPatternElement.getPatternTransform is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 229 */   public SVGAnimatedEnumeration getPatternUnits() { return this.patternUnits; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 237 */   public SVGAnimatedEnumeration getPatternContentUnits() { return this.patternContentUnits; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 244 */   public SVGAnimatedLength getX() { return this.x; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 251 */   public SVGAnimatedLength getY() { return this.y; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 258 */   public SVGAnimatedLength getWidth() { return this.width; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 266 */   public SVGAnimatedLength getHeight() { return this.height; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 273 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 283 */   public SVGAnimatedString getHref() { return this.href; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 293 */   public SVGAnimatedRect getViewBox() { throw new UnsupportedOperationException("SVGFitToViewBox.getViewBox is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 302 */   public SVGAnimatedPreserveAspectRatio getPreserveAspectRatio() { return this.preserveAspectRatio; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 312 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 321 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 328 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 335 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 342 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 352 */   public SVGStringList getRequiredFeatures() { return SVGTestsSupport.getRequiredFeatures(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 360 */   public SVGStringList getRequiredExtensions() { return SVGTestsSupport.getRequiredExtensions(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 368 */   public SVGStringList getSystemLanguage() { return SVGTestsSupport.getSystemLanguage(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 376 */   public boolean hasExtension(String extension) { return SVGTestsSupport.hasExtension(this, extension); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 384 */   protected AttributeInitializer getAttributeInitializer() { return attributeInitializer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 391 */   protected Node newNode() { return new SVGOMPatternElement(); }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMPatternElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */