/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGRectElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMRectElement
/*     */   extends SVGGraphicsElement
/*     */   implements SVGRectElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected SVGOMAnimatedLength x;
/*     */   protected SVGOMAnimatedLength y;
/*     */   protected AbstractSVGAnimatedLength rx;
/*     */   protected AbstractSVGAnimatedLength ry;
/*     */   protected SVGOMAnimatedLength width;
/*     */   protected SVGOMAnimatedLength height;
/*     */   
/*     */   static  {
/*  46 */     t = new DoublyIndexedTable(SVGGraphicsElement.xmlTraitInformation);
/*     */     
/*  48 */     t.put(null, "x", new TraitInformation(true, 3, (short)1));
/*     */     
/*  50 */     t.put(null, "y", new TraitInformation(true, 3, (short)2));
/*     */     
/*  52 */     t.put(null, "rx", new TraitInformation(true, 3, (short)1));
/*     */     
/*  54 */     t.put(null, "ry", new TraitInformation(true, 3, (short)2));
/*     */     
/*  56 */     t.put(null, "width", new TraitInformation(true, 3, (short)1));
/*     */     
/*  58 */     t.put(null, "height", new TraitInformation(true, 3, (short)2));
/*     */     
/*  60 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMRectElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMRectElement(String prefix, AbstractDocument owner) {
/* 105 */     super(prefix, owner);
/* 106 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 113 */     super.initializeAllLiveAttributes();
/* 114 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 121 */     this.x = createLiveAnimatedLength(null, "x", "0", (short)2, false);
/*     */ 
/*     */     
/* 124 */     this.y = createLiveAnimatedLength(null, "y", "0", (short)1, false);
/*     */ 
/*     */     
/* 127 */     this.width = createLiveAnimatedLength(null, "width", null, (short)2, true);
/*     */ 
/*     */ 
/*     */     
/* 131 */     this.height = createLiveAnimatedLength(null, "height", null, (short)1, true);
/*     */ 
/*     */ 
/*     */     
/* 135 */     this.rx = new AbstractSVGAnimatedLength(this, this, null, "rx", (short)2, true) {
/*     */         private final SVGOMRectElement this$0;
/*     */         
/*     */         protected String getDefaultValue() {
/* 139 */           Attr attr = this.this$0.getAttributeNodeNS(null, "ry");
/* 140 */           if (attr == null) {
/* 141 */             return "0";
/*     */           }
/* 143 */           return attr.getValue();
/*     */         }
/*     */         protected void attrChanged() {
/* 146 */           super.attrChanged();
/* 147 */           AbstractSVGAnimatedLength ry = (AbstractSVGAnimatedLength)this.this$0.getRy();
/*     */           
/* 149 */           if (isSpecified() && !ry.isSpecified()) {
/* 150 */             ry.attrChanged();
/*     */           }
/*     */         }
/*     */       };
/* 154 */     this.ry = new AbstractSVGAnimatedLength(this, this, null, "ry", (short)1, true) {
/*     */         private final SVGOMRectElement this$0;
/*     */         
/*     */         protected String getDefaultValue() {
/* 158 */           Attr attr = this.this$0.getAttributeNodeNS(null, "rx");
/* 159 */           if (attr == null) {
/* 160 */             return "0";
/*     */           }
/* 162 */           return attr.getValue();
/*     */         }
/*     */         protected void attrChanged() {
/* 165 */           super.attrChanged();
/* 166 */           AbstractSVGAnimatedLength rx = (AbstractSVGAnimatedLength)this.this$0.getRx();
/*     */           
/* 168 */           if (isSpecified() && !rx.isSpecified()) {
/* 169 */             rx.attrChanged();
/*     */           }
/*     */         }
/*     */       };
/*     */     
/* 174 */     this.liveAttributeValues.put(null, "rx", this.rx);
/* 175 */     this.liveAttributeValues.put(null, "ry", this.ry);
/* 176 */     AnimatedAttributeListener l = ((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener();
/*     */     
/* 178 */     this.rx.addAnimatedAttributeListener(l);
/* 179 */     this.ry.addAnimatedAttributeListener(l);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 186 */   public String getLocalName() { return "rect"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 193 */   public SVGAnimatedLength getX() { return this.x; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 200 */   public SVGAnimatedLength getY() { return this.y; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 207 */   public SVGAnimatedLength getWidth() { return this.width; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 214 */   public SVGAnimatedLength getHeight() { return this.height; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 221 */   public SVGAnimatedLength getRx() { return this.rx; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 228 */   public SVGAnimatedLength getRy() { return this.ry; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 235 */   protected Node newNode() { return new SVGOMRectElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 242 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updateAttributeValue(String ns, String ln, AnimatableValue val) {
/* 252 */     if (ns == null) {
/* 253 */       if (ln.equals("rx")) {
/* 254 */         super.updateAttributeValue(ns, ln, val);
/* 255 */         AbstractSVGAnimatedLength ry = (AbstractSVGAnimatedLength)getRy();
/*     */         
/* 257 */         if (!ry.isSpecified())
/* 258 */           super.updateAttributeValue(ns, "ry", val); 
/*     */         return;
/*     */       } 
/* 261 */       if (ln.equals("ry")) {
/* 262 */         super.updateAttributeValue(ns, ln, val);
/* 263 */         AbstractSVGAnimatedLength rx = (AbstractSVGAnimatedLength)getRx();
/*     */         
/* 265 */         if (!rx.isSpecified()) {
/* 266 */           super.updateAttributeValue(ns, "rx", val);
/*     */         }
/*     */         return;
/*     */       } 
/*     */     } 
/* 271 */     super.updateAttributeValue(ns, ln, val);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMRectElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */