/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.awt.geom.AffineTransform;
/*     */ import java.util.List;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.ListNodeList;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.NodeList;
/*     */ import org.w3c.dom.css.CSSStyleDeclaration;
/*     */ import org.w3c.dom.css.DocumentCSS;
/*     */ import org.w3c.dom.css.ViewCSS;
/*     */ import org.w3c.dom.events.DocumentEvent;
/*     */ import org.w3c.dom.events.Event;
/*     */ import org.w3c.dom.stylesheets.DocumentStyle;
/*     */ import org.w3c.dom.stylesheets.StyleSheetList;
/*     */ import org.w3c.dom.svg.SVGAngle;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGAnimatedPreserveAspectRatio;
/*     */ import org.w3c.dom.svg.SVGAnimatedRect;
/*     */ import org.w3c.dom.svg.SVGElement;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGNumber;
/*     */ import org.w3c.dom.svg.SVGPoint;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ import org.w3c.dom.svg.SVGSVGElement;
/*     */ import org.w3c.dom.svg.SVGStringList;
/*     */ import org.w3c.dom.svg.SVGTransform;
/*     */ import org.w3c.dom.svg.SVGViewSpec;
/*     */ import org.w3c.dom.views.AbstractView;
/*     */ import org.w3c.dom.views.DocumentView;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMSVGElement
/*     */   extends SVGStylableElement
/*     */   implements SVGSVGElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final AttributeInitializer attributeInitializer;
/*     */   protected SVGOMAnimatedLength x;
/*     */   protected SVGOMAnimatedLength y;
/*     */   protected SVGOMAnimatedLength width;
/*     */   protected SVGOMAnimatedLength height;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   protected SVGOMAnimatedPreserveAspectRatio preserveAspectRatio;
/*     */   protected SVGOMAnimatedRect viewBox;
/*     */   
/*     */   static  {
/*  76 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  78 */     t.put(null, "x", new TraitInformation(true, 3, (short)1));
/*     */     
/*  80 */     t.put(null, "y", new TraitInformation(true, 3, (short)2));
/*     */     
/*  82 */     t.put(null, "width", new TraitInformation(true, 3, (short)1));
/*     */     
/*  84 */     t.put(null, "height", new TraitInformation(true, 3, (short)2));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  94 */     t.put(null, "preserveAspectRatio", new TraitInformation(true, 32));
/*     */     
/*  96 */     t.put(null, "viewBox", new TraitInformation(true, 50));
/*     */     
/*  98 */     t.put(null, "externalResourcesRequired", new TraitInformation(true, 49));
/*     */     
/* 100 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 108 */     attributeInitializer = new AttributeInitializer(7);
/* 109 */     attributeInitializer.addAttribute("http://www.w3.org/2000/xmlns/", null, "xmlns", "http://www.w3.org/2000/svg");
/*     */ 
/*     */ 
/*     */     
/* 113 */     attributeInitializer.addAttribute("http://www.w3.org/2000/xmlns/", "xmlns", "xlink", "http://www.w3.org/1999/xlink");
/*     */ 
/*     */ 
/*     */     
/* 117 */     attributeInitializer.addAttribute(null, null, "preserveAspectRatio", "xMidYMid meet");
/*     */ 
/*     */ 
/*     */     
/* 121 */     attributeInitializer.addAttribute(null, null, "zoomAndPan", "magnify");
/*     */ 
/*     */ 
/*     */     
/* 125 */     attributeInitializer.addAttribute(null, null, "version", "1.0");
/*     */ 
/*     */ 
/*     */     
/* 129 */     attributeInitializer.addAttribute(null, null, "contentScriptType", "text/ecmascript");
/*     */ 
/*     */ 
/*     */     
/* 133 */     attributeInitializer.addAttribute(null, null, "contentStyleType", "text/css");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMSVGElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMSVGElement(String prefix, AbstractDocument owner) {
/* 186 */     super(prefix, owner);
/* 187 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 194 */     super.initializeAllLiveAttributes();
/* 195 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 202 */     this.x = createLiveAnimatedLength(null, "x", "0", (short)2, false);
/*     */ 
/*     */     
/* 205 */     this.y = createLiveAnimatedLength(null, "y", "0", (short)1, false);
/*     */ 
/*     */     
/* 208 */     this.width = createLiveAnimatedLength(null, "width", "100%", (short)2, true);
/*     */ 
/*     */ 
/*     */     
/* 212 */     this.height = createLiveAnimatedLength(null, "height", "100%", (short)1, true);
/*     */ 
/*     */ 
/*     */     
/* 216 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */ 
/*     */     
/* 219 */     this.preserveAspectRatio = createLiveAnimatedPreserveAspectRatio();
/* 220 */     this.viewBox = createLiveAnimatedRect(null, "viewBox", null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 227 */   public String getLocalName() { return "svg"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 234 */   public SVGAnimatedLength getX() { return this.x; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 241 */   public SVGAnimatedLength getY() { return this.y; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 248 */   public SVGAnimatedLength getWidth() { return this.width; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 255 */   public SVGAnimatedLength getHeight() { return this.height; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 262 */   public String getContentScriptType() { return getAttributeNS(null, "contentScriptType"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 269 */   public void setContentScriptType(String type) { setAttributeNS(null, "contentScriptType", type); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 276 */   public String getContentStyleType() { return getAttributeNS(null, "contentStyleType"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 283 */   public void setContentStyleType(String type) { setAttributeNS(null, "contentStyleType", type); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGRect getViewport() {
/* 290 */     SVGContext ctx = getSVGContext();
/* 291 */     return new SVGOMRect(0.0F, 0.0F, ctx.getViewportWidth(), ctx.getViewportHeight());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 299 */   public float getPixelUnitToMillimeterX() { return getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 306 */   public float getPixelUnitToMillimeterY() { return getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 314 */   public float getScreenPixelToMillimeterX() { return getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 322 */   public float getScreenPixelToMillimeterY() { return getSVGContext().getPixelUnitToMillimeter(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 329 */   public boolean getUseCurrentView() { throw new UnsupportedOperationException("SVGSVGElement.getUseCurrentView is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 337 */   public void setUseCurrentView(boolean useCurrentView) throws DOMException { throw new UnsupportedOperationException("SVGSVGElement.setUseCurrentView is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 345 */   public SVGViewSpec getCurrentView() { throw new UnsupportedOperationException("SVGSVGElement.getCurrentView is not implemented"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getCurrentScale() {
/* 353 */     AffineTransform scrnTrans = getSVGContext().getScreenTransform();
/* 354 */     if (scrnTrans != null) {
/* 355 */       return (float)Math.sqrt(scrnTrans.getDeterminant());
/*     */     }
/* 357 */     return 1.0F;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setCurrentScale(float currentScale) throws DOMException {
/* 364 */     SVGContext context = getSVGContext();
/* 365 */     AffineTransform scrnTrans = context.getScreenTransform();
/* 366 */     float scale = 1.0F;
/* 367 */     if (scrnTrans != null) {
/* 368 */       scale = (float)Math.sqrt(scrnTrans.getDeterminant());
/*     */     }
/* 370 */     float delta = currentScale / scale;
/*     */ 
/*     */     
/* 373 */     scrnTrans = new AffineTransform(scrnTrans.getScaleX() * delta, scrnTrans.getShearY() * delta, scrnTrans.getShearX() * delta, scrnTrans.getScaleY() * delta, scrnTrans.getTranslateX(), scrnTrans.getTranslateY());
/*     */ 
/*     */ 
/*     */     
/* 377 */     context.setScreenTransform(scrnTrans);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGPoint getCurrentTranslate() {
/* 384 */     return new SVGPoint(this) {
/*     */         protected AffineTransform getScreenTransform() {
/* 386 */           SVGContext context = this.this$0.getSVGContext();
/* 387 */           return context.getScreenTransform();
/*     */         } private final SVGOMSVGElement this$0;
/*     */         public float getX() {
/* 390 */           AffineTransform scrnTrans = getScreenTransform();
/* 391 */           return (float)scrnTrans.getTranslateX();
/*     */         }
/*     */         public float getY() {
/* 394 */           AffineTransform scrnTrans = getScreenTransform();
/* 395 */           return (float)scrnTrans.getTranslateY();
/*     */         }
/*     */         public void setX(float newX) throws DOMException {
/* 398 */           SVGContext context = this.this$0.getSVGContext();
/* 399 */           AffineTransform scrnTrans = context.getScreenTransform();
/* 400 */           scrnTrans = new AffineTransform(scrnTrans.getScaleX(), scrnTrans.getShearY(), scrnTrans.getShearX(), scrnTrans.getScaleY(), newX, scrnTrans.getTranslateY());
/*     */ 
/*     */ 
/*     */           
/* 404 */           context.setScreenTransform(scrnTrans);
/*     */         }
/*     */         public void setY(float newY) throws DOMException {
/* 407 */           SVGContext context = this.this$0.getSVGContext();
/* 408 */           AffineTransform scrnTrans = context.getScreenTransform();
/* 409 */           scrnTrans = new AffineTransform(scrnTrans.getScaleX(), scrnTrans.getShearY(), scrnTrans.getShearX(), scrnTrans.getScaleY(), scrnTrans.getTranslateX(), newY);
/*     */ 
/*     */ 
/*     */           
/* 413 */           context.setScreenTransform(scrnTrans);
/*     */         }
/*     */         public SVGPoint matrixTransform(SVGMatrix mat) {
/* 416 */           AffineTransform scrnTrans = getScreenTransform();
/* 417 */           float x = (float)scrnTrans.getTranslateX();
/* 418 */           float y = (float)scrnTrans.getTranslateY();
/* 419 */           float newX = mat.getA() * x + mat.getC() * y + mat.getE();
/* 420 */           float newY = mat.getB() * x + mat.getD() * y + mat.getF();
/* 421 */           return new SVGOMPoint(newX, newY);
/*     */         }
/*     */       };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int suspendRedraw(int max_wait_milliseconds) {
/* 430 */     if (max_wait_milliseconds > 60000) {
/* 431 */       max_wait_milliseconds = 60000;
/* 432 */     } else if (max_wait_milliseconds < 0) {
/* 433 */       max_wait_milliseconds = 0;
/*     */     } 
/* 435 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 436 */     return ctx.suspendRedraw(max_wait_milliseconds);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void unsuspendRedraw(int suspend_handle_id) throws DOMException {
/* 443 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 444 */     if (!ctx.unsuspendRedraw(suspend_handle_id)) {
/* 445 */       throw createDOMException((short)8, "invalid.suspend.handle", new Object[] { new Integer(suspend_handle_id) });
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void unsuspendRedrawAll() {
/* 455 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 456 */     ctx.unsuspendRedrawAll();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void forceRedraw() {
/* 463 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 464 */     ctx.forceRedraw();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void pauseAnimations() {
/* 471 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 472 */     ctx.pauseAnimations();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void unpauseAnimations() {
/* 479 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 480 */     ctx.unpauseAnimations();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean animationsPaused() {
/* 487 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 488 */     return ctx.animationsPaused();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public float getCurrentTime() {
/* 495 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 496 */     return ctx.getCurrentTime();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setCurrentTime(float seconds) throws DOMException {
/* 503 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 504 */     ctx.setCurrentTime(seconds);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public NodeList getIntersectionList(SVGRect rect, SVGElement referenceElement) {
/* 513 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 514 */     List list = ctx.getIntersectionList(rect, referenceElement);
/* 515 */     return new ListNodeList(list);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public NodeList getEnclosureList(SVGRect rect, SVGElement referenceElement) {
/* 524 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 525 */     List list = ctx.getEnclosureList(rect, referenceElement);
/* 526 */     return new ListNodeList(list);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean checkIntersection(SVGElement element, SVGRect rect) {
/* 534 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 535 */     return ctx.checkIntersection(element, rect);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean checkEnclosure(SVGElement element, SVGRect rect) {
/* 543 */     SVGSVGContext ctx = (SVGSVGContext)getSVGContext();
/* 544 */     return ctx.checkEnclosure(element, rect);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 551 */   public void deselectAll() { ((SVGSVGContext)getSVGContext()).deselectAll(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGNumber createSVGNumber() {
/* 558 */     return new SVGNumber(this) { protected float value;
/*     */         private final SVGOMSVGElement this$0;
/*     */         
/* 561 */         public float getValue() { return this.value; }
/*     */ 
/*     */         
/* 564 */         public void setValue(float f) throws DOMException { this.value = f; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 573 */   public SVGLength createSVGLength() { return new SVGOMLength(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 580 */   public SVGAngle createSVGAngle() { return new SVGOMAngle(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 587 */   public SVGPoint createSVGPoint() { return new SVGOMPoint(0.0F, 0.0F); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGMatrix createSVGMatrix() {
/* 594 */     return new AbstractSVGMatrix(this) { protected AffineTransform at;
/*     */         private final SVGOMSVGElement this$0;
/*     */         
/* 597 */         protected AffineTransform getAffineTransform() { return this.at; } }
/*     */       ;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 606 */   public SVGRect createSVGRect() { return new SVGOMRect(0.0F, 0.0F, 0.0F, 0.0F); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransform createSVGTransform() {
/* 613 */     SVGOMTransform ret = new SVGOMTransform();
/* 614 */     ret.setType((short)1);
/* 615 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransform createSVGTransformFromMatrix(SVGMatrix matrix) {
/* 623 */     SVGOMTransform tr = new SVGOMTransform();
/* 624 */     tr.setMatrix(matrix);
/* 625 */     return tr;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 632 */   public Element getElementById(String elementId) { return this.ownerDocument.getChildElementById(this, elementId); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 642 */   public SVGElement getNearestViewportElement() { return SVGLocatableSupport.getNearestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 650 */   public SVGElement getFarthestViewportElement() { return SVGLocatableSupport.getFarthestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 658 */   public SVGRect getBBox() { return SVGLocatableSupport.getBBox(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 666 */   public SVGMatrix getCTM() { return SVGLocatableSupport.getCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 674 */   public SVGMatrix getScreenCTM() { return SVGLocatableSupport.getScreenCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 683 */   public SVGMatrix getTransformToElement(SVGElement element) throws SVGException { return SVGLocatableSupport.getTransformToElement(this, element); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 693 */   public DocumentView getDocument() { return (DocumentView)getOwnerDocument(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSStyleDeclaration getComputedStyle(Element elt, String pseudoElt) {
/* 702 */     AbstractView av = ((DocumentView)getOwnerDocument()).getDefaultView();
/* 703 */     return ((ViewCSS)av).getComputedStyle(elt, pseudoElt);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 713 */   public Event createEvent(String eventType) throws DOMException { return ((DocumentEvent)getOwnerDocument()).createEvent(eventType); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean canDispatch(String namespaceURI, String type) throws DOMException {
/* 722 */     AbstractDocument doc = (AbstractDocument)getOwnerDocument();
/* 723 */     return doc.canDispatch(namespaceURI, type);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 733 */   public StyleSheetList getStyleSheets() { return ((DocumentStyle)getOwnerDocument()).getStyleSheets(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 742 */   public CSSStyleDeclaration getOverrideStyle(Element elt, String pseudoElt) { return ((DocumentCSS)getOwnerDocument()).getOverrideStyle(elt, pseudoElt); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 752 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 759 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 766 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 773 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 783 */   public short getZoomAndPan() { return SVGZoomAndPanSupport.getZoomAndPan(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 791 */   public void setZoomAndPan(short val) { SVGZoomAndPanSupport.setZoomAndPan(this, val); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 801 */   public SVGAnimatedRect getViewBox() { return this.viewBox; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 809 */   public SVGAnimatedPreserveAspectRatio getPreserveAspectRatio() { return this.preserveAspectRatio; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 819 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 829 */   public SVGStringList getRequiredFeatures() { return SVGTestsSupport.getRequiredFeatures(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 837 */   public SVGStringList getRequiredExtensions() { return SVGTestsSupport.getRequiredExtensions(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 845 */   public SVGStringList getSystemLanguage() { return SVGTestsSupport.getSystemLanguage(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 853 */   public boolean hasExtension(String extension) { return SVGTestsSupport.hasExtension(this, extension); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 861 */   protected AttributeInitializer getAttributeInitializer() { return attributeInitializer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 868 */   protected Node newNode() { return new SVGOMSVGElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 875 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMSVGElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */