/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.util.XMLSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGAnimatedBoolean;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ import org.w3c.dom.svg.SVGPoint;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ import org.w3c.dom.svg.SVGStringList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class SVGOMTextContentElement
/*     */   extends SVGStylableElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final String[] LENGTH_ADJUST_VALUES;
/*     */   protected SVGOMAnimatedBoolean externalResourcesRequired;
/*     */   protected AbstractSVGAnimatedLength textLength;
/*     */   protected SVGOMAnimatedEnumeration lengthAdjust;
/*     */   
/*     */   static  {
/*  49 */     t = new DoublyIndexedTable(SVGStylableElement.xmlTraitInformation);
/*     */     
/*  51 */     t.put(null, "textLength", new TraitInformation(true, 3, (short)3));
/*     */     
/*  53 */     t.put(null, "lengthAdjust", new TraitInformation(true, 15));
/*     */     
/*  55 */     t.put(null, "externalResourcesRequired", new TraitInformation(true, 49));
/*     */     
/*  57 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  63 */     LENGTH_ADJUST_VALUES = new String[] { "", "spacing", "spacingAndGlyphs" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMTextContentElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMTextContentElement(String prefix, AbstractDocument owner) {
/*  96 */     super(prefix, owner);
/*  97 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 104 */     super.initializeAllLiveAttributes();
/* 105 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 112 */     this.externalResourcesRequired = createLiveAnimatedBoolean(null, "externalResourcesRequired", false);
/*     */ 
/*     */     
/* 115 */     this.lengthAdjust = createLiveAnimatedEnumeration(null, "lengthAdjust", LENGTH_ADJUST_VALUES, (short)1);
/*     */ 
/*     */ 
/*     */     
/* 119 */     this.textLength = new AbstractSVGAnimatedLength(this, this, null, "textLength", (short)2, true)
/*     */       {
/*     */         boolean usedDefault;
/*     */         private final SVGOMTextContentElement this$0;
/*     */         
/*     */         protected String getDefaultValue() {
/* 125 */           this.usedDefault = true;
/* 126 */           return String.valueOf(this.this$0.getComputedTextLength());
/*     */         }
/*     */         
/*     */         public SVGLength getBaseVal() {
/* 130 */           if (this.baseVal == null) {
/* 131 */             this.baseVal = new SVGOMTextContentElement.null.SVGTextLength(this, this.direction);
/*     */           }
/* 133 */           return this.baseVal;
/*     */         }
/*     */         
/*     */         class SVGTextLength
/*     */           extends BaseSVGLength {
/*     */           private final SVGOMTextContentElement.null this$1;
/*     */           
/*     */           protected void revalidate() {
/* 141 */             this.this$1.usedDefault = false;
/*     */             
/* 143 */             super.revalidate();
/*     */ 
/*     */ 
/*     */             
/* 147 */             if (this.this$1.usedDefault) this.valid = false;
/*     */           
/*     */           }
/*     */         }
/*     */       };
/* 152 */     this.liveAttributeValues.put(null, "textLength", this.textLength);
/* 153 */     this.textLength.addAnimatedAttributeListener(((SVGOMDocument)this.ownerDocument).getAnimatedAttributeListener());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 162 */   public SVGAnimatedLength getTextLength() { return this.textLength; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 170 */   public SVGAnimatedEnumeration getLengthAdjust() { return this.lengthAdjust; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 178 */   public int getNumberOfChars() { return SVGTextContentSupport.getNumberOfChars(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 186 */   public float getComputedTextLength() { return SVGTextContentSupport.getComputedTextLength(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 195 */   public float getSubStringLength(int charnum, int nchars) throws DOMException { return SVGTextContentSupport.getSubStringLength(this, charnum, nchars); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 203 */   public SVGPoint getStartPositionOfChar(int charnum) throws DOMException { return SVGTextContentSupport.getStartPositionOfChar(this, charnum); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 211 */   public SVGPoint getEndPositionOfChar(int charnum) throws DOMException { return SVGTextContentSupport.getEndPositionOfChar(this, charnum); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 219 */   public SVGRect getExtentOfChar(int charnum) throws DOMException { return SVGTextContentSupport.getExtentOfChar(this, charnum); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 227 */   public float getRotationOfChar(int charnum) throws DOMException { return SVGTextContentSupport.getRotationOfChar(this, charnum); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 235 */   public int getCharNumAtPosition(SVGPoint point) { return SVGTextContentSupport.getCharNumAtPosition(this, point.getX(), point.getY()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 245 */   public void selectSubString(int charnum, int nchars) throws DOMException { SVGTextContentSupport.selectSubString(this, charnum, nchars); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 255 */   public SVGAnimatedBoolean getExternalResourcesRequired() { return this.externalResourcesRequired; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 264 */   public String getXMLlang() { return XMLSupport.getXMLLang(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 271 */   public void setXMLlang(String lang) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:lang", lang); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 278 */   public String getXMLspace() { return XMLSupport.getXMLSpace(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 285 */   public void setXMLspace(String space) { setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:space", space); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 295 */   public SVGStringList getRequiredFeatures() { return SVGTestsSupport.getRequiredFeatures(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 303 */   public SVGStringList getRequiredExtensions() { return SVGTestsSupport.getRequiredExtensions(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 311 */   public SVGStringList getSystemLanguage() { return SVGTestsSupport.getSystemLanguage(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 319 */   public boolean hasExtension(String extension) { return SVGTestsSupport.hasExtension(this, extension); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 326 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMTextContentElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */