/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.awt.geom.AffineTransform;
/*     */ import org.apache.batik.anim.values.AnimatableMotionPointValue;
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedTransformList;
/*     */ import org.w3c.dom.svg.SVGElement;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGRect;
/*     */ import org.w3c.dom.svg.SVGTextElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMTextElement
/*     */   extends SVGOMTextPositioningElement
/*     */   implements SVGTextElement, SVGMotionAnimatableElement
/*     */ {
/*     */   protected static final String X_DEFAULT_VALUE = "0";
/*     */   protected static final String Y_DEFAULT_VALUE = "0";
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected SVGOMAnimatedTransformList transform;
/*     */   protected AffineTransform motionTransform;
/*     */   
/*     */   static  {
/*  57 */     t = new DoublyIndexedTable(SVGOMTextPositioningElement.xmlTraitInformation);
/*     */     
/*  59 */     t.put(null, "transform", new TraitInformation(true, 9));
/*     */     
/*  61 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMTextElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMTextElement(String prefix, AbstractDocument owner) {
/*  86 */     super(prefix, owner);
/*  87 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/*  94 */     super.initializeAllLiveAttributes();
/*  95 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 102 */   private void initializeLiveAttributes() { this.transform = createLiveAnimatedTransformList(null, "transform", ""); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 110 */   public String getLocalName() { return "text"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 120 */   public SVGElement getNearestViewportElement() { return SVGLocatableSupport.getNearestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 128 */   public SVGElement getFarthestViewportElement() { return SVGLocatableSupport.getFarthestViewportElement(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 135 */   public SVGRect getBBox() { return SVGLocatableSupport.getBBox(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 142 */   public SVGMatrix getCTM() { return SVGLocatableSupport.getCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 150 */   public SVGMatrix getScreenCTM() { return SVGLocatableSupport.getScreenCTM(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 159 */   public SVGMatrix getTransformToElement(SVGElement element) throws SVGException { return SVGLocatableSupport.getTransformToElement(this, element); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 169 */   public SVGAnimatedTransformList getTransform() { return this.transform; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 176 */   protected String getDefaultXValue() { return "0"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 183 */   protected String getDefaultYValue() { return "0"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 190 */   protected Node newNode() { return new SVGOMTextElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 197 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 207 */   public AffineTransform getMotionTransform() { return this.motionTransform; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updateOtherValue(String type, AnimatableValue val) {
/* 216 */     if (type.equals("motion")) {
/* 217 */       if (this.motionTransform == null) {
/* 218 */         this.motionTransform = new AffineTransform();
/*     */       }
/* 220 */       if (val == null) {
/* 221 */         this.motionTransform.setToIdentity();
/*     */       } else {
/* 223 */         AnimatableMotionPointValue p = (AnimatableMotionPointValue)val;
/* 224 */         this.motionTransform.setToTranslation(p.getX(), p.getY());
/* 225 */         this.motionTransform.rotate(p.getAngle());
/*     */       } 
/* 227 */       SVGOMDocument d = (SVGOMDocument)this.ownerDocument;
/* 228 */       d.getAnimatedAttributeListener().otherAnimationChanged(this, type);
/*     */     } else {
/* 230 */       super.updateOtherValue(type, val);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMTextElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */