/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.svg.SVGAnimatedEnumeration;
/*     */ import org.w3c.dom.svg.SVGAnimatedLength;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ import org.w3c.dom.svg.SVGTextPathElement;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGOMTextPathElement
/*     */   extends SVGOMTextContentElement
/*     */   implements SVGTextPathElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected static final AttributeInitializer attributeInitializer;
/*     */   protected static final String[] METHOD_VALUES;
/*     */   protected static final String[] SPACING_VALUES;
/*     */   protected SVGOMAnimatedEnumeration method;
/*     */   protected SVGOMAnimatedEnumeration spacing;
/*     */   protected SVGOMAnimatedLength startOffset;
/*     */   protected SVGOMAnimatedString href;
/*     */   
/*     */   static  {
/*  48 */     t = new DoublyIndexedTable(SVGOMTextContentElement.xmlTraitInformation);
/*     */     
/*  50 */     t.put(null, "method", new TraitInformation(true, 15));
/*     */     
/*  52 */     t.put(null, "spacing", new TraitInformation(true, 15));
/*     */     
/*  54 */     t.put(null, "startOffset", new TraitInformation(true, 3));
/*     */     
/*  56 */     t.put("http://www.w3.org/1999/xlink", "href", new TraitInformation(true, 10));
/*     */     
/*  58 */     xmlTraitInformation = t;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  66 */     attributeInitializer = new AttributeInitializer(4);
/*  67 */     attributeInitializer.addAttribute("http://www.w3.org/2000/xmlns/", null, "xmlns:xlink", "http://www.w3.org/1999/xlink");
/*     */ 
/*     */     
/*  70 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "type", "simple");
/*     */     
/*  72 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "show", "other");
/*     */     
/*  74 */     attributeInitializer.addAttribute("http://www.w3.org/1999/xlink", "xlink", "actuate", "onLoad");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  81 */     METHOD_VALUES = new String[] { "", "align", "stretch" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  90 */     SPACING_VALUES = new String[] { "", "auto", "exact" };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGOMTextPathElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGOMTextPathElement(String prefix, AbstractDocument owner) {
/* 128 */     super(prefix, owner);
/* 129 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 136 */     super.initializeAllLiveAttributes();
/* 137 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initializeLiveAttributes() {
/* 144 */     this.method = createLiveAnimatedEnumeration(null, "method", METHOD_VALUES, (short)1);
/*     */ 
/*     */     
/* 147 */     this.spacing = createLiveAnimatedEnumeration(null, "spacing", SPACING_VALUES, (short)2);
/*     */ 
/*     */     
/* 150 */     this.startOffset = createLiveAnimatedLength(null, "startOffset", "0", (short)0, true);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 155 */     this.href = createLiveAnimatedString("http://www.w3.org/1999/xlink", "href");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 163 */   public String getLocalName() { return "textPath"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 170 */   public SVGAnimatedLength getStartOffset() { return this.startOffset; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 177 */   public SVGAnimatedEnumeration getMethod() { return this.method; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 184 */   public SVGAnimatedEnumeration getSpacing() { return this.spacing; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 194 */   public SVGAnimatedString getHref() { return this.href; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 202 */   protected AttributeInitializer getAttributeInitializer() { return attributeInitializer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 209 */   protected Node newNode() { return new SVGOMTextPathElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 216 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGOMTextPathElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */