/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.anim.values.AnimatableValue;
/*     */ import org.apache.batik.css.dom.CSSOMSVGColor;
/*     */ import org.apache.batik.css.dom.CSSOMSVGPaint;
/*     */ import org.apache.batik.css.dom.CSSOMStoredStyleDeclaration;
/*     */ import org.apache.batik.css.dom.CSSOMValue;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.CSSStylableElement;
/*     */ import org.apache.batik.css.engine.StyleDeclaration;
/*     */ import org.apache.batik.css.engine.StyleDeclarationProvider;
/*     */ import org.apache.batik.css.engine.StyleMap;
/*     */ import org.apache.batik.css.engine.value.Value;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.anim.AnimationTargetListener;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.apache.batik.util.ParsedURL;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.css.CSSStyleDeclaration;
/*     */ import org.w3c.dom.css.CSSValue;
/*     */ import org.w3c.dom.svg.SVGAnimatedString;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class SVGStylableElement
/*     */   extends SVGOMElement
/*     */   implements CSSStylableElement
/*     */ {
/*     */   protected static DoublyIndexedTable xmlTraitInformation;
/*     */   protected StyleMap computedStyleMap;
/*     */   protected OverrideStyleDeclaration overrideStyleDeclaration;
/*     */   protected SVGOMAnimatedString className;
/*     */   protected StyleDeclaration style;
/*     */   
/*     */   static  {
/*  63 */     t = new DoublyIndexedTable(SVGOMElement.xmlTraitInformation);
/*     */     
/*  65 */     t.put(null, "class", new TraitInformation(true, 16));
/*     */     
/*  67 */     xmlTraitInformation = t;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGStylableElement() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGStylableElement(String prefix, AbstractDocument owner) {
/* 102 */     super(prefix, owner);
/* 103 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeAllLiveAttributes() {
/* 110 */     super.initializeAllLiveAttributes();
/* 111 */     initializeLiveAttributes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 118 */   private void initializeLiveAttributes() { this.className = createLiveAnimatedString(null, "class"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSStyleDeclaration getOverrideStyle() {
/* 125 */     if (this.overrideStyleDeclaration == null) {
/* 126 */       CSSEngine eng = ((SVGOMDocument)getOwnerDocument()).getCSSEngine();
/* 127 */       this.overrideStyleDeclaration = new OverrideStyleDeclaration(this, eng);
/*     */     } 
/* 129 */     return this.overrideStyleDeclaration;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 138 */   public StyleMap getComputedStyleMap(String pseudoElement) { return this.computedStyleMap; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 145 */   public void setComputedStyleMap(String pseudoElement, StyleMap sm) { this.computedStyleMap = sm; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 152 */   public String getXMLId() { return getAttributeNS(null, "id"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 159 */   public String getCSSClass() { return getAttributeNS(null, "class"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ParsedURL getCSSBase() {
/* 168 */     if (getXblBoundElement() != null) {
/* 169 */       return null;
/*     */     }
/* 171 */     String bu = getBaseURI();
/* 172 */     return (bu == null) ? null : new ParsedURL(bu);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isPseudoInstanceOf(String pseudoClass) {
/* 180 */     if (pseudoClass.equals("first-child")) {
/* 181 */       Node n = getPreviousSibling();
/* 182 */       while (n != null && n.getNodeType() != 1) {
/* 183 */         n = n.getPreviousSibling();
/*     */       }
/* 185 */       return (n == null);
/*     */     } 
/* 187 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 196 */   public StyleDeclarationProvider getOverrideStyleDeclarationProvider() { return (StyleDeclarationProvider)getOverrideStyle(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void updatePropertyValue(String pn, AnimatableValue val) {
/* 205 */     CSSStyleDeclaration over = getOverrideStyle();
/* 206 */     if (val == null) {
/* 207 */       over.removeProperty(pn);
/*     */     } else {
/* 209 */       over.setProperty(pn, val.getCssText(), "");
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean useLinearRGBColorInterpolation() {
/* 218 */     CSSEngine eng = ((SVGOMDocument)getOwnerDocument()).getCSSEngine();
/* 219 */     Value v = eng.getComputedStyle(this, null, 6);
/*     */     
/* 221 */     return (v.getStringValue().charAt(0) == 'l');
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addTargetListener(String ns, String an, boolean isCSS, AnimationTargetListener l) {
/* 229 */     if (isCSS && this.svgContext != null) {
/* 230 */       ((SVGAnimationTargetContext)this.svgContext).addTargetListener(an, l);
/*     */     } else {
/* 232 */       super.addTargetListener(ns, an, isCSS, l);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeTargetListener(String ns, String an, boolean isCSS, AnimationTargetListener l) {
/* 241 */     if (isCSS) {
/* 242 */       ((SVGAnimationTargetContext)this.svgContext).removeTargetListener(an, l);
/*     */     } else {
/* 244 */       super.removeTargetListener(ns, an, isCSS, l);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSStyleDeclaration getStyle() {
/* 254 */     if (this.style == null) {
/* 255 */       CSSEngine eng = ((SVGOMDocument)getOwnerDocument()).getCSSEngine();
/* 256 */       this.style = new StyleDeclaration(this, eng);
/* 257 */       putLiveAttributeValue(null, "style", this.style);
/*     */     } 
/* 259 */     return this.style;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSValue getPresentationAttribute(String name) {
/* 267 */     PresentationAttributeValue presentationAttributeValue = (CSSValue)getLiveAttributeValue(null, name);
/* 268 */     if (presentationAttributeValue != null) {
/* 269 */       return presentationAttributeValue;
/*     */     }
/* 271 */     CSSEngine eng = ((SVGOMDocument)getOwnerDocument()).getCSSEngine();
/* 272 */     int idx = eng.getPropertyIndex(name);
/* 273 */     if (idx == -1) {
/* 274 */       return null;
/*     */     }
/* 276 */     if (idx > 59) {
/* 277 */       if (eng.getValueManagers()[idx] instanceof org.apache.batik.css.engine.value.svg.SVGPaintManager) {
/* 278 */         PresentationAttributePaintValue presentationAttributePaintValue = new PresentationAttributePaintValue(this, eng, name);
/*     */       }
/* 280 */       if (eng.getValueManagers()[idx] instanceof org.apache.batik.css.engine.value.svg.SVGColorManager)
/* 281 */         PresentationAttributeColorValue presentationAttributeColorValue = new PresentationAttributeColorValue(this, eng, name); 
/*     */     } else {
/*     */       PresentationAttributeColorValue presentationAttributeColorValue; PresentationAttributePaintValue presentationAttributePaintValue;
/* 284 */       switch (idx) {
/*     */         case 15:
/*     */         case 45:
/* 287 */           presentationAttributePaintValue = new PresentationAttributePaintValue(this, eng, name);
/*     */           break;
/*     */         
/*     */         case 19:
/*     */         case 33:
/*     */         case 43:
/* 293 */           presentationAttributeColorValue = new PresentationAttributeColorValue(this, eng, name);
/*     */           break;
/*     */         
/*     */         default:
/* 297 */           presentationAttributeValue = new PresentationAttributeValue(this, eng, name); break;
/*     */       } 
/*     */     } 
/* 300 */     putLiveAttributeValue(null, name, (LiveAttributeValue)presentationAttributeValue);
/* 301 */     if (getAttributeNS(null, name).length() == 0) {
/* 302 */       return null;
/*     */     }
/* 304 */     return presentationAttributeValue;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 312 */   public SVGAnimatedString getClassName() { return this.className; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 319 */   protected DoublyIndexedTable getTraitInformationTable() { return xmlTraitInformation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class PresentationAttributeValue
/*     */     extends CSSOMValue
/*     */     implements LiveAttributeValue, CSSOMValue.ValueProvider
/*     */   {
/*     */     protected CSSEngine cssEngine;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String property;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Value value;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean mutate;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGStylableElement this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public PresentationAttributeValue(SVGStylableElement this$0, CSSEngine eng, String prop) {
/* 354 */       super(null); this.this$0 = this$0;
/* 355 */       this.valueProvider = this;
/* 356 */       setModificationHandler(new SVGStylableElement$1(this));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 369 */       this.cssEngine = eng;
/* 370 */       this.property = prop;
/*     */       
/* 372 */       Attr attr = this$0.getAttributeNodeNS(null, prop);
/* 373 */       if (attr != null) {
/* 374 */         this.value = this.cssEngine.parsePropertyValue(this$0, prop, attr.getValue());
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Value getValue() {
/* 385 */       if (this.value == null) {
/* 386 */         throw new DOMException((short)11, "");
/*     */       }
/* 388 */       return this.value;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrAdded(Attr node, String newv) {
/* 397 */       if (!this.mutate) {
/* 398 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrModified(Attr node, String oldv, String newv) {
/* 407 */       if (!this.mutate) {
/* 408 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrRemoved(Attr node, String oldv) {
/* 417 */       if (!this.mutate) {
/* 418 */         this.value = null;
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class PresentationAttributeColorValue
/*     */     extends CSSOMSVGColor
/*     */     implements LiveAttributeValue, CSSOMSVGColor.ValueProvider
/*     */   {
/*     */     protected CSSEngine cssEngine;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String property;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Value value;
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean mutate;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGStylableElement this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public PresentationAttributeColorValue(SVGStylableElement this$0, CSSEngine eng, String prop) {
/* 455 */       super(null); this.this$0 = this$0;
/* 456 */       this.valueProvider = this;
/* 457 */       setModificationHandler(new SVGStylableElement$2(this));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 470 */       this.cssEngine = eng;
/* 471 */       this.property = prop;
/*     */       
/* 473 */       Attr attr = this$0.getAttributeNodeNS(null, prop);
/* 474 */       if (attr != null) {
/* 475 */         this.value = this.cssEngine.parsePropertyValue(this$0, prop, attr.getValue());
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Value getValue() {
/* 486 */       if (this.value == null) {
/* 487 */         throw new DOMException((short)11, "");
/*     */       }
/* 489 */       return this.value;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrAdded(Attr node, String newv) {
/* 498 */       if (!this.mutate) {
/* 499 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrModified(Attr node, String oldv, String newv) {
/* 508 */       if (!this.mutate) {
/* 509 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrRemoved(Attr node, String oldv) {
/* 518 */       if (!this.mutate) {
/* 519 */         this.value = null;
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class PresentationAttributePaintValue
/*     */     extends CSSOMSVGPaint
/*     */     implements LiveAttributeValue, CSSOMSVGColor.ValueProvider
/*     */   {
/*     */     protected CSSEngine cssEngine;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String property;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Value value;
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean mutate;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGStylableElement this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public PresentationAttributePaintValue(SVGStylableElement this$0, CSSEngine eng, String prop) {
/* 556 */       super(null); this.this$0 = this$0;
/* 557 */       this.valueProvider = this;
/* 558 */       setModificationHandler(new SVGStylableElement$3(this));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 572 */       this.cssEngine = eng;
/* 573 */       this.property = prop;
/*     */       
/* 575 */       Attr attr = this$0.getAttributeNodeNS(null, prop);
/* 576 */       if (attr != null) {
/* 577 */         this.value = this.cssEngine.parsePropertyValue(this$0, prop, attr.getValue());
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Value getValue() {
/* 588 */       if (this.value == null) {
/* 589 */         throw new DOMException((short)11, "");
/*     */       }
/* 591 */       return this.value;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrAdded(Attr node, String newv) {
/* 600 */       if (!this.mutate) {
/* 601 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrModified(Attr node, String oldv, String newv) {
/* 610 */       if (!this.mutate) {
/* 611 */         this.value = this.cssEngine.parsePropertyValue(this.this$0, this.property, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrRemoved(Attr node, String oldv) {
/* 620 */       if (!this.mutate) {
/* 621 */         this.value = null;
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class StyleDeclaration
/*     */     extends CSSOMStoredStyleDeclaration
/*     */     implements LiveAttributeValue, CSSEngine.MainPropertyReceiver
/*     */   {
/*     */     protected boolean mutate;
/*     */ 
/*     */ 
/*     */     
/*     */     private final SVGStylableElement this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public StyleDeclaration(SVGStylableElement this$0, CSSEngine eng) {
/* 643 */       super(eng);
/*     */       this.this$0 = this$0;
/* 645 */       this.declaration = this.cssEngine.parseStyleDeclaration(this$0, this$0.getAttributeNS(null, "style"));
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrAdded(Attr node, String newv) {
/* 656 */       if (!this.mutate) {
/* 657 */         this.declaration = this.cssEngine.parseStyleDeclaration(this.this$0, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrModified(Attr node, String oldv, String newv) {
/* 666 */       if (!this.mutate) {
/* 667 */         this.declaration = this.cssEngine.parseStyleDeclaration(this.this$0, newv);
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void attrRemoved(Attr node, String oldv) {
/* 676 */       if (!this.mutate) {
/* 677 */         this.declaration = new StyleDeclaration();
/*     */       }
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void textChanged(String text) throws DOMException {
/* 688 */       this.declaration = this.cssEngine.parseStyleDeclaration(this.this$0, text);
/*     */       
/* 690 */       this.mutate = true;
/* 691 */       this.this$0.setAttributeNS(null, "style", text);
/* 692 */       this.mutate = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void propertyRemoved(String name) throws DOMException {
/* 699 */       int idx = this.cssEngine.getPropertyIndex(name);
/* 700 */       for (int i = 0; i < this.declaration.size(); i++) {
/* 701 */         if (idx == this.declaration.getIndex(i)) {
/* 702 */           this.declaration.remove(i);
/* 703 */           this.mutate = true;
/* 704 */           this.this$0.setAttributeNS(null, "style", this.declaration.toString(this.cssEngine));
/*     */           
/* 706 */           this.mutate = false;
/*     */           return;
/*     */         } 
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void propertyChanged(String name, String value, String prio) throws DOMException {
/* 717 */       boolean important = (prio != null && prio.length() > 0);
/* 718 */       this.cssEngine.setMainProperties(this.this$0, this, name, value, important);
/*     */       
/* 720 */       this.mutate = true;
/* 721 */       this.this$0.setAttributeNS(null, "style", this.declaration.toString(this.cssEngine));
/*     */       
/* 723 */       this.mutate = false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setMainProperty(String name, Value v, boolean important) {
/* 733 */       int idx = this.cssEngine.getPropertyIndex(name);
/* 734 */       if (idx == -1) {
/*     */         return;
/*     */       }
/*     */       int i;
/* 738 */       for (i = 0; i < this.declaration.size() && 
/* 739 */         idx != this.declaration.getIndex(i); i++);
/*     */ 
/*     */       
/* 742 */       if (i < this.declaration.size()) {
/* 743 */         this.declaration.put(i, v, idx, important);
/*     */       } else {
/* 745 */         this.declaration.append(v, idx, important);
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected class OverrideStyleDeclaration
/*     */     extends CSSOMStoredStyleDeclaration
/*     */   {
/*     */     private final SVGStylableElement this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     protected OverrideStyleDeclaration(SVGStylableElement this$0, CSSEngine eng) {
/* 760 */       super(eng); this.this$0 = this$0;
/* 761 */       this.declaration = new StyleDeclaration();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 770 */     public void textChanged(String text) throws DOMException { ((SVGOMDocument)this.this$0.ownerDocument).overrideStyleTextChanged(this.this$0, text); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 778 */     public void propertyRemoved(String name) throws DOMException { ((SVGOMDocument)this.this$0.ownerDocument).overrideStylePropertyRemoved(this.this$0, name); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 787 */     public void propertyChanged(String name, String value, String prio) throws DOMException { ((SVGOMDocument)this.this$0.ownerDocument).overrideStylePropertyChanged(this.this$0, name, value, prio); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\SVGStylableElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */