/*     */ package org.apache.batik.dom.svg12;
/*     */ 
/*     */ import java.net.URL;
/*     */ import org.apache.batik.css.engine.CSSContext;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.SVG12CSSEngine;
/*     */ import org.apache.batik.css.engine.value.ShorthandManager;
/*     */ import org.apache.batik.css.engine.value.ValueManager;
/*     */ import org.apache.batik.css.parser.ExtendedParser;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.AbstractNode;
/*     */ import org.apache.batik.dom.AbstractStylableDocument;
/*     */ import org.apache.batik.dom.ExtensibleDOMImplementation;
/*     */ import org.apache.batik.dom.GenericElement;
/*     */ import org.apache.batik.dom.events.DocumentEventSupport;
/*     */ import org.apache.batik.dom.events.EventSupport;
/*     */ import org.apache.batik.dom.svg.SVGDOMImplementation;
/*     */ import org.apache.batik.dom.svg.SVGOMDocument;
/*     */ import org.apache.batik.dom.util.DOMUtilities;
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.apache.batik.util.ParsedURL;
/*     */ import org.w3c.css.sac.InputSource;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.DocumentType;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.events.Event;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVG12DOMImplementation
/*     */   extends SVGDOMImplementation
/*     */ {
/*     */   public SVG12DOMImplementation() {
/*  65 */     this.factories = svg12Factories;
/*  66 */     registerFeature("CSS", "2.0");
/*  67 */     registerFeature("StyleSheets", "2.0");
/*  68 */     registerFeature("SVG", new String[] { "1.0", "1.1", "1.2" });
/*  69 */     registerFeature("SVGEvents", new String[] { "1.0", "1.1", "1.2" });
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public CSSEngine createCSSEngine(AbstractStylableDocument doc, CSSContext ctx, ExtendedParser ep, ValueManager[] vms, ShorthandManager[] sms) {
/*  77 */     ParsedURL durl = ((SVGOMDocument)doc).getParsedURL();
/*  78 */     SVG12CSSEngine sVG12CSSEngine = new SVG12CSSEngine(doc, durl, ep, vms, sms, ctx);
/*     */     
/*  80 */     URL url = getClass().getResource("resources/UserAgentStyleSheet.css");
/*  81 */     if (url != null) {
/*  82 */       ParsedURL purl = new ParsedURL(url);
/*  83 */       InputSource is = new InputSource(purl.toString());
/*  84 */       sVG12CSSEngine.setUserAgentStyleSheet(sVG12CSSEngine.parseStyleSheet(is, purl, "all"));
/*     */     } 
/*     */ 
/*     */     
/*  88 */     return sVG12CSSEngine;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String namespaceURI, String qualifiedName, DocumentType doctype) throws DOMException {
/*  99 */     SVGOMDocument result = new SVG12OMDocument(doctype, this);
/* 100 */     result.setIsSVG12(true);
/*     */     
/* 102 */     if (qualifiedName != null) {
/* 103 */       result.appendChild(result.createElementNS(namespaceURI, qualifiedName));
/*     */     }
/* 105 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element createElementNS(AbstractDocument document, String namespaceURI, String qualifiedName) {
/* 115 */     if (namespaceURI == null) {
/* 116 */       return new GenericElement(qualifiedName.intern(), document);
/*     */     }
/* 118 */     String name = DOMUtilities.getLocalName(qualifiedName);
/* 119 */     String prefix = DOMUtilities.getPrefix(qualifiedName);
/* 120 */     if ("http://www.w3.org/2000/svg".equals(namespaceURI)) {
/* 121 */       ExtensibleDOMImplementation.ElementFactory ef = (ExtensibleDOMImplementation.ElementFactory)this.factories.get(name);
/* 122 */       if (ef != null) {
/* 123 */         return ef.create(prefix, document);
/*     */       }
/* 125 */     } else if ("http://www.w3.org/2004/xbl".equals(namespaceURI)) {
/* 126 */       ExtensibleDOMImplementation.ElementFactory ef = (ExtensibleDOMImplementation.ElementFactory)xblFactories.get(name);
/* 127 */       if (ef != null) {
/* 128 */         return ef.create(prefix, document);
/*     */       }
/*     */     } 
/*     */     
/* 132 */     if (this.customFactories != null) {
/*     */       
/* 134 */       ExtensibleDOMImplementation.ElementFactory cef = (ExtensibleDOMImplementation.ElementFactory)this.customFactories.get(namespaceURI, name);
/* 135 */       if (cef != null) {
/* 136 */         return cef.create(prefix, document);
/*     */       }
/*     */     } 
/*     */     
/* 140 */     return new BindableElement(prefix, document, namespaceURI, name);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public DocumentEventSupport createDocumentEventSupport() {
/* 148 */     DocumentEventSupport result = super.createDocumentEventSupport();
/* 149 */     result.registerEventFactory("WheelEvent", new DocumentEventSupport.EventFactory(this) {
/*     */           private final SVG12DOMImplementation this$0;
/*     */           
/* 152 */           public Event createEvent() { return new SVGOMWheelEvent(); }
/*     */         
/*     */         });
/* 155 */     result.registerEventFactory("ShadowTreeEvent", new DocumentEventSupport.EventFactory(this) {
/*     */           private final SVG12DOMImplementation this$0;
/*     */           
/* 158 */           public Event createEvent() { return new XBLOMShadowTreeEvent(); }
/*     */         
/*     */         });
/* 161 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 168 */   public EventSupport createEventSupport(AbstractNode n) { return new XBLEventSupport(n); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static HashTable xblFactories;
/*     */ 
/*     */   
/* 176 */   protected static HashTable svg12Factories = new HashTable(SVGDOMImplementation.svg11Factories);
/*     */   
/*     */   static  {
/* 179 */     svg12Factories.put("flowDiv", new FlowDivElementFactory());
/*     */ 
/*     */     
/* 182 */     svg12Factories.put("flowLine", new FlowLineElementFactory());
/*     */ 
/*     */     
/* 185 */     svg12Factories.put("flowPara", new FlowParaElementFactory());
/*     */ 
/*     */     
/* 188 */     svg12Factories.put("flowRegionBreak", new FlowRegionBreakElementFactory());
/*     */ 
/*     */     
/* 191 */     svg12Factories.put("flowRegion", new FlowRegionElementFactory());
/*     */ 
/*     */     
/* 194 */     svg12Factories.put("flowRegionExclude", new FlowRegionExcludeElementFactory());
/*     */ 
/*     */     
/* 197 */     svg12Factories.put("flowRoot", new FlowRootElementFactory());
/*     */ 
/*     */     
/* 200 */     svg12Factories.put("flowSpan", new FlowSpanElementFactory());
/*     */ 
/*     */     
/* 203 */     svg12Factories.put("handler", new HandlerElementFactory());
/*     */ 
/*     */     
/* 206 */     svg12Factories.put("multiImage", new MultiImageElementFactory());
/*     */ 
/*     */     
/* 209 */     svg12Factories.put("solidColor", new SolidColorElementFactory());
/*     */ 
/*     */     
/* 212 */     svg12Factories.put("subImage", new SubImageElementFactory());
/*     */ 
/*     */     
/* 215 */     svg12Factories.put("subImageRef", new SubImageRefElementFactory());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 416 */     xblFactories = new HashTable();
/*     */ 
/*     */     
/* 419 */     xblFactories.put("xbl", new XBLXBLElementFactory());
/*     */ 
/*     */     
/* 422 */     xblFactories.put("definition", new XBLDefinitionElementFactory());
/*     */ 
/*     */     
/* 425 */     xblFactories.put("template", new XBLTemplateElementFactory());
/*     */ 
/*     */     
/* 428 */     xblFactories.put("content", new XBLContentElementFactory());
/*     */ 
/*     */     
/* 431 */     xblFactories.put("handlerGroup", new XBLHandlerGroupElementFactory());
/*     */ 
/*     */     
/* 434 */     xblFactories.put("import", new XBLImportElementFactory());
/*     */ 
/*     */     
/* 437 */     xblFactories.put("shadowTree", new XBLShadowTreeElementFactory());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 541 */     DOM_IMPLEMENTATION = new SVG12DOMImplementation();
/*     */   }
/*     */   protected static final DOMImplementation DOM_IMPLEMENTATION;
/*     */   
/*     */   protected static class FlowDivElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowDivElement(prefix, (AbstractDocument)doc); } }
/*     */   
/* 548 */   public static DOMImplementation getDOMImplementation() { return DOM_IMPLEMENTATION; }
/*     */   
/*     */   protected static class FlowLineElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowLineElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowParaElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowParaElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowRegionBreakElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowRegionBreakElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowRegionElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowRegionElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowRegionExcludeElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowRegionExcludeElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowRootElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowRootElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class FlowSpanElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMFlowSpanElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class HandlerElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMHandlerElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class MultiImageElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMMultiImageElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class SolidColorElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMSolidColorElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class SubImageElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMSubImageElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class SubImageRefElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new SVGOMSubImageRefElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLXBLElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMXBLElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLDefinitionElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMDefinitionElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLTemplateElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMTemplateElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLContentElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMContentElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLHandlerGroupElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMHandlerGroupElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLImportElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMImportElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */   
/*     */   protected static class XBLShadowTreeElementFactory implements ExtensibleDOMImplementation.ElementFactory {
/*     */     public Element create(String prefix, Document doc) { return new XBLOMShadowTreeElement(prefix, (AbstractDocument)doc); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg12\SVG12DOMImplementation.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */