/*     */ package org.apache.batik.dom.svg12;
/*     */ 
/*     */ import java.util.HashSet;
/*     */ import org.apache.batik.dom.AbstractNode;
/*     */ import org.apache.batik.dom.events.AbstractEvent;
/*     */ import org.apache.batik.dom.events.EventListenerList;
/*     */ import org.apache.batik.dom.events.EventSupport;
/*     */ import org.apache.batik.dom.events.NodeEventTarget;
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.apache.batik.dom.xbl.NodeXBL;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.NodeList;
/*     */ import org.w3c.dom.events.Event;
/*     */ import org.w3c.dom.events.EventException;
/*     */ import org.w3c.dom.events.EventListener;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class XBLEventSupport
/*     */   extends EventSupport
/*     */ {
/*     */   protected HashTable capturingImplementationListeners;
/*     */   protected HashTable bubblingImplementationListeners;
/*  62 */   protected static HashTable eventTypeAliases = new HashTable();
/*     */   static  {
/*  64 */     eventTypeAliases.put("SVGLoad", "load");
/*  65 */     eventTypeAliases.put("SVGUnoad", "unload");
/*  66 */     eventTypeAliases.put("SVGAbort", "abort");
/*  67 */     eventTypeAliases.put("SVGError", "error");
/*  68 */     eventTypeAliases.put("SVGResize", "resize");
/*  69 */     eventTypeAliases.put("SVGScroll", "scroll");
/*  70 */     eventTypeAliases.put("SVGZoom", "zoom");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  77 */   public XBLEventSupport(AbstractNode n) { super(n); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture, Object group) {
/*  89 */     super.addEventListenerNS(namespaceURI, type, listener, useCapture, group);
/*     */     
/*  91 */     if (namespaceURI == null || namespaceURI.equals("http://www.w3.org/2001/xml-events")) {
/*     */       
/*  93 */       String alias = (String)eventTypeAliases.get(type);
/*  94 */       if (alias != null) {
/*  95 */         super.addEventListenerNS(namespaceURI, alias, listener, useCapture, group);
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture) {
/* 108 */     super.removeEventListenerNS(namespaceURI, type, listener, useCapture);
/* 109 */     if (namespaceURI == null || namespaceURI.equals("http://www.w3.org/2001/xml-events")) {
/*     */       
/* 111 */       String alias = (String)eventTypeAliases.get(type);
/* 112 */       if (alias != null) {
/* 113 */         super.removeEventListenerNS(namespaceURI, alias, listener, useCapture);
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addImplementationEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture) {
/*     */     HashTable hashTable;
/* 128 */     if (useCapture) {
/* 129 */       if (this.capturingImplementationListeners == null) {
/* 130 */         this.capturingImplementationListeners = new HashTable();
/*     */       }
/* 132 */       hashTable = this.capturingImplementationListeners;
/*     */     } else {
/* 134 */       if (this.bubblingImplementationListeners == null) {
/* 135 */         this.bubblingImplementationListeners = new HashTable();
/*     */       }
/* 137 */       hashTable = this.bubblingImplementationListeners;
/*     */     } 
/* 139 */     EventListenerList list = (EventListenerList)hashTable.get(type);
/* 140 */     if (list == null) {
/* 141 */       list = new EventListenerList();
/* 142 */       hashTable.put(type, list);
/*     */     } 
/* 144 */     list.addListener(namespaceURI, null, listener);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeImplementationEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture) {
/* 154 */     HashTable listeners = useCapture ? this.capturingImplementationListeners : this.bubblingImplementationListeners;
/*     */     
/* 156 */     if (listeners == null) {
/*     */       return;
/*     */     }
/* 159 */     EventListenerList list = (EventListenerList)listeners.get(type);
/* 160 */     if (list == null) {
/*     */       return;
/*     */     }
/* 163 */     list.removeListener(namespaceURI, listener);
/* 164 */     if (list.size() == 0) {
/* 165 */       listeners.remove(type);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void moveEventListeners(EventSupport other) {
/* 176 */     super.moveEventListeners(other);
/* 177 */     XBLEventSupport es = (XBLEventSupport)other;
/* 178 */     es.capturingImplementationListeners = this.capturingImplementationListeners;
/* 179 */     es.bubblingImplementationListeners = this.bubblingImplementationListeners;
/* 180 */     this.capturingImplementationListeners = null;
/* 181 */     this.bubblingImplementationListeners = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean dispatchEvent(NodeEventTarget target, Event evt) throws EventException {
/* 213 */     if (evt == null) {
/* 214 */       return false;
/*     */     }
/* 216 */     if (!(evt instanceof AbstractEvent)) {
/* 217 */       throw createEventException((short)9, "unsupported.event", new Object[0]);
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 222 */     AbstractEvent e = (AbstractEvent)evt;
/* 223 */     String type = e.getType();
/* 224 */     if (type == null || type.length() == 0) {
/* 225 */       throw createEventException((short)0, "unspecified.event", new Object[0]);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 231 */     setTarget(e, target);
/* 232 */     stopPropagation(e, false);
/* 233 */     stopImmediatePropagation(e, false);
/* 234 */     preventDefault(e, false);
/*     */     
/* 236 */     NodeEventTarget[] ancestors = getAncestors(target);
/* 237 */     int bubbleLimit = e.getBubbleLimit();
/* 238 */     int minAncestor = 0;
/* 239 */     if (isSingleScopeEvent(e)) {
/*     */ 
/*     */       
/* 242 */       AbstractNode targetNode = (AbstractNode)target;
/* 243 */       Node boundElement = targetNode.getXblBoundElement();
/* 244 */       if (boundElement != null) {
/* 245 */         minAncestor = ancestors.length;
/* 246 */         while (minAncestor > 0) {
/* 247 */           AbstractNode ancestorNode = (AbstractNode)ancestors[minAncestor - 1];
/*     */           
/* 249 */           if (ancestorNode.getXblBoundElement() != boundElement) {
/*     */             break;
/*     */           }
/* 252 */           minAncestor--;
/*     */         } 
/*     */       } 
/* 255 */     } else if (bubbleLimit != 0) {
/*     */       
/* 257 */       minAncestor = ancestors.length - bubbleLimit + 1;
/* 258 */       if (minAncestor < 0) {
/* 259 */         minAncestor = 0;
/*     */       }
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 271 */     AbstractEvent[] es = getRetargettedEvents(target, ancestors, e);
/* 272 */     boolean preventDefault = false;
/*     */     
/* 274 */     HashSet stoppedGroups = new HashSet();
/* 275 */     HashSet toBeStoppedGroups = new HashSet();
/* 276 */     for (int i = 0; i < minAncestor; i++) {
/* 277 */       NodeEventTarget node = ancestors[i];
/*     */       
/* 279 */       setCurrentTarget(es[i], node);
/* 280 */       setEventPhase(es[i], (short)1);
/* 281 */       fireImplementationEventListeners(node, es[i], true);
/*     */     } 
/* 283 */     for (int i = minAncestor; i < ancestors.length; i++) {
/* 284 */       NodeEventTarget node = ancestors[i];
/*     */       
/* 286 */       setCurrentTarget(es[i], node);
/* 287 */       setEventPhase(es[i], (short)1);
/* 288 */       fireImplementationEventListeners(node, es[i], true);
/* 289 */       fireEventListeners(node, es[i], true, stoppedGroups, toBeStoppedGroups);
/*     */       
/* 291 */       fireHandlerGroupEventListeners(node, es[i], true, stoppedGroups, toBeStoppedGroups);
/*     */       
/* 293 */       preventDefault = (preventDefault || es[i].getDefaultPrevented());
/* 294 */       stoppedGroups.addAll(toBeStoppedGroups);
/* 295 */       toBeStoppedGroups.clear();
/*     */     } 
/*     */ 
/*     */     
/* 299 */     setEventPhase(e, (short)2);
/* 300 */     setCurrentTarget(e, target);
/* 301 */     fireImplementationEventListeners(target, e, false);
/* 302 */     fireEventListeners(target, e, false, stoppedGroups, toBeStoppedGroups);
/*     */     
/* 304 */     fireHandlerGroupEventListeners(this.node, e, false, stoppedGroups, toBeStoppedGroups);
/*     */     
/* 306 */     stoppedGroups.addAll(toBeStoppedGroups);
/* 307 */     toBeStoppedGroups.clear();
/* 308 */     preventDefault = (preventDefault || e.getDefaultPrevented());
/*     */     
/* 310 */     if (e.getBubbles()) {
/* 311 */       for (int i = ancestors.length - 1; i >= minAncestor; i--) {
/* 312 */         NodeEventTarget node = ancestors[i];
/*     */         
/* 314 */         setCurrentTarget(es[i], node);
/* 315 */         setEventPhase(es[i], (short)3);
/* 316 */         fireImplementationEventListeners(node, es[i], false);
/* 317 */         fireEventListeners(node, es[i], false, stoppedGroups, toBeStoppedGroups);
/*     */         
/* 319 */         fireHandlerGroupEventListeners(node, es[i], false, stoppedGroups, toBeStoppedGroups);
/*     */         
/* 321 */         preventDefault = (preventDefault || es[i].getDefaultPrevented());
/*     */         
/* 323 */         stoppedGroups.addAll(toBeStoppedGroups);
/* 324 */         toBeStoppedGroups.clear();
/*     */       } 
/* 326 */       for (int i = minAncestor - 1; i >= 0; i--) {
/* 327 */         NodeEventTarget node = ancestors[i];
/*     */         
/* 329 */         setCurrentTarget(es[i], node);
/* 330 */         setEventPhase(es[i], (short)3);
/* 331 */         fireImplementationEventListeners(node, es[i], false);
/* 332 */         preventDefault = (preventDefault || es[i].getDefaultPrevented());
/*     */       } 
/*     */     } 
/*     */     
/* 336 */     if (!preventDefault) {
/* 337 */       runDefaultActions(e);
/*     */     }
/* 339 */     return preventDefault;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void fireHandlerGroupEventListeners(NodeEventTarget node, AbstractEvent e, boolean useCapture, HashSet stoppedGroups, HashSet toBeStoppedGroups) {
/* 351 */     NodeList defs = ((NodeXBL)node).getXblDefinitions();
/* 352 */     for (int j = 0; j < defs.getLength(); j++) {
/*     */       
/* 354 */       Node n = defs.item(j).getFirstChild();
/* 355 */       while (n != null && !(n instanceof XBLOMHandlerGroupElement))
/*     */       {
/* 357 */         n = n.getNextSibling();
/*     */       }
/* 359 */       if (n != null) {
/*     */ 
/*     */         
/* 362 */         node = (NodeEventTarget)n;
/* 363 */         String type = e.getType();
/* 364 */         EventSupport support = node.getEventSupport();
/*     */         
/* 366 */         if (support != null) {
/*     */ 
/*     */           
/* 369 */           EventListenerList list = support.getEventListeners(type, useCapture);
/*     */           
/* 371 */           if (list == null) {
/*     */             return;
/*     */           }
/*     */           
/* 375 */           EventListenerList.Entry[] arrayOfEntry = list.getEventListeners();
/* 376 */           fireEventListeners(node, e, arrayOfEntry, stoppedGroups, toBeStoppedGroups);
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 386 */   protected boolean isSingleScopeEvent(Event evt) { return (evt instanceof org.w3c.dom.events.MutationEvent || evt instanceof org.apache.batik.dom.xbl.ShadowTreeEvent); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected AbstractEvent[] getRetargettedEvents(NodeEventTarget target, NodeEventTarget[] ancestors, AbstractEvent e) {
/* 398 */     boolean singleScope = isSingleScopeEvent(e);
/* 399 */     AbstractNode targetNode = (AbstractNode)target;
/* 400 */     AbstractEvent[] es = new AbstractEvent[ancestors.length];
/* 401 */     if (ancestors.length > 0) {
/* 402 */       int index = ancestors.length - 1;
/* 403 */       Node boundElement = targetNode.getXblBoundElement();
/* 404 */       AbstractNode ancestorNode = (AbstractNode)ancestors[index];
/* 405 */       if (!singleScope && ancestorNode.getXblBoundElement() != boundElement) {
/*     */         
/* 407 */         es[index] = retargetEvent(e, ancestors[index]);
/*     */       } else {
/* 409 */         es[index] = e;
/*     */       } 
/* 411 */       while (--index >= 0) {
/* 412 */         ancestorNode = (AbstractNode)ancestors[index + 1];
/* 413 */         boundElement = ancestorNode.getXblBoundElement();
/* 414 */         AbstractNode nextAncestorNode = (AbstractNode)ancestors[index];
/* 415 */         Node nextBoundElement = nextAncestorNode.getXblBoundElement();
/* 416 */         if (!singleScope && nextBoundElement != boundElement) {
/* 417 */           es[index] = retargetEvent(es[index + 1], ancestors[index]); continue;
/*     */         } 
/* 419 */         es[index] = es[index + 1];
/*     */       } 
/*     */     } 
/*     */     
/* 423 */     return es;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected AbstractEvent retargetEvent(AbstractEvent e, NodeEventTarget target) {
/* 431 */     AbstractEvent clonedEvent = e.cloneEvent();
/* 432 */     setTarget(clonedEvent, target);
/* 433 */     return clonedEvent;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public EventListenerList getImplementationEventListeners(String type, boolean useCapture) {
/* 441 */     HashTable listeners = useCapture ? this.capturingImplementationListeners : this.bubblingImplementationListeners;
/*     */     
/* 443 */     if (listeners == null) {
/* 444 */       return null;
/*     */     }
/* 446 */     return (EventListenerList)listeners.get(type);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void fireImplementationEventListeners(NodeEventTarget node, AbstractEvent e, boolean useCapture) {
/* 456 */     String type = e.getType();
/* 457 */     XBLEventSupport support = (XBLEventSupport)node.getEventSupport();
/*     */     
/* 459 */     if (support == null) {
/*     */       return;
/*     */     }
/* 462 */     EventListenerList list = support.getImplementationEventListeners(type, useCapture);
/*     */ 
/*     */     
/* 465 */     if (list == null) {
/*     */       return;
/*     */     }
/*     */     
/* 469 */     EventListenerList.Entry[] arrayOfEntry = list.getEventListeners();
/* 470 */     fireEventListeners(node, e, arrayOfEntry, null, null);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg12\XBLEventSupport.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */