/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.parser.LengthListHandler;
/*     */ import org.apache.batik.parser.LengthListParser;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGLength;
/*     */ import org.w3c.dom.svg.SVGLengthList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGLengthList
/*     */   extends AbstractSVGList
/*     */   implements SVGLengthList
/*     */ {
/*     */   protected short direction;
/*     */   public static final String SVG_LENGTH_LIST_SEPARATOR = " ";
/*     */   
/*  56 */   protected String getItemSeparator() { return " "; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract SVGException createSVGException(short paramShort, String paramString, Object[] paramArrayOfObject);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract Element getElement();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  76 */   protected AbstractSVGLengthList(short direction) { this.direction = direction; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  84 */   public SVGLength initialize(SVGLength newItem) throws DOMException, SVGException { return (SVGLength)initializeImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  91 */   public SVGLength getItem(int index) throws DOMException { return (SVGLength)getItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 100 */   public SVGLength insertItemBefore(SVGLength newItem, int index) throws DOMException, SVGException { return (SVGLength)insertItemBeforeImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 109 */   public SVGLength replaceItem(SVGLength newItem, int index) throws DOMException, SVGException { return (SVGLength)replaceItemImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   public SVGLength removeItem(int index) throws DOMException { return (SVGLength)removeItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 124 */   public SVGLength appendItem(SVGLength newItem) throws DOMException, SVGException { return (SVGLength)appendItemImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGItem createSVGItem(Object newItem) {
/* 131 */     SVGLength l = (SVGLength)newItem;
/* 132 */     return new SVGLengthItem(this, l.getUnitType(), l.getValueInSpecifiedUnits(), this.direction);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void doParse(String value, ListHandler handler) throws ParseException {
/* 145 */     LengthListParser lengthListParser = new LengthListParser();
/*     */     
/* 147 */     LengthListBuilder builder = new LengthListBuilder(this, handler);
/*     */     
/* 149 */     lengthListParser.setLengthListHandler(builder);
/* 150 */     lengthListParser.parse(value);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void checkItemType(Object newItem) throws SVGException {
/* 157 */     if (!(newItem instanceof SVGLength)) {
/* 158 */       createSVGException((short)0, "expected.length", null);
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   protected class SVGLengthItem
/*     */     extends AbstractSVGLength
/*     */     implements SVGItem
/*     */   {
/*     */     protected AbstractSVGList parentList;
/*     */     
/*     */     private final AbstractSVGLengthList this$0;
/*     */     
/*     */     public SVGLengthItem(AbstractSVGLengthList this$0, short type, float value, short direction) {
/* 172 */       super(direction); this.this$0 = this$0;
/* 173 */       this.unitType = type;
/* 174 */       this.value = value;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 181 */     protected SVGOMElement getAssociatedElement() { return (SVGOMElement)this.this$0.getElement(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 194 */     public void setParent(AbstractSVGList list) { this.parentList = list; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 201 */     public AbstractSVGList getParent() { return this.parentList; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void reset() throws ParseException {
/* 208 */       if (this.parentList != null) {
/* 209 */         this.parentList.itemChanged();
/*     */       }
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class LengthListBuilder
/*     */     implements LengthListHandler
/*     */   {
/*     */     protected ListHandler listHandler;
/*     */ 
/*     */ 
/*     */     
/*     */     protected float currentValue;
/*     */ 
/*     */ 
/*     */     
/*     */     protected short currentType;
/*     */ 
/*     */ 
/*     */     
/*     */     private final AbstractSVGLengthList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public LengthListBuilder(AbstractSVGLengthList this$0, ListHandler listHandler) {
/* 239 */       this.this$0 = this$0;
/* 240 */       this.listHandler = listHandler;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 247 */     public void startLengthList() throws ParseException { this.listHandler.startList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void startLength() throws ParseException {
/* 254 */       this.currentType = 1;
/* 255 */       this.currentValue = 0.0F;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 262 */     public void lengthValue(float v) throws ParseException { this.currentValue = v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 269 */     public void em() throws ParseException { this.currentType = 3; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 276 */     public void ex() throws ParseException { this.currentType = 4; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 283 */     public void in() throws ParseException { this.currentType = 8; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 290 */     public void cm() throws ParseException { this.currentType = 6; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 297 */     public void mm() throws ParseException { this.currentType = 7; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 304 */     public void pc() throws ParseException { this.currentType = 10; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 311 */     public void pt() throws ParseException { this.currentType = 3; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 318 */     public void px() throws ParseException { this.currentType = 5; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 325 */     public void percentage() throws ParseException { this.currentType = 2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 332 */     public void endLength() throws ParseException { this.listHandler.item(new AbstractSVGLengthList.SVGLengthItem(this.this$0, this.currentType, this.currentValue, this.this$0.direction)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 340 */     public void endLengthList() throws ParseException { this.listHandler.endList(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGLengthList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */