/*      */ package org.apache.batik.dom.svg;
/*      */ 
/*      */ import org.apache.batik.parser.DefaultPathHandler;
/*      */ import org.apache.batik.parser.ParseException;
/*      */ import org.apache.batik.parser.PathParser;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.svg.SVGException;
/*      */ import org.w3c.dom.svg.SVGPathSeg;
/*      */ import org.w3c.dom.svg.SVGPathSegArcAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegArcRel;
/*      */ import org.w3c.dom.svg.SVGPathSegClosePath;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicRel;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicSmoothAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoCubicSmoothRel;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticRel;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticSmoothAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegCurvetoQuadraticSmoothRel;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoHorizontalAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoHorizontalRel;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoRel;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoVerticalAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegLinetoVerticalRel;
/*      */ import org.w3c.dom.svg.SVGPathSegList;
/*      */ import org.w3c.dom.svg.SVGPathSegMovetoAbs;
/*      */ import org.w3c.dom.svg.SVGPathSegMovetoRel;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractSVGPathSegList
/*      */   extends AbstractSVGList
/*      */   implements SVGPathSegList, SVGPathSegConstants
/*      */ {
/*      */   public static final String SVG_PATHSEG_LIST_SEPARATOR = " ";
/*      */   
/*   77 */   protected String getItemSeparator() { return " "; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected abstract SVGException createSVGException(short paramShort, String paramString, Object[] paramArrayOfObject);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   95 */   public SVGPathSeg initialize(SVGPathSeg newItem) throws DOMException, SVGException { return (SVGPathSeg)initializeImpl(newItem); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  103 */   public SVGPathSeg getItem(int index) throws DOMException { return (SVGPathSeg)getItemImpl(index); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  111 */   public SVGPathSeg insertItemBefore(SVGPathSeg newItem, int index) throws DOMException, SVGException { return (SVGPathSeg)insertItemBeforeImpl(newItem, index); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  119 */   public SVGPathSeg replaceItem(SVGPathSeg newItem, int index) throws DOMException, SVGException { return (SVGPathSeg)replaceItemImpl(newItem, index); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  127 */   public SVGPathSeg removeItem(int index) throws DOMException { return (SVGPathSeg)removeItemImpl(index); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  135 */   public SVGPathSeg appendItem(SVGPathSeg newItem) throws DOMException, SVGException { return (SVGPathSeg)appendItemImpl(newItem); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected SVGItem createSVGItem(Object newItem) {
/*  142 */     SVGPathSeg pathSeg = (SVGPathSeg)newItem;
/*      */     
/*  144 */     return createPathSegItem(pathSeg);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void doParse(String value, ListHandler handler) throws ParseException {
/*  156 */     PathParser pathParser = new PathParser();
/*      */     
/*  158 */     PathSegListBuilder builder = new PathSegListBuilder(this, handler);
/*      */     
/*  160 */     pathParser.setPathHandler(builder);
/*  161 */     pathParser.parse(value);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void checkItemType(Object newItem) {
/*  169 */     if (!(newItem instanceof SVGPathSeg)) {
/*  170 */       createSVGException((short)0, "expected SVGPathSeg", null);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected SVGPathSegItem createPathSegItem(SVGPathSeg pathSeg) {
/*  181 */     SVGPathSegItem pathSegItem = null;
/*      */     
/*  183 */     short type = pathSeg.getPathSegType();
/*      */     
/*  185 */     switch (type) {
/*      */       case 10:
/*      */       case 11:
/*  188 */         pathSegItem = new SVGPathSegArcItem(this, pathSeg);
/*      */         break;
/*      */       case 1:
/*  191 */         pathSegItem = new SVGPathSegItem(this, pathSeg);
/*      */         break;
/*      */       case 6:
/*      */       case 7:
/*  195 */         pathSegItem = new SVGPathSegCurvetoCubicItem(this, pathSeg);
/*      */         break;
/*      */       case 16:
/*      */       case 17:
/*  199 */         pathSegItem = new SVGPathSegCurvetoCubicSmoothItem(this, pathSeg);
/*      */         break;
/*      */       case 8:
/*      */       case 9:
/*  203 */         pathSegItem = new SVGPathSegCurvetoQuadraticItem(this, pathSeg);
/*      */         break;
/*      */       case 18:
/*      */       case 19:
/*  207 */         pathSegItem = new SVGPathSegCurvetoQuadraticSmoothItem(this, pathSeg);
/*      */         break;
/*      */       case 2:
/*      */       case 3:
/*      */       case 4:
/*      */       case 5:
/*  213 */         pathSegItem = new SVGPathSegMovetoLinetoItem(this, pathSeg);
/*      */         break;
/*      */       case 12:
/*      */       case 13:
/*  217 */         pathSegItem = new SVGPathSegLinetoHorizontalItem(this, pathSeg);
/*      */         break;
/*      */       case 14:
/*      */       case 15:
/*  221 */         pathSegItem = new SVGPathSegLinetoVerticalItem(this, pathSeg);
/*      */         break;
/*      */     } 
/*      */     
/*  225 */     return pathSegItem;
/*      */   }
/*      */ 
/*      */   
/*      */   protected class SVGPathSegItem
/*      */     extends AbstractSVGItem
/*      */     implements SVGPathSeg, SVGPathSegClosePath
/*      */   {
/*      */     protected short type;
/*      */     
/*      */     protected String letter;
/*      */     
/*      */     protected float x;
/*      */     
/*      */     protected float y;
/*      */     protected float x1;
/*      */     protected float y1;
/*      */     protected float x2;
/*      */     protected float y2;
/*      */     protected float r1;
/*      */     protected float r2;
/*      */     protected float angle;
/*      */     protected boolean largeArcFlag;
/*      */     protected boolean sweepFlag;
/*      */     private final AbstractSVGPathSegList this$0;
/*      */     
/*  251 */     protected SVGPathSegItem(AbstractSVGPathSegList this$0) { this.this$0 = this$0; }
/*      */     public SVGPathSegItem(AbstractSVGPathSegList this$0, short type, String letter) {
/*  253 */       this.this$0 = this$0;
/*  254 */       this.type = type;
/*  255 */       this.letter = letter;
/*      */     }
/*      */     public SVGPathSegItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  258 */       this.this$0 = this$0;
/*  259 */       this.type = pathSeg.getPathSegType();
/*  260 */       switch (this.type) {
/*      */         case 1:
/*  262 */           this.letter = "z";
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */     
/*  268 */     protected String getStringValue() { return this.letter; }
/*      */ 
/*      */ 
/*      */     
/*  272 */     public short getPathSegType() { return this.type; }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  277 */     public String getPathSegTypeAsLetter() { return this.letter; }
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegMovetoLinetoItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegMovetoAbs, SVGPathSegMovetoRel, SVGPathSegLinetoAbs, SVGPathSegLinetoRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */     
/*      */     public SVGPathSegMovetoLinetoItem(AbstractSVGPathSegList this$0, short type, String letter, float x, float y) {
/*  290 */       super(this$0, type, letter); this.this$0 = this$0;
/*  291 */       this.x = x;
/*  292 */       this.y = y;
/*      */     }
/*      */     public SVGPathSegMovetoLinetoItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  295 */       super(this$0); this.this$0 = this$0;
/*  296 */       this.type = pathSeg.getPathSegType();
/*  297 */       switch (this.type) {
/*      */         case 5:
/*  299 */           this.letter = "l";
/*  300 */           this.x = ((SVGPathSegLinetoRel)pathSeg).getX();
/*  301 */           this.y = ((SVGPathSegLinetoRel)pathSeg).getY();
/*      */           break;
/*      */         case 4:
/*  304 */           this.letter = "L";
/*  305 */           this.x = ((SVGPathSegLinetoAbs)pathSeg).getX();
/*  306 */           this.y = ((SVGPathSegLinetoAbs)pathSeg).getY();
/*      */           break;
/*      */         case 3:
/*  309 */           this.letter = "m";
/*  310 */           this.x = ((SVGPathSegMovetoRel)pathSeg).getX();
/*  311 */           this.y = ((SVGPathSegMovetoRel)pathSeg).getY();
/*      */           break;
/*      */         case 2:
/*  314 */           this.letter = "M";
/*  315 */           this.x = ((SVGPathSegMovetoAbs)pathSeg).getX();
/*  316 */           this.y = ((SVGPathSegMovetoAbs)pathSeg).getY();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  323 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  326 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  330 */       this.x = x;
/*  331 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  334 */       this.y = y;
/*  335 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  339 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegCurvetoCubicItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegCurvetoCubicAbs, SVGPathSegCurvetoCubicRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */ 
/*      */     
/*      */     public SVGPathSegCurvetoCubicItem(AbstractSVGPathSegList this$0, short type, String letter, float x1, float y1, float x2, float y2, float x, float y) {
/*  354 */       super(this$0, type, letter); this.this$0 = this$0;
/*  355 */       this.x = x;
/*  356 */       this.y = y;
/*  357 */       this.x1 = x1;
/*  358 */       this.y1 = y1;
/*  359 */       this.x2 = x2;
/*  360 */       this.y2 = y2;
/*      */     }
/*      */     public SVGPathSegCurvetoCubicItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  363 */       super(this$0); this.this$0 = this$0;
/*  364 */       this.type = pathSeg.getPathSegType();
/*  365 */       switch (this.type) {
/*      */         case 6:
/*  367 */           this.letter = "C";
/*  368 */           this.x = ((SVGPathSegCurvetoCubicAbs)pathSeg).getX();
/*  369 */           this.y = ((SVGPathSegCurvetoCubicAbs)pathSeg).getY();
/*  370 */           this.x1 = ((SVGPathSegCurvetoCubicAbs)pathSeg).getX1();
/*  371 */           this.y1 = ((SVGPathSegCurvetoCubicAbs)pathSeg).getY1();
/*  372 */           this.x2 = ((SVGPathSegCurvetoCubicAbs)pathSeg).getX2();
/*  373 */           this.y2 = ((SVGPathSegCurvetoCubicAbs)pathSeg).getY2();
/*      */           break;
/*      */         case 7:
/*  376 */           this.letter = "c";
/*  377 */           this.x = ((SVGPathSegCurvetoCubicRel)pathSeg).getX();
/*  378 */           this.y = ((SVGPathSegCurvetoCubicRel)pathSeg).getY();
/*  379 */           this.x1 = ((SVGPathSegCurvetoCubicRel)pathSeg).getX1();
/*  380 */           this.y1 = ((SVGPathSegCurvetoCubicRel)pathSeg).getY1();
/*  381 */           this.x2 = ((SVGPathSegCurvetoCubicRel)pathSeg).getX2();
/*  382 */           this.y2 = ((SVGPathSegCurvetoCubicRel)pathSeg).getY2();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  389 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  392 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  396 */       this.x = x;
/*  397 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  400 */       this.y = y;
/*  401 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  405 */     public float getX1() { return this.x1; }
/*      */ 
/*      */     
/*  408 */     public float getY1() { return this.y1; }
/*      */ 
/*      */     
/*      */     public void setX1(float x1) throws ParseException {
/*  412 */       this.x1 = x1;
/*  413 */       resetAttribute();
/*      */     }
/*      */     public void setY1(float y1) throws ParseException {
/*  416 */       this.y1 = y1;
/*  417 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  421 */     public float getX2() { return this.x2; }
/*      */ 
/*      */     
/*  424 */     public float getY2() { return this.y2; }
/*      */ 
/*      */     
/*      */     public void setX2(float x2) throws ParseException {
/*  428 */       this.x2 = x2;
/*  429 */       resetAttribute();
/*      */     }
/*      */     public void setY2(float y2) throws ParseException {
/*  432 */       this.y2 = y2;
/*  433 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  437 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x1) + ' ' + Float.toString(this.y1) + ' ' + Float.toString(this.x2) + ' ' + Float.toString(this.y2) + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegCurvetoQuadraticItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegCurvetoQuadraticAbs, SVGPathSegCurvetoQuadraticRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public SVGPathSegCurvetoQuadraticItem(AbstractSVGPathSegList this$0, short type, String letter, float x1, float y1, float x, float y) {
/*  459 */       super(this$0, type, letter); this.this$0 = this$0;
/*  460 */       this.x = x;
/*  461 */       this.y = y;
/*  462 */       this.x1 = x1;
/*  463 */       this.y1 = y1;
/*      */     }
/*      */     public SVGPathSegCurvetoQuadraticItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  466 */       super(this$0); this.this$0 = this$0;
/*  467 */       this.type = pathSeg.getPathSegType();
/*  468 */       switch (this.type) {
/*      */         case 8:
/*  470 */           this.letter = "Q";
/*  471 */           this.x = ((SVGPathSegCurvetoQuadraticAbs)pathSeg).getX();
/*  472 */           this.y = ((SVGPathSegCurvetoQuadraticAbs)pathSeg).getY();
/*  473 */           this.x1 = ((SVGPathSegCurvetoQuadraticAbs)pathSeg).getX1();
/*  474 */           this.y1 = ((SVGPathSegCurvetoQuadraticAbs)pathSeg).getY1();
/*      */           break;
/*      */         case 9:
/*  477 */           this.letter = "q";
/*  478 */           this.x = ((SVGPathSegCurvetoQuadraticRel)pathSeg).getX();
/*  479 */           this.y = ((SVGPathSegCurvetoQuadraticRel)pathSeg).getY();
/*  480 */           this.x1 = ((SVGPathSegCurvetoQuadraticRel)pathSeg).getX1();
/*  481 */           this.y1 = ((SVGPathSegCurvetoQuadraticRel)pathSeg).getY1();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  489 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  492 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  496 */       this.x = x;
/*  497 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  500 */       this.y = y;
/*  501 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  505 */     public float getX1() { return this.x1; }
/*      */ 
/*      */     
/*  508 */     public float getY1() { return this.y1; }
/*      */ 
/*      */     
/*      */     public void setX1(float x1) throws ParseException {
/*  512 */       this.x1 = x1;
/*  513 */       resetAttribute();
/*      */     }
/*      */     public void setY1(float y1) throws ParseException {
/*  516 */       this.y1 = y1;
/*  517 */       resetAttribute();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  522 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x1) + ' ' + Float.toString(this.y1) + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegArcItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegArcAbs, SVGPathSegArcRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public SVGPathSegArcItem(AbstractSVGPathSegList this$0, short type, String letter, float r1, float r2, float angle, boolean largeArcFlag, boolean sweepFlag, float x, float y) {
/*  542 */       super(this$0, type, letter); this.this$0 = this$0;
/*  543 */       this.x = x;
/*  544 */       this.y = y;
/*  545 */       this.r1 = r1;
/*  546 */       this.r2 = r2;
/*  547 */       this.angle = angle;
/*  548 */       this.largeArcFlag = largeArcFlag;
/*  549 */       this.sweepFlag = sweepFlag;
/*      */     }
/*      */     public SVGPathSegArcItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  552 */       super(this$0); this.this$0 = this$0;
/*  553 */       this.type = pathSeg.getPathSegType();
/*  554 */       switch (this.type) {
/*      */         case 10:
/*  556 */           this.letter = "A";
/*  557 */           this.x = ((SVGPathSegArcAbs)pathSeg).getX();
/*  558 */           this.y = ((SVGPathSegArcAbs)pathSeg).getY();
/*  559 */           this.r1 = ((SVGPathSegArcAbs)pathSeg).getR1();
/*  560 */           this.r2 = ((SVGPathSegArcAbs)pathSeg).getR2();
/*  561 */           this.angle = ((SVGPathSegArcAbs)pathSeg).getAngle();
/*  562 */           this.largeArcFlag = ((SVGPathSegArcAbs)pathSeg).getLargeArcFlag();
/*  563 */           this.sweepFlag = ((SVGPathSegArcAbs)pathSeg).getSweepFlag();
/*      */           break;
/*      */         case 11:
/*  566 */           this.letter = "a";
/*  567 */           this.x = ((SVGPathSegArcRel)pathSeg).getX();
/*  568 */           this.y = ((SVGPathSegArcRel)pathSeg).getY();
/*  569 */           this.r1 = ((SVGPathSegArcRel)pathSeg).getR1();
/*  570 */           this.r2 = ((SVGPathSegArcRel)pathSeg).getR2();
/*  571 */           this.angle = ((SVGPathSegArcRel)pathSeg).getAngle();
/*  572 */           this.largeArcFlag = ((SVGPathSegArcRel)pathSeg).getLargeArcFlag();
/*  573 */           this.sweepFlag = ((SVGPathSegArcRel)pathSeg).getSweepFlag();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  580 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  583 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  587 */       this.x = x;
/*  588 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  591 */       this.y = y;
/*  592 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  596 */     public float getR1() { return this.r1; }
/*      */ 
/*      */     
/*  599 */     public float getR2() { return this.r2; }
/*      */ 
/*      */     
/*      */     public void setR1(float r1) throws ParseException {
/*  603 */       this.r1 = r1;
/*  604 */       resetAttribute();
/*      */     }
/*      */     public void setR2(float r2) throws ParseException {
/*  607 */       this.r2 = r2;
/*  608 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  612 */     public float getAngle() { return this.angle; }
/*      */ 
/*      */     
/*      */     public void setAngle(float angle) throws ParseException {
/*  616 */       this.angle = angle;
/*  617 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  621 */     public boolean getSweepFlag() { return this.sweepFlag; }
/*      */ 
/*      */     
/*      */     public void setSweepFlag(boolean sweepFlag) {
/*  625 */       this.sweepFlag = sweepFlag;
/*  626 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  630 */     public boolean getLargeArcFlag() { return this.largeArcFlag; }
/*      */ 
/*      */     
/*      */     public void setLargeArcFlag(boolean largeArcFlag) {
/*  634 */       this.largeArcFlag = largeArcFlag;
/*  635 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  639 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.r1) + ' ' + Float.toString(this.r2) + ' ' + Float.toString(this.angle) + ' ' + (this.largeArcFlag ? "1" : "0") + ' ' + (this.sweepFlag ? "1" : "0") + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegLinetoHorizontalItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegLinetoHorizontalAbs, SVGPathSegLinetoHorizontalRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public SVGPathSegLinetoHorizontalItem(AbstractSVGPathSegList this$0, short type, String letter, float value) {
/*  664 */       super(this$0, type, letter); this.this$0 = this$0;
/*  665 */       this.x = value;
/*      */     } public SVGPathSegLinetoHorizontalItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  667 */       super(this$0); this.this$0 = this$0;
/*  668 */       this.type = pathSeg.getPathSegType();
/*  669 */       switch (this.type) {
/*      */         case 12:
/*  671 */           this.letter = "H";
/*  672 */           this.x = ((SVGPathSegLinetoHorizontalAbs)pathSeg).getX();
/*      */           break;
/*      */         case 13:
/*  675 */           this.letter = "h";
/*  676 */           this.x = ((SVGPathSegLinetoHorizontalRel)pathSeg).getX();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  683 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  687 */       this.x = x;
/*  688 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  692 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x); }
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegLinetoVerticalItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegLinetoVerticalAbs, SVGPathSegLinetoVerticalRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */     
/*      */     public SVGPathSegLinetoVerticalItem(AbstractSVGPathSegList this$0, short type, String letter, float value) {
/*  705 */       super(this$0, type, letter); this.this$0 = this$0;
/*  706 */       this.y = value;
/*      */     }
/*      */     public SVGPathSegLinetoVerticalItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  709 */       super(this$0); this.this$0 = this$0;
/*  710 */       this.type = pathSeg.getPathSegType();
/*  711 */       switch (this.type) {
/*      */         case 14:
/*  713 */           this.letter = "V";
/*  714 */           this.y = ((SVGPathSegLinetoVerticalAbs)pathSeg).getY();
/*      */           break;
/*      */         case 15:
/*  717 */           this.letter = "v";
/*  718 */           this.y = ((SVGPathSegLinetoVerticalRel)pathSeg).getY();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  725 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setY(float y) throws ParseException {
/*  729 */       this.y = y;
/*  730 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  734 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */   
/*      */   public class SVGPathSegCurvetoCubicSmoothItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegCurvetoCubicSmoothAbs, SVGPathSegCurvetoCubicSmoothRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */     
/*      */     public SVGPathSegCurvetoCubicSmoothItem(AbstractSVGPathSegList this$0, short type, String letter, float x2, float y2, float x, float y) {
/*  746 */       super(this$0, type, letter); this.this$0 = this$0;
/*  747 */       this.x = x;
/*  748 */       this.y = y;
/*  749 */       this.x2 = x2;
/*  750 */       this.y2 = y2;
/*      */     }
/*      */     public SVGPathSegCurvetoCubicSmoothItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  753 */       super(this$0); this.this$0 = this$0;
/*  754 */       this.type = pathSeg.getPathSegType();
/*  755 */       switch (this.type) {
/*      */         case 16:
/*  757 */           this.letter = "S";
/*  758 */           this.x = ((SVGPathSegCurvetoCubicSmoothAbs)pathSeg).getX();
/*  759 */           this.y = ((SVGPathSegCurvetoCubicSmoothAbs)pathSeg).getY();
/*  760 */           this.x2 = ((SVGPathSegCurvetoCubicSmoothAbs)pathSeg).getX2();
/*  761 */           this.y2 = ((SVGPathSegCurvetoCubicSmoothAbs)pathSeg).getY2();
/*      */           break;
/*      */         case 17:
/*  764 */           this.letter = "s";
/*  765 */           this.x = ((SVGPathSegCurvetoCubicSmoothRel)pathSeg).getX();
/*  766 */           this.y = ((SVGPathSegCurvetoCubicSmoothRel)pathSeg).getY();
/*  767 */           this.x2 = ((SVGPathSegCurvetoCubicSmoothRel)pathSeg).getX2();
/*  768 */           this.y2 = ((SVGPathSegCurvetoCubicSmoothRel)pathSeg).getY2();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  775 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  778 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  782 */       this.x = x;
/*  783 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  786 */       this.y = y;
/*  787 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  791 */     public float getX2() { return this.x2; }
/*      */ 
/*      */     
/*  794 */     public float getY2() { return this.y2; }
/*      */ 
/*      */     
/*      */     public void setX2(float x2) throws ParseException {
/*  798 */       this.x2 = x2;
/*  799 */       resetAttribute();
/*      */     }
/*      */     public void setY2(float y2) throws ParseException {
/*  802 */       this.y2 = y2;
/*  803 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  807 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x2) + ' ' + Float.toString(this.y2) + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class SVGPathSegCurvetoQuadraticSmoothItem
/*      */     extends SVGPathSegItem
/*      */     implements SVGPathSegCurvetoQuadraticSmoothAbs, SVGPathSegCurvetoQuadraticSmoothRel
/*      */   {
/*      */     private final AbstractSVGPathSegList this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public SVGPathSegCurvetoQuadraticSmoothItem(AbstractSVGPathSegList this$0, short type, String letter, float x, float y) {
/*  825 */       super(this$0, type, letter); this.this$0 = this$0;
/*  826 */       this.x = x;
/*  827 */       this.y = y;
/*      */     }
/*      */     public SVGPathSegCurvetoQuadraticSmoothItem(AbstractSVGPathSegList this$0, SVGPathSeg pathSeg) {
/*  830 */       super(this$0); this.this$0 = this$0;
/*  831 */       this.type = pathSeg.getPathSegType();
/*  832 */       switch (this.type) {
/*      */         case 18:
/*  834 */           this.letter = "T";
/*  835 */           this.x = ((SVGPathSegCurvetoQuadraticSmoothAbs)pathSeg).getX();
/*  836 */           this.y = ((SVGPathSegCurvetoQuadraticSmoothAbs)pathSeg).getY();
/*      */           break;
/*      */         case 19:
/*  839 */           this.letter = "t";
/*  840 */           this.x = ((SVGPathSegCurvetoQuadraticSmoothRel)pathSeg).getX();
/*  841 */           this.y = ((SVGPathSegCurvetoQuadraticSmoothRel)pathSeg).getY();
/*      */           break;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  848 */     public float getX() { return this.x; }
/*      */ 
/*      */     
/*  851 */     public float getY() { return this.y; }
/*      */ 
/*      */     
/*      */     public void setX(float x) throws ParseException {
/*  855 */       this.x = x;
/*  856 */       resetAttribute();
/*      */     }
/*      */     public void setY(float y) throws ParseException {
/*  859 */       this.y = y;
/*  860 */       resetAttribute();
/*      */     }
/*      */ 
/*      */     
/*  864 */     protected String getStringValue() { return this.letter + ' ' + Float.toString(this.x) + ' ' + Float.toString(this.y); }
/*      */   }
/*      */ 
/*      */   
/*      */   protected class PathSegListBuilder
/*      */     extends DefaultPathHandler
/*      */   {
/*      */     protected ListHandler listHandler;
/*      */     
/*      */     private final AbstractSVGPathSegList this$0;
/*      */     
/*      */     public PathSegListBuilder(AbstractSVGPathSegList this$0, ListHandler listHandler) {
/*  876 */       this.this$0 = this$0;
/*  877 */       this.listHandler = listHandler;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  883 */     public void startPath() { this.listHandler.startList(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  890 */     public void endPath() { this.listHandler.endList(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  897 */     public void movetoRel(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem(this.this$0, (short)3, "m", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  906 */     public void movetoAbs(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem(this.this$0, (short)2, "M", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  915 */     public void closePath() { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegItem(this.this$0, (short)1, "z")); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  924 */     public void linetoRel(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem(this.this$0, (short)5, "l", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  933 */     public void linetoAbs(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegMovetoLinetoItem(this.this$0, (short)4, "L", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  942 */     public void linetoHorizontalRel(float x) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegLinetoHorizontalItem(this.this$0, (short)13, "h", x)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  951 */     public void linetoHorizontalAbs(float x) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegLinetoHorizontalItem(this.this$0, (short)12, "H", x)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  960 */     public void linetoVerticalRel(float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegLinetoVerticalItem(this.this$0, (short)15, "v", y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  969 */     public void linetoVerticalAbs(float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegLinetoVerticalItem(this.this$0, (short)14, "V", y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  981 */     public void curvetoCubicRel(float x1, float y1, float x2, float y2, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoCubicItem(this.this$0, (short)7, "c", x1, y1, x2, y2, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  993 */     public void curvetoCubicAbs(float x1, float y1, float x2, float y2, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoCubicItem(this.this$0, (short)6, "C", x1, y1, x2, y2, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1004 */     public void curvetoCubicSmoothRel(float x2, float y2, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoCubicSmoothItem(this.this$0, (short)17, "s", x2, y2, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1015 */     public void curvetoCubicSmoothAbs(float x2, float y2, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoCubicSmoothItem(this.this$0, (short)16, "S", x2, y2, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1026 */     public void curvetoQuadraticRel(float x1, float y1, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticItem(this.this$0, (short)9, "q", x1, y1, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1037 */     public void curvetoQuadraticAbs(float x1, float y1, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticItem(this.this$0, (short)8, "Q", x1, y1, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1047 */     public void curvetoQuadraticSmoothRel(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticSmoothItem(this.this$0, (short)19, "t", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1057 */     public void curvetoQuadraticSmoothAbs(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegCurvetoQuadraticSmoothItem(this.this$0, (short)18, "T", x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1070 */     public void arcRel(float rx, float ry, float xAxisRotation, boolean largeArcFlag, boolean sweepFlag, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegArcItem(this.this$0, (short)11, "a", rx, ry, xAxisRotation, largeArcFlag, sweepFlag, x, y)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1083 */     public void arcAbs(float rx, float ry, float xAxisRotation, boolean largeArcFlag, boolean sweepFlag, float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPathSegList.SVGPathSegArcItem(this.this$0, (short)10, "A", rx, ry, xAxisRotation, largeArcFlag, sweepFlag, x, y)); }
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGPathSegList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */