/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.apache.batik.parser.PointsHandler;
/*     */ import org.apache.batik.parser.PointsParser;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGPoint;
/*     */ import org.w3c.dom.svg.SVGPointList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGPointList
/*     */   extends AbstractSVGList
/*     */   implements SVGPointList
/*     */ {
/*     */   public static final String SVG_POINT_LIST_SEPARATOR = " ";
/*     */   
/*  50 */   protected String getItemSeparator() { return " "; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract SVGException createSVGException(short paramShort, String paramString, Object[] paramArrayOfObject);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  66 */   public SVGPoint initialize(SVGPoint newItem) throws DOMException, SVGException { return (SVGPoint)initializeImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  73 */   public SVGPoint getItem(int index) throws DOMException { return (SVGPoint)getItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  82 */   public SVGPoint insertItemBefore(SVGPoint newItem, int index) throws DOMException, SVGException { return (SVGPoint)insertItemBeforeImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  91 */   public SVGPoint replaceItem(SVGPoint newItem, int index) throws DOMException, SVGException { return (SVGPoint)replaceItemImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  98 */   public SVGPoint removeItem(int index) throws DOMException { return (SVGPoint)removeItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 106 */   public SVGPoint appendItem(SVGPoint newItem) throws DOMException, SVGException { return (SVGPoint)appendItemImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGItem createSVGItem(Object newItem) {
/* 113 */     SVGPoint point = (SVGPoint)newItem;
/* 114 */     return new SVGPointItem(this, point.getX(), point.getY());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void doParse(String value, ListHandler handler) throws ParseException {
/* 125 */     PointsParser pointsParser = new PointsParser();
/* 126 */     PointsListBuilder builder = new PointsListBuilder(this, handler);
/* 127 */     pointsParser.setPointsHandler(builder);
/* 128 */     pointsParser.parse(value);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void checkItemType(Object newItem) throws SVGException {
/* 135 */     if (!(newItem instanceof SVGPoint)) {
/* 136 */       createSVGException((short)0, "expected.point", null);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class SVGPointItem
/*     */     extends AbstractSVGItem
/*     */     implements SVGPoint
/*     */   {
/*     */     protected float x;
/*     */ 
/*     */ 
/*     */     
/*     */     protected float y;
/*     */ 
/*     */     
/*     */     private final AbstractSVGPointList this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public SVGPointItem(AbstractSVGPointList this$0, float x, float y) {
/* 159 */       this.this$0 = this$0;
/* 160 */       this.x = x;
/* 161 */       this.y = y;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 168 */     protected String getStringValue() { return Float.toString(this.x) + ',' + Float.toString(this.y); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 177 */     public float getX() { return this.x; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 184 */     public float getY() { return this.y; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setX(float x) {
/* 191 */       this.x = x;
/* 192 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setY(float y) {
/* 199 */       this.y = y;
/* 200 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 207 */     public SVGPoint matrixTransform(SVGMatrix matrix) { return SVGOMPoint.matrixTransform(this, matrix); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class PointsListBuilder
/*     */     implements PointsHandler
/*     */   {
/*     */     protected ListHandler listHandler;
/*     */ 
/*     */ 
/*     */     
/*     */     private final AbstractSVGPointList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public PointsListBuilder(AbstractSVGPointList this$0, ListHandler listHandler) {
/* 226 */       this.this$0 = this$0;
/* 227 */       this.listHandler = listHandler;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 234 */     public void startPoints() { this.listHandler.startList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 241 */     public void point(float x, float y) throws ParseException { this.listHandler.item(new AbstractSVGPointList.SVGPointItem(this.this$0, x, y)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 248 */     public void endPoints() { this.listHandler.endList(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGPointList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */