/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import org.apache.batik.parser.DefaultPreserveAspectRatioHandler;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.apache.batik.parser.PreserveAspectRatioParser;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGPreserveAspectRatio;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGPreserveAspectRatio
/*     */   implements SVGPreserveAspectRatio, SVGConstants
/*     */ {
/*     */   protected static final String[] ALIGN_VALUES = { 
/*  44 */       null, "none", "xMinYMin", "xMidYMin", "xMaxYMin", "xMinYMid", "xMidYMid", "xMaxYMid", "xMinYMax", "xMidYMax", "xMaxYMax" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   protected static final String[] MEET_OR_SLICE_VALUES = { null, "meet", "slice" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String getValueAsString(short align, short meetOrSlice) {
/*  76 */     if (align < 1 || align > 10) {
/*  77 */       return null;
/*     */     }
/*  79 */     String value = ALIGN_VALUES[align];
/*  80 */     if (align == 1) {
/*  81 */       return value;
/*     */     }
/*  83 */     if (meetOrSlice < 1 || meetOrSlice > 2) {
/*  84 */       return null;
/*     */     }
/*  86 */     return value + ' ' + MEET_OR_SLICE_VALUES[meetOrSlice];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  93 */   protected short align = 6;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 100 */   protected short meetOrSlice = 1;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 107 */   public short getAlign() { return this.align; }
/*     */ 
/*     */ 
/*     */   
/* 111 */   public short getMeetOrSlice() { return this.meetOrSlice; }
/*     */ 
/*     */   
/*     */   public void setAlign(short align) {
/* 115 */     this.align = align;
/* 116 */     setAttributeValue(getValueAsString());
/*     */   }
/*     */   
/*     */   public void setMeetOrSlice(short meetOrSlice) {
/* 120 */     this.meetOrSlice = meetOrSlice;
/* 121 */     setAttributeValue(getValueAsString());
/*     */   }
/*     */   
/*     */   public void reset() {
/* 125 */     this.align = 6;
/* 126 */     this.meetOrSlice = 1;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract void setAttributeValue(String paramString) throws DOMException;
/*     */ 
/*     */   
/*     */   protected abstract DOMException createDOMException(short paramShort, String paramString, Object[] paramArrayOfObject);
/*     */ 
/*     */   
/*     */   protected void setValueAsString(String value) throws DOMException {
/* 138 */     PreserveAspectRatioParserHandler ph = new PreserveAspectRatioParserHandler(this);
/*     */     try {
/* 140 */       PreserveAspectRatioParser p = new PreserveAspectRatioParser();
/* 141 */       p.setPreserveAspectRatioHandler(ph);
/* 142 */       p.parse(value);
/* 143 */       this.align = ph.getAlign();
/* 144 */       this.meetOrSlice = ph.getMeetOrSlice();
/*     */     } catch (ParseException ex) {
/* 146 */       throw createDOMException((short)13, "preserve.aspect.ratio", new Object[] { value });
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String getValueAsString() {
/* 156 */     if (this.align < 1 || this.align > 10) {
/* 157 */       throw createDOMException((short)13, "preserve.aspect.ratio.align", new Object[] { new Integer(this.align) });
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 162 */     String value = ALIGN_VALUES[this.align];
/* 163 */     if (this.align == 1) {
/* 164 */       return value;
/*     */     }
/*     */     
/* 167 */     if (this.meetOrSlice < 1 || this.meetOrSlice > 2) {
/* 168 */       throw createDOMException((short)13, "preserve.aspect.ratio.meet.or.slice", new Object[] { new Integer(this.meetOrSlice) });
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 173 */     return value + ' ' + MEET_OR_SLICE_VALUES[this.meetOrSlice];
/*     */   } protected class PreserveAspectRatioParserHandler extends DefaultPreserveAspectRatioHandler { public short align;
/*     */     protected PreserveAspectRatioParserHandler(AbstractSVGPreserveAspectRatio this$0) {
/* 176 */       this.this$0 = this$0;
/*     */       
/* 178 */       this.align = 6;
/*     */       
/* 180 */       this.meetOrSlice = 1;
/*     */     }
/*     */     public short meetOrSlice; private final AbstractSVGPreserveAspectRatio this$0;
/* 183 */     public short getAlign() { return this.align; }
/*     */ 
/*     */ 
/*     */     
/* 187 */     public short getMeetOrSlice() { return this.meetOrSlice; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 196 */     public void none() { this.align = 1; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 205 */     public void xMaxYMax() { this.align = 10; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 214 */     public void xMaxYMid() { this.align = 7; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 223 */     public void xMaxYMin() { this.align = 4; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 232 */     public void xMidYMax() { this.align = 9; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 241 */     public void xMidYMid() { this.align = 6; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 250 */     public void xMidYMin() { this.align = 3; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 259 */     public void xMinYMax() { this.align = 8; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 268 */     public void xMinYMid() { this.align = 5; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 277 */     public void xMinYMin() { this.align = 2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 286 */     public void meet() { this.meetOrSlice = 1; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 295 */     public void slice() { this.meetOrSlice = 2; } }
/*     */ 
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGPreserveAspectRatio.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */