/*     */ package org.apache.batik.dom.svg;
/*     */ 
/*     */ import java.awt.geom.AffineTransform;
/*     */ import org.apache.batik.parser.ParseException;
/*     */ import org.apache.batik.parser.TransformListHandler;
/*     */ import org.apache.batik.parser.TransformListParser;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.svg.SVGException;
/*     */ import org.w3c.dom.svg.SVGMatrix;
/*     */ import org.w3c.dom.svg.SVGTransform;
/*     */ import org.w3c.dom.svg.SVGTransformList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractSVGTransformList
/*     */   extends AbstractSVGList
/*     */   implements SVGTransformList
/*     */ {
/*     */   public static final String SVG_TRANSFORMATION_LIST_SEPARATOR = "";
/*     */   
/*  54 */   protected String getItemSeparator() { return ""; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract SVGException createSVGException(short paramShort, String paramString, Object[] paramArrayOfObject);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  70 */   public SVGTransform initialize(SVGTransform newItem) throws DOMException, SVGException { return (SVGTransform)initializeImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  77 */   public SVGTransform getItem(int index) throws DOMException { return (SVGTransform)getItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  86 */   public SVGTransform insertItemBefore(SVGTransform newItem, int index) throws DOMException, SVGException { return (SVGTransform)insertItemBeforeImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  95 */   public SVGTransform replaceItem(SVGTransform newItem, int index) throws DOMException, SVGException { return (SVGTransform)replaceItemImpl(newItem, index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 102 */   public SVGTransform removeItem(int index) throws DOMException { return (SVGTransform)removeItemImpl(index); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 110 */   public SVGTransform appendItem(SVGTransform newItem) throws DOMException, SVGException { return (SVGTransform)appendItemImpl(newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransform createSVGTransformFromMatrix(SVGMatrix matrix) {
/* 118 */     SVGOMTransform transform = new SVGOMTransform();
/* 119 */     transform.setMatrix(matrix);
/* 120 */     return transform;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SVGTransform consolidate() {
/* 127 */     revalidate();
/*     */     
/* 129 */     int size = this.itemList.size();
/* 130 */     if (size == 0)
/* 131 */       return null; 
/* 132 */     if (size == 1) {
/* 133 */       return getItem(0);
/*     */     }
/*     */     
/* 136 */     SVGTransformItem t = (SVGTransformItem)getItemImpl(0);
/* 137 */     AffineTransform at = (AffineTransform)t.affineTransform.clone();
/*     */     
/* 139 */     for (int i = 1; i < size; i++) {
/* 140 */       t = (SVGTransformItem)getItemImpl(i);
/* 141 */       at.concatenate(t.affineTransform);
/*     */     } 
/* 143 */     SVGOMMatrix matrix = new SVGOMMatrix(at);
/* 144 */     return initialize(createSVGTransformFromMatrix(matrix));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AffineTransform getAffineTransform() {
/* 152 */     AffineTransform at = new AffineTransform();
/* 153 */     for (int i = 0; i < getNumberOfItems(); i++) {
/* 154 */       SVGTransformItem item = (SVGTransformItem)getItem(i);
/* 155 */       at.concatenate(item.affineTransform);
/*     */     } 
/* 157 */     return at;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 164 */   protected SVGItem createSVGItem(Object newItem) { return new SVGTransformItem(this, (SVGTransform)newItem); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void doParse(String value, ListHandler handler) throws ParseException {
/* 176 */     TransformListParser transformListParser = new TransformListParser();
/* 177 */     TransformListBuilder builder = new TransformListBuilder(this, handler);
/* 178 */     transformListParser.setTransformListHandler(builder);
/* 179 */     transformListParser.parse(value);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void checkItemType(Object newItem) {
/* 186 */     if (!(newItem instanceof SVGTransform)) {
/* 187 */       createSVGException((short)0, "expected.transform", null);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class SVGTransformItem
/*     */     extends AbstractSVGTransform
/*     */     implements SVGItem
/*     */   {
/*     */     protected boolean xOnly;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean angleOnly;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected AbstractSVGList parent;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String itemStringValue;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final AbstractSVGTransformList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 225 */     protected SVGTransformItem(AbstractSVGTransformList this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected SVGTransformItem(AbstractSVGTransformList this$0, SVGTransform transform) {
/* 231 */       this.this$0 = this$0;
/* 232 */       assign(transform);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void resetAttribute() {
/* 240 */       if (this.parent != null) {
/* 241 */         this.itemStringValue = null;
/* 242 */         this.parent.itemChanged();
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 251 */     public void setParent(AbstractSVGList list) { this.parent = list; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 258 */     public AbstractSVGList getParent() { return this.parent; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public String getValueAsString() {
/* 266 */       if (this.itemStringValue == null) {
/* 267 */         this.itemStringValue = getStringValue();
/*     */       }
/* 269 */       return this.itemStringValue;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void assign(SVGTransform transform) {
/* 277 */       this.type = transform.getType();
/* 278 */       SVGMatrix matrix = transform.getMatrix();
/* 279 */       switch (this.type) {
/*     */         case 2:
/* 281 */           setTranslate(matrix.getE(), matrix.getF());
/*     */           break;
/*     */         case 3:
/* 284 */           setScale(matrix.getA(), matrix.getD());
/*     */           break;
/*     */         case 4:
/* 287 */           if (matrix.getE() == 0.0F) {
/* 288 */             rotate(transform.getAngle()); break;
/*     */           } 
/* 290 */           this.angleOnly = false;
/* 291 */           if (matrix.getA() == 1.0F) {
/* 292 */             setRotate(transform.getAngle(), matrix.getE(), matrix.getF()); break;
/*     */           } 
/* 294 */           if (transform instanceof AbstractSVGTransform) {
/* 295 */             AbstractSVGTransform internal = (AbstractSVGTransform)transform;
/*     */             
/* 297 */             setRotate(internal.getAngle(), internal.getX(), internal.getY());
/*     */           } 
/*     */           break;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 5:
/* 306 */           setSkewX(transform.getAngle());
/*     */           break;
/*     */         case 6:
/* 309 */           setSkewY(transform.getAngle());
/*     */           break;
/*     */         case 1:
/* 312 */           setMatrix(matrix);
/*     */           break;
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void translate(float x) throws ParseException {
/* 321 */       this.xOnly = true;
/* 322 */       setTranslate(x, 0.0F);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void rotate(float angle) throws ParseException {
/* 329 */       this.angleOnly = true;
/* 330 */       setRotate(angle, 0.0F, 0.0F);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected void scale(float x) throws ParseException {
/* 337 */       this.xOnly = true;
/* 338 */       setScale(x, x);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 346 */     protected void matrix(float a, float b, float c, float d, float e, float f) throws ParseException { setMatrix(new SVGOMMatrix(new AffineTransform(a, b, c, d, e, f))); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setMatrix(SVGMatrix matrix) {
/* 353 */       super.setMatrix(matrix);
/* 354 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setTranslate(float tx, float ty) throws ParseException {
/* 361 */       super.setTranslate(tx, ty);
/* 362 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setScale(float sx, float sy) throws ParseException {
/* 369 */       super.setScale(sx, sy);
/* 370 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setRotate(float angle, float cx, float cy) throws ParseException {
/* 378 */       super.setRotate(angle, cx, cy);
/* 379 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setSkewX(float angle) throws ParseException {
/* 386 */       super.setSkewX(angle);
/* 387 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void setSkewY(float angle) throws ParseException {
/* 394 */       super.setSkewY(angle);
/* 395 */       resetAttribute();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 402 */     protected SVGMatrix createMatrix() { return new AbstractSVGTransformList$1(this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String getStringValue() {
/*     */       int i;
/*     */       double[] matrix;
/* 443 */       StringBuffer buf = new StringBuffer();
/* 444 */       switch (this.type) {
/*     */         case 2:
/* 446 */           buf.append("translate(");
/* 447 */           buf.append((float)this.affineTransform.getTranslateX());
/* 448 */           if (!this.xOnly) {
/* 449 */             buf.append(' ');
/* 450 */             buf.append((float)this.affineTransform.getTranslateY());
/*     */           } 
/* 452 */           buf.append(')');
/*     */           break;
/*     */         case 4:
/* 455 */           buf.append("rotate(");
/* 456 */           buf.append(this.angle);
/* 457 */           if (!this.angleOnly) {
/* 458 */             buf.append(' ');
/* 459 */             buf.append(this.x);
/* 460 */             buf.append(' ');
/* 461 */             buf.append(this.y);
/*     */           } 
/* 463 */           buf.append(')');
/*     */           break;
/*     */         case 3:
/* 466 */           buf.append("scale(");
/* 467 */           buf.append((float)this.affineTransform.getScaleX());
/* 468 */           if (!this.xOnly) {
/* 469 */             buf.append(' ');
/* 470 */             buf.append((float)this.affineTransform.getScaleY());
/*     */           } 
/* 472 */           buf.append(')');
/*     */           break;
/*     */         case 5:
/* 475 */           buf.append("skewX(");
/* 476 */           buf.append(this.angle);
/* 477 */           buf.append(')');
/*     */           break;
/*     */         case 6:
/* 480 */           buf.append("skewY(");
/* 481 */           buf.append(this.angle);
/* 482 */           buf.append(')');
/*     */           break;
/*     */         case 1:
/* 485 */           buf.append("matrix(");
/* 486 */           matrix = new double[6];
/* 487 */           this.affineTransform.getMatrix(matrix);
/* 488 */           for (i = 0; i < 6; i++) {
/* 489 */             if (i != 0) {
/* 490 */               buf.append(' ');
/*     */             }
/* 492 */             buf.append((float)matrix[i]);
/*     */           } 
/* 494 */           buf.append(')');
/*     */           break;
/*     */       } 
/* 497 */       return buf.toString();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected class TransformListBuilder
/*     */     implements TransformListHandler
/*     */   {
/*     */     protected ListHandler listHandler;
/*     */ 
/*     */ 
/*     */     
/*     */     private final AbstractSVGTransformList this$0;
/*     */ 
/*     */ 
/*     */     
/*     */     public TransformListBuilder(AbstractSVGTransformList this$0, ListHandler listHandler) {
/* 516 */       this.this$0 = this$0;
/* 517 */       this.listHandler = listHandler;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 524 */     public void startTransformList() { this.listHandler.startList(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void matrix(float a, float b, float c, float d, float e, float f) throws ParseException {
/* 533 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 534 */       item.matrix(a, b, c, d, e, f);
/* 535 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void rotate(float theta) throws ParseException {
/* 542 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 543 */       item.rotate(theta);
/* 544 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void rotate(float theta, float cx, float cy) throws ParseException {
/* 552 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 553 */       item.setRotate(theta, cx, cy);
/* 554 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void translate(float tx) throws ParseException {
/* 561 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 562 */       item.translate(tx);
/* 563 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void translate(float tx, float ty) throws ParseException {
/* 570 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 571 */       item.setTranslate(tx, ty);
/* 572 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void scale(float sx) throws ParseException {
/* 579 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 580 */       item.scale(sx);
/* 581 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void scale(float sx, float sy) throws ParseException {
/* 588 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 589 */       item.setScale(sx, sy);
/* 590 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void skewX(float skx) throws ParseException {
/* 597 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 598 */       item.setSkewX(skx);
/* 599 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void skewY(float sky) throws ParseException {
/* 606 */       AbstractSVGTransformList.SVGTransformItem item = new AbstractSVGTransformList.SVGTransformItem(this.this$0);
/* 607 */       item.setSkewY(sky);
/* 608 */       this.listHandler.item(item);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 615 */     public void endTransformList() { this.listHandler.endList(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svg-dom.jar!\org\apache\batik\dom\svg\AbstractSVGTransformList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */